-- grouping types on genomic features
-- table name defined in macro: TBN_GF_GRP
drop table if exists gfGrouping;
create table gfGrouping (
  id TINYINT not null primary key,
  name char(50) not null
);
-- insert into gfGrouping values (1, "genome");
insert into gfGrouping values (2, "RefSeq gene");
insert into gfGrouping values (3, "non-coding RNA");
insert into gfGrouping values (4, "RepeatMasker");
insert into gfGrouping values (5, "others");



-- for genomic features that can be used as horizontal axis
-- each type of gf (except genome) will have a corresponding covering table
drop table if exists gfInfo;
create table gfInfo (
  name char(50) not null primary key,
  printname char(100) not null,
  grp tinyint not null
);
-- insert into gfInfo values ('genome','genome', 1);
insert into gfInfo values ('utr3',"3' UTR", 2);
insert into gfInfo values ('genebody','gene body', 2);
insert into gfInfo values ('utr5',"5' UTR", 2);
insert into gfInfo values ('promoter','3kb promoter', 2);
insert into gfInfo values ('exons','exon', 2);
insert into gfInfo values ('introns','intron', 2);
insert into gfInfo values ('wgRna',"sno/miRNA", 3);
insert into gfInfo values ('RNA','RNA (by RepeatMasker)', 3);
insert into gfInfo values ('DNA','DNA transposon', 4);
insert into gfInfo values ('SINE','SINE', 4);
insert into gfInfo values ('LINE','LINE', 4);
insert into gfInfo values ('LTR','LTR', 4);
insert into gfInfo values ('Low_complexity','low complexity', 4);
insert into gfInfo values ('Satellite','satellite', 4);
insert into gfInfo values ('Simple_repeat','simple repeat', 4);
insert into gfInfo values ('Other','other repeats', 4);
insert into gfInfo values ('Unknown','unknown', 4);
insert into gfInfo values ('cpgisland','CpG island', 5);


-- for stuff that can be plotted as decorative tracks (no genome)
-- the grp is also from gfGrouping table
-- filetype: 0: server bigBed, 2: server bigWig
drop table if exists decorInfo;
create table decorInfo (
  name char(50) not null primary key,
  printname char(100) not null,
  grp tinyint not null,
  fileType tinyint not null
);
insert into decorInfo values ('utr3',"3' UTR", 2, 0);
insert into decorInfo values ('genebody','gene body', 2, 0);
insert into decorInfo values ('utr5',"5' UTR", 2, 0);
insert into decorInfo values ('promoter','3kb promoter', 2, 0);
insert into decorInfo values ('exons','exon', 2, 0);
insert into decorInfo values ('introns','intron', 2, 0);
insert into decorInfo values ('wgRna',"sno/miRNA", 3, 0);
insert into decorInfo values ('RNA','RNA (by RepeatMasker)', 3, 0);
insert into decorInfo values ('DNA','DNA transposon', 4, 0);
insert into decorInfo values ('SINE','SINE', 4, 0);
insert into decorInfo values ('LINE','LINE', 4, 0);
insert into decorInfo values ('LTR','LTR', 4, 0);
insert into decorInfo values ('Low_complexity','low complexity', 4, 0);
insert into decorInfo values ('Satellite','satellite', 4, 0);
insert into decorInfo values ('Simple_repeat','simple repeat', 4, 0);
insert into decorInfo values ('Other','other repeats', 4, 0);
insert into decorInfo values ('Unknown','unknown', 4, 0);
insert into decorInfo values ('cpgisland','CpG island', 5, 0);



-- insert into decorInfo values ('GCcontent','G/C content', 5, 0);
-- insert into decorInfo values ('CpG','CpG density', 5, 0);
-- insert into decorInfo values ('masked','masked region', 5, 0);
-- insert into decorInfo values ('mappability','mappability', 5, 0);



drop table if exists session;
create table session (
  session char(20) not null collate utf8_bin,
  statusId int not null,
  statusNote varchar(255) null,
  clientCtrl text null,
  serverTrack text null,
  customTrack text null,
  customTrackAttr text null,
  collateType char(30) not null,
  collateWhat varchar(100) not null,
  dspStat varchar(255) null,
  serverDecor text null,
  customDecor text null,
  corrStat varchar(255) null,
  itemlistID int null
);
drop table if exists collateitemlist;
create table collateitemlist (
  id int not null primary key,
  itemlist text not null
);
-- grant ALL on hg19heatmap.session to 'nobody@localhost';
-- grant ALL on hg19heatmap.collateitemlist to 'nobody@localhost';
