/**************************
     This file is copyrighted, but license is hereby granted for personal,
     academic, and non-profit use.
     Commercial users should contact Xin Zhou xzhou82@gmail.com for permission.
 **************************/
#include <stdio.h>
#include <stdlib.h>
#include <search.h>
#include <string.h>
#include <sys/wait.h>
#include <limits.h>
#include <mysql.h>
#include <assert.h>
#include <math.h>
#include <time.h>
#include "tabix.h"

/* the only place to use gnu hash is
assemblying hmtk info for datasets
be very careful if the hash function will be used elsewhere
*/

#define GFType_cgi "gftype"
#define StartChrom_cgi "startChr"
#define StartCoord_cgi "startCoord"
#define StopChrom_cgi "stopChr"
#define StopCoord_cgi "stopCoord"
#define Moveleft_cgi "moveleft"
#define Moveright_cgi "moveright"
//#define Zoomout_cgi "zoomout"
#define MaxProcessNum 20 // max # of processes to fork for bigwig data query
#define BGcolor "#FFF9D2" // supposedly eye-friendly background color
#define MaxBigbeditem4geneplot 4000 // max # of bigbed items for gene plot
#define min(a,b) ( (a) < (b) ? (a) : (b) )
#define max(a,b) ( (a) > (b) ? (a) : (b) )


/* default values */
#define GENOME "genome"
#define M_hide 0
#define M_hide_s "0"
#define M_show 1
#define M_show_s "1"
#define M_thin 2
#define M_thin_s "2"
#define M_full 3
#define M_full_s "3"
#define M_arc 4
#define M_arc_s "4"
#define M_trihm 5
#define M_trihm_s "5"
#define M_den 6
#define M_den_s "6"
#define M_error -1


#define FT_bigbed_n 0
#define FT_bigbed_c 1
#define FT_hmtk_n 2
#define FT_hmtk_c 3
#define FT_bam_n 4
#define FT_bam_c 5
#define FT_pwc 6
#define FT_htest 7
#define FT_qdecor_n 8
#define FT_chiapet_n 9
#define FT_chiapet_c 10
#define FT_tkgrp 11
#define FT_cat_n 12
#define FT_cat_c 13


#define trashDir "/usr/lib/trash"
#define WWWT "/var/www/browser/t"
#define BINdir "../bin"
#define Mysqlserver "localhost"
#define Mysqluser "root"
#define Mysqlpswd "xzhou"


/* miscellaneous */
#define SQUAWK 0 // set to 1 for squawking
#define CHECKCPUTIME 0 // 1 for benchmarking cpu time
#define Squawk stderr // where to squawk at, stdout or stderr
#define boolean short
#define TRUE 1
#define FALSE 0


struct slNode
    { 
    /* covers tnode, and track */
    struct slNode *next;
    char *name;
    };
struct tnode
    { 
    /*
	for decor tracks:
	t1: track name
	t2: label
	t3: urlpath
	t4: mode digit

	for cgiparamsl:
	t1: key
	t2: value

	for hmtk json dump:
	t1: label
	t2: md anno
	t4: filetype
	*/
    struct tnode *next;
    char *t1;
    char *t2;
    char *t3;
    int t4;
    int num;
    float fnum;
    float fnum2;
    };
struct nsortItem
	{
	/* numerical sort */
	double value;
	void *ptr; // points to original item
	};
struct genericItem
	{
	/* to include beditem and readitem 
	when only coordinate is concerned
	and when bed/sam format cannot be sured
	*/
	struct genericItem *next;
	unsigned int start;
	unsigned int stop;
	};

struct beditem
	{
	/* such and the read has no field for chrs, because they are always attached to
	some structures that identifies chr
	*/
	struct beditem *next;
	unsigned int start;
	unsigned int stop;
	char *rest;
	};
struct readitem
	{
	struct readitem *next;
	unsigned int start;
	unsigned int stop;
	char *id;
	char *flag; // string (decimal) representation of the flag, to be parsed by js
	char *mismatch;
	char *seq; // read sequence
	};


struct nnode
    { 
    // for genestruct
    struct nnode *next;
    int chrIdx;
    int start;
    int stop;
    int flank5start; // upstream flank start, only used in genesetview
    int flank5stop;
    int flank3start; // downstream flank start, only used in genesetview
    int flank3stop;
    char strand;
    char *name;
    double *data;
    };
struct urlpiece
    { 
    // a piece of loooong url
    int offset;
    char *text;
    };
struct track
    { 
    /* both for track and density track */
    struct track *next;
    char *name; // matches file name
    char *urlpath; // either URL or file path
    int ft; // M_filetype
    double *data; // array length: dsp.usedSummaryNumber
    int gid; // for grouping tracks in htest, passed from client
    boolean flag;
    pid_t pid; // for forking on a track
    char *tmpfile; // session+track name, will hold data made by child process and later, need to be made before forking so that both parent/child can see it
    };
struct region
    {
    struct region *prev;
    struct region *next;
    int chromIdx;
    int bstart; // *b*oundary of this region in genome
    int bstop;
    int dstart; // *d*isplayed portion of this region
    int dstop;
    int flank5start; // upstream flank start, only used in genesetview
    int flank5stop;
    int flank3start; // downstream flank start, only used in genesetview
    int flank3stop;
    int summarySize;
    char *coordString;
    char *name; // only for itemlist
    // will only be used when zoom level changed, to indicate if this region is start of view region
    boolean isViewStart;
    int viewStartCoord;
    double fvalue; // a value for sorting items
    };
struct point
    {
    int chromIdx;
    int coord;
    boolean hitBorder;
    };
/* |--left wing--|========DSP========|--right wing--|
            dsp start            dsp stop
   start/stop index of dsp, need to be exactly hmSpan in length
*/
struct chritemsl
	{
	struct chritemsl *next;
	int chromIdx;
	struct beditem *itemsl;
	};
struct displayedRegion
    {
    // in case of juxtaposition, gf will be bigbed file path (server) or url (custom)
    char *gf;
    // start/stop will be used in determining head/tail
    // but will not be used for iteration purpose
    struct point *start;
    struct point *stop;
	struct chritemsl *chritemsl;
    struct region *head; // 5' end
    struct region *tail; // 3' end
    long entireLength;
    int usedSummaryNumber; // corresponds to number of pixels horizontally in heatmap
    boolean atbplevel; // if showing basepair, in this case, summary size will equal seq length
    int juxType; // type of juxtaposition, run mode 0-5
	int juxFt; // type of the file used in juxtaposition
	tabix_t *tabix; // tabix file handle for region computing during juxtaposition
    };
struct heatmap
    {
    struct displayedRegion *dsp;
    struct displayedRegion *dsp_chiapet;
    struct track *trackSl;
    struct slNode *genetracksl;
    // decor tracks grouped by file type (indicated by file type number)
    struct tnode *decor0;
    struct tnode *decor1;
    struct tnode *decor8;
    struct tnode *decor4;
    struct tnode *decor5;
    struct tnode *decor9;
    struct tnode *decor10;
    struct slNode *datasetSl; // list of datasets in use
    };



/**********************************
       global variables
 *********************************/
const char *CentralDB="WashUGb";
unsigned int hmSpan = 0;
MYSQL *conn;
struct chrInfoNode /* to be used in array */
    {
    char *name;
    unsigned int length;
    };
struct chrInfoNode **chrInfo; // an array
int lastChrIdx=-1;
struct point leftBorder, rightBorder;
boolean trigger_getdata;
char *bbiDir;
char *formatdbpath;
char *session = NULL;
int statusId = -1;
struct slNode *genetracksl = NULL;
struct tnode *cgiparamsl=NULL;



/**********************************
          tiny functions 
 *********************************/
void done()
{
if(SQUAWK) fputs("done\n", stderr);
}
void errabort(char *msg)
{
/*
va_list args;
va_start(args, format);
fprintf(stderr, format, args);
fputs("\n", stderr);
va_end(args);
*/
fprintf(stderr, "Aborted: %s\n", msg);
exit(0);
}

char *getSeq(char *chrom, unsigned int start, unsigned int stop)
{
/* call fastacmd to fetch seq 
free after use
*/
srand(time(0));
int r=rand();
char *outfile;
if(asprintf(&outfile, "%s/%d", trashDir, r)<0) errabort("bae");
char *command;
if(asprintf(&command, "fastacmd -d %s -s %s -L %d,%d -l %d > %s", formatdbpath, chrom, start, stop, (stop-start+1), outfile)<0) errabort("bae");

if(system(command) == -1)
	{
	fputs("cannot spawn process for fastacmd\n", stderr);
	return NULL;
	}

FILE *fin=fopen(outfile,"r");
if(fin==NULL)
	{
	fprintf(stderr, "%s: %m\n", __FUNCTION__);
	return NULL;
	}
char *line=malloc(1);
size_t s=1;
assert(getline(&line, &s, fin)!=-1);
assert(getline(&line, &s, fin)!=-1);
fclose(fin);
// last character is always newline
unlink(outfile);
free(outfile);
char delim[]="\n";
return strtok(line,delim);
}

void slReverse(void *sl)
{
struct slNode **ppt = (struct slNode **)sl;
struct slNode *newList = NULL;
struct slNode *el, *next;

next = *ppt;
while (next != NULL)
{    
	el = next;
	next = el->next;
	el->next = newList;
	newList = el;
}    
*ppt = newList;
}

int slCount2(void *in)
{
// works for things similar as slNode
struct slNode *sl=(struct slNode *)in;
int a=0;
for(; sl!=NULL; sl=sl->next)
	a++;
return a;
}
void slFree(void *in)
{
// works for things similar as slNode
struct slNode *sl=(struct slNode *)in;
struct slNode *n;
while(sl!=NULL)
	{
	n=sl->next;
	free(sl);
	sl=n;
	}
}
int tnodesl_search4num(struct tnode *sl, char *what)
{
/* return -1 if not found
so it should work only for positive integer values
*/
for(; sl!=NULL; sl=sl->next)
	{
	if(strcasecmp(sl->t1, what)==0)
		return sl->num;
	}
return -1;
}

int nsort_compAsc(const void *a, const void *b)
{
// numerical sort, ascending
const struct nsortItem *aa=a;
const struct nsortItem *bb=b;
return (aa->value > bb->value) - (aa->value < bb->value);
}
int nsort_compDsc(const void *a, const void *b)
{
// numerical sort, descending
const struct nsortItem *aa=a;
const struct nsortItem *bb=b;
return (bb->value > aa->value) - (bb->value < aa->value);
}

struct genericItem *beditemsort_startAsc(struct genericItem *sl)
{
/* apply numerical sort to start of generic items
yield new list in ascending order
original list is *altered*
*/
if(sl==NULL) return NULL;
int count=0;
struct genericItem *t;
for(t=sl; t!=NULL; t=t->next) count++;
struct nsortItem *array=malloc(sizeof(struct nsortItem)*count);
if(array==NULL)
	{
	fprintf(stderr, "%s: out of mem\n", __FUNCTION__);
	exit(0);
	}
int i=0;
for(t=sl; t!=NULL; t=t->next)
	{
	array[i].value=t->start;
	array[i++].ptr=(void *)t;
	}
qsort(array, count, sizeof(struct nsortItem), nsort_compDsc);
struct genericItem *newsl=NULL;
for(i=0; i<count; i++)
	{
	t=(struct genericItem *)array[i].ptr;
	t->next=newsl;
	newsl=t;
	}
free(array);
return newsl;
}

struct genericItem *beditemsort_stopDsc(struct genericItem *sl)
{
/* apply numerical sort to stop of bed items
yield new list in descending order
original list is *altered*
*/
if(sl==NULL) return NULL;
int count=0;
struct genericItem *t;
for(t=sl; t!=NULL; t=t->next) count++;
struct nsortItem *array=malloc(sizeof(struct nsortItem)*count);
if(array==NULL)
	{
	fprintf(stderr, "%s: out of mem\n", __FUNCTION__);
	exit(0);
	}
int i=0;
for(t=sl; t!=NULL; t=t->next)
	{
	array[i].value=t->stop;
	array[i++].ptr=(void *)t;
	}
qsort(array, count, sizeof(struct nsortItem), nsort_compAsc);
struct genericItem *newsl=NULL;
for(i=0; i<count; i++)
	{
	t=(struct genericItem *)array[i].ptr;
	t->next=newsl;
	newsl=t;
	}
free(array);
return newsl;
}

char *makefilepath(char *trackname, int ft)
{
/* for native tracks */
char *p;
switch(ft)
	{
	case FT_bigbed_c:
	case FT_hmtk_c:
	case FT_chiapet_c:
	case FT_bam_c:
	case FT_cat_c:
		return trackname;
	case FT_bigbed_n:
		if(asprintf(&p, "%s%s.gz", bbiDir, trackname)<0) fputs("no memory\n", stderr);
		return p;
	case FT_hmtk_n:
		if(asprintf(&p, "%s%s.gz", bbiDir, trackname)<0) fputs("no memory\n", stderr);
		return p;
	case FT_qdecor_n:
		if(asprintf(&p, "%s%s.gz", bbiDir, trackname)<0) fputs("no memory\n", stderr);
		return p;
	case FT_chiapet_n:
		if(asprintf(&p, "%s%s.gz", bbiDir, trackname)<0) fputs("no memory\n", stderr);
		return p;
	case FT_cat_n:
		if(asprintf(&p, "%s%s.gz", bbiDir, trackname)<0) fputs("no memory\n", stderr);
		return p;
	case FT_bam_n:
		if(asprintf(&p, "%s%s.gz", bbiDir, trackname)<0) fputs("no memory\n", stderr);
		return p;
	default:
		fprintf(stderr, "%s: %s %d\n", __FUNCTION__, trackname, ft);
		exit(0);
	}
return NULL;
}



float standardDeviation(double *data, int len)
{
if(len <= 1) return 0;
double ave = 0;
int i;
for(i=0; i<len; i++) ave += data[i];
ave /= len;
double std = 0;
for(i=0; i<len; i++)
    std += (data[i]-ave) * (data[i]-ave);
return sqrt(std/len);
}
int urlpiece_cmp(const void *a, const void *b)
{
const struct urlpiece *u1 = (const struct urlpiece *)a;
const struct urlpiece *u2 = (const struct urlpiece *)b;
return (u1->offset > u2->offset) - (u1->offset < u2->offset);
}
int getRegionNumber(struct displayedRegion *dsp)
{
int i=0;
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next) i++;
return i;
}
void dspAddRegionHead(struct displayedRegion *dsp, struct region *r)
{
r->next = dsp->head;
r->prev = NULL;
dsp->head = r;
if(dsp->tail == NULL)
    dsp->tail = r;
else
    r->next->prev = r;
}
void dspAddRegionTail(struct displayedRegion *dsp, struct region *r)
{
r->prev = dsp->tail;
r->next = NULL;
dsp->tail = r;
if(dsp->head == NULL)
    dsp->head = r;
else
    r->prev->next = r;
}

int intMin(int a, int b)
{
if(a > b) return b;
return a;
}
int intMax(int a, int b)
{
if(a > b) return a;
return b;
}

long strMayPositiveInt(char *what)
{
// return -1 to indicate error
char *tail;
long value = strtol(what, &tail, 0);
if(tail[0] == '\0')
    return value;
return -1;
}
int decorMode2num(char *str)
{
// convert string "thin" into "2"
if(strcasecmp(str, "thin")==0) return M_thin;
if(strcasecmp(str, "full")==0) return M_full;
if(strcasecmp(str, "density")==0) return M_den;
if(strcasecmp(str, "arc")==0) return M_arc;
if(strcasecmp(str, "trihm")==0) return M_trihm;
if(strcasecmp(str, "hide")==0) return M_hide;
if(strcasecmp(str, "show")==0) return M_show;
return M_error;
}

int *str2intArr(char *string, int howmany)
{
/* "1,2,3" to [1,2,3], for string such as "exonStarts"
   return pointer to an array
   free after use

   fields must be delimited by comma
 */
int *number = malloc(sizeof(int)*howmany);
char delim[] = ",";
char *tok = strtok(string, delim); assert(tok!=NULL);
assert((number[0]=strMayPositiveInt(tok))!=-1);
int i=1;
for(; i<howmany; i++)
    {
    tok = strtok(NULL, delim); assert(tok!=NULL);
    assert((number[i]=strMayPositiveInt(tok))!=-1);
    }
return number;
}

/*** cgi ***/
boolean cgiVarExists(char *what)
{
struct tnode *t;
for(t=cgiparamsl; t!=NULL; t=t->next)
	{
	if(strcasecmp(what, t->t1)==0) return TRUE;
	}
return FALSE;
}

char *cgiString(char *what)
{
/* return a copy of hash data
free after use
*/
struct tnode *t;
for(t=cgiparamsl; t!=NULL; t=t->next)
	{
	if(strcasecmp(what, t->t1)==0) return strdup(t->t2);
	}
return NULL;
}

int cgiInt(char *what)
{
struct tnode *t;
for(t=cgiparamsl; t!=NULL; t=t->next)
	{
	if(strcasecmp(what, t->t1)==0) return strtol(t->t2,NULL,0);
	}
fprintf(stderr, "integer-value param missing (%s)\n", what);
exit(0);
}

double cgiDouble(char *what)
{
struct tnode *t;
for(t=cgiparamsl; t!=NULL; t=t->next)
	{
	if(strcasecmp(what, t->t1)==0) return strtod(t->t2,NULL);
	}
fprintf(stderr, "float-value param missing (%s)\n", what);
exit(0);
}

void cgiVarSet(char *key, char *data)
{
struct tnode *t=malloc(sizeof(struct tnode));
t->t1=strdup(key);
t->t2=strdup(data);
t->next=cgiparamsl;
cgiparamsl=t;
}

void strDecode(char *in, char *out, int inLength)
{
char c;
int i;
for (i=0; i<inLength;++i)
	{    
	c = *in++;
	if (c == '+') 
		{
		*out++ = ' '; 
		}
	else if (c == '%') 
		{
		int code;
		if (sscanf(in, "%2x", &code) != 1)
		code = '?'; 
		in += 2;
		i += 2;
		*out++ = code;
		}    
	else 
		{
	*out++ = c; 
		}
	}
*out++ = 0; 
}

/*** mysql ***/
void mysqlConnect(const char *dbname)
{
conn=mysql_init(NULL);
if(mysql_real_connect(conn, Mysqlserver, Mysqluser, Mysqlpswd, dbname, 0, NULL, 0))
	return;
fprintf(stderr, "cannot connect to db (%s)\n", dbname);
exit(0);
}

void mysqlUpdate(char *query)
{
/* replace sqlUpdate()
*/
if(mysql_query(conn, query))
	{
	fprintf(stderr, "%s\n", mysql_error(conn));
	exit(0);
	}
}

MYSQL_RES *mysqlGetResult(char *query)
{
/* replaces sqlGetResult() in kent source
upon failure, return NULL
*/
if(mysql_query(conn, query))
	{
	fprintf(stderr, "%s\n", mysql_error(conn));
	return NULL;
	}
MYSQL_RES *re=mysql_use_result(conn);
if(re==NULL)
	{
	fprintf(stderr, "mysql_use_result: %s (%s)\n", mysql_error(conn), query);
	return NULL;
	}
return re;
}

char *mysqlGetOnestring(char *query)
{
/* upon any failure, return NULL 
free after use
*/
MYSQL_RES *sr = mysqlGetResult(query);
if(sr == NULL)
    return NULL;
char **row=mysql_fetch_row(sr);
if(row==NULL || row[0]==NULL)
	{
	mysql_free_result(sr);
	return NULL;
	}
char *re = strdup(row[0]);
mysql_free_result(sr);
return re;
}

int mysqlGetPositiveInteger(char *query)
{
/* upon any failure, return -1 */
MYSQL_RES *sr = mysqlGetResult(query);
if(sr==NULL)
	return -1;
char **row;
if((row=mysql_fetch_row(sr)) == NULL)
    {
    mysql_free_result(sr);
    return -1;
    }
if(row[0] == NULL)
    {
	fprintf(stderr, "%s: row[0]==null\n", __FUNCTION__);
    mysql_free_result(sr);
    return -1;
    }
int value = strMayPositiveInt(row[0]);
mysql_free_result(sr);
return value;
}
int mysqlGetGenesGroupId()
{
// there should be a decor track group "Genes", fetch its ID
return mysqlGetPositiveInteger("select id from gfGrouping where name=\"Genes\"");
}

boolean mysqlResultAffirmative(char *query)
{
MYSQL_RES *sr = mysqlGetResult(query);
if(sr==NULL)
	return FALSE;
boolean re = (mysql_fetch_row(sr) != NULL);
mysql_free_result(sr);
return re;
}

boolean sessionExists(char *session)
{
char *query;
if(asprintf(&query, "select session from session where session=\"%s\"", session)<0) errabort("bae");
boolean re=mysqlResultAffirmative(query);
free(query);
return re;
}

boolean sessionStatusExists(char *session, int status)
{
if(!sessionExists(session)) return FALSE;
char *query;
if(asprintf(&query, "select statusId from session where session=\"%s\" and statusId=%d", session, status)<0) errabort("bae");
boolean re=mysqlResultAffirmative(query);
free(query);
return re;
}

char *getItemlistfromdb(char *session, int statusId)
{
char *query;
if(asprintf(&query, "select itemlist from genesetRuntime where session=\"%s\" and statusId=%d", session, statusId)<0) errabort("bae");
char *re = mysqlGetOnestring(query);
free(query);
return re;
}



void showRegionSl(struct displayedRegion *dsp)
{
fprintf(stderr, "showRegionSl:\nusedSummaryNumber: %d\nentireLength: %ld\n", dsp->usedSummaryNumber, dsp->entireLength);
struct region *r;
int i = 0;
for(r=dsp->head; r!=NULL; r=r->next)
    fprintf(stderr, "(%d) %s [%d,%d >> %d,%d]\tlen: %d\tsp:%d\n", i++, chrInfo[r->chromIdx]->name, r->bstart,r->dstart, r->dstop,r->bstop, r->dstop-r->dstart, r->summarySize);

fputs("showRegionSl: okay\n",stderr);
}
void showTrackSl(struct track *sl)
{
int i=0;
for(; sl!=NULL; sl=sl->next)
    fprintf(stderr, "%d\t%s\n", ++i, sl->name);
}



/**********************************
         small functions 
 *********************************/

struct beditem *slSort_beditem(struct beditem *sl, int(*compare)(const void *el1, const void *el2))
{
/* the returned list is generated in reverse order
so besure to sort in *reverse* order so as to get *forward* order from returned list
*/
if(sl==NULL) return NULL;
int count=0;
struct beditem *t;
for(t=sl; t!=NULL; t=t->next) count++;
struct beditem **itemArr=malloc(sizeof(struct beditem *)*count);
if(itemArr==NULL)
	{
	fprintf(stderr, "%s: out of mem\n", __FUNCTION__);
	exit(0);
	}
int i=0;
for(t=sl; t!=NULL; t=t->next)
	itemArr[i++]=t;
qsort(itemArr, count, sizeof(struct beditem *), compare);
struct beditem *newsl=NULL;
for(i=0; i<count; i++)
	{
	itemArr[i]->next=newsl;
	newsl=itemArr[i];
	}
free(itemArr);
return newsl;
}

int strMayChrID(char *what)
{
int i = 0;
for(; i<=lastChrIdx; i++)
    {
    if(strcasecmp(chrInfo[i]->name, what) == 0)
        return i;
    }
return -1;
}
int *dissectCoordString(char *item)
{
/* input a string, supposedly "chr:start-stop strand"
   return 3-element int array: [chr idx, start, stop]
   the value will be -1 to indicate any error in input
   strand is optional, convert to 1/0 for +/-

   string will be broken
 */
size_t s = strlen(item);
char strand = item[s-1];
char *chr, *start, *stop;
char delim[] = " \t-:";
if((chr=strtok(item, delim)) == NULL)
    return NULL;
if((start=strtok(NULL, delim)) == NULL)
    return NULL;
if((stop=strtok(NULL, delim)) == NULL)
    return NULL;
int *arr = malloc(sizeof(int)*4);
arr[0] = strMayChrID(chr);
arr[1] = strMayPositiveInt(start);
arr[2] = strMayPositiveInt(stop);
if(strand=='+' || strand=='-')
    arr[3] = strand=='+' ? 1 : 0;
else
    arr[3] = 1;
if(arr[0] != -1)
    {
    // if coord is invalid (minus, exceed chr length...), replace by -1
    if(arr[1] > chrInfo[arr[0]]->length)
        arr[1] = -1;
    if(arr[2] > chrInfo[arr[0]]->length)
        arr[2] = -1;
    }
return arr;
}



boolean slLookup(void *sl, char *what, boolean caseSensitive)
{
/* caseSensitive: if true will use strcmp, else use strcasecmp
 */
struct slNode *this = (struct slNode *)sl;
for(; this!=NULL; this=this->next)
    {
    if(caseSensitive)
        {
        if(strcmp(this->name, what) == 0)
            return TRUE;
	}
    else
        {
	if(strcasecmp(this->name, what) == 0)
	    return TRUE;
	}
    }
return FALSE;
}

struct slNode *slSearch(void *sl, char *what)
{
struct slNode *this = (struct slNode *)sl;
for(; this!=NULL; this=this->next)
    {
    if(strcmp(this->name, what) == 0)
        return this;
    }
return NULL;
}


/*
boolean binaryFileIsInvalid(char *f, boolean isURL)
{
// takes file path or URL, return true if file has problem
boolean fail = FALSE;
if(isURL)
    {
    struct udcFile *tmp = udcFileMayOpen(f, "/var/www/trash");
    if(tmp == NULL)
        fail = TRUE;
    else
        udcFileClose(&tmp);
    }
else
    {
    FILE *fin = fopen(f, "rb");
    if(fin == NULL) 
        fail = TRUE;
    else
        fclose(fin);
    }
return fail;
}
*/


tabix_t *tabixOpen(char *urlpath)
{
/* open tabix file and load index!
to be used repeatedly, free after use
*/
tabix_t *fin=ti_open(urlpath,0);
if(fin==0)
	return NULL;
if(ti_lazy_index_load(fin)<0)
	return NULL;
return fin;
}

struct readitem *tabixQuery_sam(tabix_t *fin, char *querycoord)
{
/* tabix the sam file */
int chridx, begin, end;
if(ti_parse_region(fin->idx, querycoord, &chridx, &begin, &end)<0)
	{
	fprintf(stderr, "%s: coord parsing error (%s)\n", __FUNCTION__, querycoord);
	// don't abort, this could be the case when a chr (eg chrM) is not in the data file
	return NULL;
	}
struct readitem *sl=NULL, *read;
ti_iter_t iter=ti_queryi(fin, chridx, begin, end);
const char *row;
char delim[]="\t";
char *tmpstr, *tok;
int len;
while((row=ti_read(fin, iter, &len)) != 0)
	{
	tmpstr=strdup(row);
	/** FIXME memory leak here **/
	if(tmpstr==NULL)
		{
		fprintf(stderr, "%s: mem\n", __FUNCTION__);
		exit(0);
		}
	read=malloc(sizeof(struct readitem));
	// read id
	if((tok=strtok(tmpstr, delim))==NULL) continue;
	read->id=tok;
	// flag
	if((tok=strtok(NULL, delim))==NULL) continue;
	read->flag=tok;
	// chr name
	strtok(NULL,delim);
	// start
	if((tok=strtok(NULL, delim))==NULL) continue;
	if((read->start=strMayPositiveInt(tok))==-1) continue;
	read->start--;
	// chopchop
	strtok(NULL,delim);
	strtok(NULL,delim);
	strtok(NULL,delim);
	strtok(NULL,delim);
	strtok(NULL,delim);
	// seq
	if((tok=strtok(NULL, delim))==NULL) continue;
	read->seq=tok;
	read->stop=read->start+strlen(tok);
	// qual
	strtok(NULL,delim);
	// optional fields
	read->mismatch=NULL;
	tok=strtok(NULL,delim);
	while(tok!=NULL)
		{
		if(tok[0]=='M' && tok[1]=='D')
			{
			read->mismatch=tok;
			break;
			}
		tok=strtok(NULL,delim);
		}

	read->next=sl;
	sl=read;
	}
ti_iter_destroy(iter);

return sl;
}

struct beditem *tabixQuery_bed(tabix_t *fin, char *querycoord)
{
/* only query bed file
generic interval-based query over tabix file
query coord must be in the format of chr1:234-567
return NULL upon any error

the returned list is not sorted, it will be sorted on demand
as different sorting methods will be used,
e.g. sort by start, or stop
*/
int chridx, begin, end;
if(ti_parse_region(fin->idx, querycoord, &chridx, &begin, &end)<0)
	{
	fprintf(stderr, "%s: coord parsing error (%s)\n", __FUNCTION__, querycoord);
	// don't abort, this could be the case when a chr (eg chrM) is not in the data file
	return NULL;
	}
struct beditem *sl=NULL, *bi;
ti_iter_t iter=ti_queryi(fin, chridx, begin, end);
const char *row;
char delim[]="\t";
char *tmpstr, *tok, *rest;
int len;
boolean haveInvalid=FALSE;
while((row=ti_read(fin, iter, &len)) != 0)
	{
	tmpstr=strdup(row);
	/** FIXME memory leak here
	memory is allocated for tmpstr
	but it got chopped up
	don't know how to free its pieces
	*/
	if(tmpstr==NULL)
		{
		fprintf(stderr, "%s: mem\n", __FUNCTION__);
		exit(0);
		}
	bi=malloc(sizeof(struct beditem));
	// chr, discard
	if((rest=strchr(tmpstr, '\t'))==NULL)
		{ haveInvalid=TRUE; continue; }
	strtok(tmpstr, delim);
	tmpstr=++rest;
	// start
	if((rest=strchr(tmpstr, '\t'))==NULL)
		{ haveInvalid=TRUE; continue; }
	tok=strtok(tmpstr, delim);
	if((bi->start=strMayPositiveInt(tok))==-1)
		{ haveInvalid=TRUE; continue; }
	tmpstr=++rest;
	// stop
	if((rest=strchr(tmpstr, '\t'))==NULL)
		{ haveInvalid=TRUE; continue; }
	tok=strtok(tmpstr, delim);
	if((bi->stop=strMayPositiveInt(tok))==-1)
		{ haveInvalid=TRUE; continue; }
	bi->rest=++rest;

	bi->next=sl;
	sl=bi;
	}
ti_iter_destroy(iter);

if(haveInvalid)
	fprintf(stderr, "%s: failed to parse certain lines in %s\n", __FUNCTION__, fin->fn);

return sl;
}

void tabixQuery_bedgraph(tabix_t *fin, char *chrom, unsigned int start, unsigned int stop, int spnum, double *data)
{
/* only query bedgraph file
data must be already initialized with 0
*/
char *query;
if(asprintf(&query, "%s:%d-%d", chrom, start, stop)<0)
	{
	fprintf(stderr, "%s: no mem\n", __FUNCTION__);
	return;
	}

int chridx, begin, end;
if(ti_parse_region(fin->idx, query, &chridx, &begin, &end)<0)
	{
	fprintf(stderr, "%s: coord parsing error (%s)\n", __FUNCTION__, query);
	// don't abort, this could be the case when a chr (eg chrM) is not in the data file
	return;
	}
float step=((float)(stop-start))/spnum;
ti_iter_t iter=ti_queryi(fin, chridx, begin, end);
char delim[]="\t";
char *row, *tok;
int len;
unsigned int i,istart,istop,jstart,jstop;
boolean atbplevel=spnum>=(stop-start);
double value;
double *sumvalue=NULL, *sumbp=NULL;
if(!atbplevel)
	{
	if((sumvalue=malloc(sizeof(double)*spnum))==NULL)
		{
		fprintf(stderr, "%s: sumvalue out of mem\n", __FUNCTION__);
		exit(0);
		}
	if((sumbp=malloc(sizeof(double)*spnum))==NULL)
		{
		fprintf(stderr, "%s: sumbp out of mem\n", __FUNCTION__);
		exit(0);
		}
	for(i=0; i<spnum; i++)
		{
		sumvalue[i]=0;
		sumbp[i]=0;
		}
	}
/* in fact, spnum should alway <= bp length, it should never be greater than bp length
*/
while((row=ti_read(fin, iter, &len)) != 0)
	{
	// chr, discard
	strtok(row, delim);
	if((tok=strtok(NULL,delim))==NULL) continue;
	if((istart=strMayPositiveInt(tok))==-1) continue;
	if((tok=strtok(NULL,delim))==NULL) continue;
	if((istop=strMayPositiveInt(tok))==-1) continue;
	if((tok=strtok(NULL,delim))==NULL) continue;
	//fprintf(stderr, ">%d %d\n", istart, istop);
	value=strtod(tok, NULL);
	jstart=max(start,istart);
	jstop=min(stop,istop);

	if(atbplevel)
		{
		for(i=jstart; i<jstop; i++)
			data[i-start]=value;
		}
	else
		{
		// i is summary point idx
		for(i=floor((jstart-start)/step); i<=floor((jstop-start)/step); i++)
			{
			if(i>=spnum) break;
			/* overlap of the bedgraph item with the bin
			*** type cast must be enforced ***/
			double ostart=max((double)start+(double)i*step, (double)jstart);
			double ostop=min((double)start+(double)(i+1)*step, (double)jstop);
			//if(ostart>=ostop) fprintf(stderr, "%f %f\n", ostart, ostop);
			sumvalue[i]+=value*(ostop-ostart);
			sumbp[i]+=ostop-ostart;
			}
		}
	}
ti_iter_destroy(iter);
if(!atbplevel)
	{
	for(i=0; i<spnum; i++)
		{
		if(sumbp[i]>0)
			data[i]=sumvalue[i]/sumbp[i];
		}
	}
}

void *tabixQuery_regioncoord(tabix_t *fin, int ft, char *chr, unsigned int start, unsigned int stop)
{
char *query;
if(asprintf(&query, "%s:%d-%d", chr, start, stop)<0)
	fputs("mem",stderr);
if(ft==FT_bam_n||ft==FT_bam_c)
	return (void *)tabixQuery_sam(fin, query);
else if(ft==FT_bigbed_n||ft==FT_bigbed_c||ft==FT_chiapet_n||ft==FT_chiapet_c)
	return (void *)tabixQuery_bed(fin, query);
fprintf(stderr, "%s: ft not supported (%d)\n", __FUNCTION__, ft);
exit(0);
}

void *tabixQuery_region(tabix_t *fin, int ft, struct region *r)
{
return tabixQuery_regioncoord(fin, ft, chrInfo[r->chromIdx]->name, r->dstart, r->dstop);
}

void *tabixQuery_dsp(struct displayedRegion *dsp, char *urlpath, int ft)
{
/* wrapper of tabixQuery, return an array
will not sort item
will always fetch items with full information
free after use
*/
struct region *r;
int regioncount=0, dataidx=0;
for(r=dsp->head; r!=NULL; r=r->next)
	regioncount++;
void **data;

if(ft==FT_bam_n||ft==FT_bam_c)
	data=malloc(sizeof(struct beditem *)*regioncount);
else if(ft==FT_bigbed_n||ft==FT_bigbed_c||ft==FT_chiapet_n||ft==FT_chiapet_c)
	data=malloc(sizeof(struct readitem *)*regioncount);
else
	{
	fprintf(stderr, "%s: ft not supported (%d)\n", __FUNCTION__, ft);
	exit(0);
	}

tabix_t *fin=tabixOpen(urlpath);
if(fin==NULL)
	return NULL;
for(r=dsp->head; r!=NULL; r=r->next)
	{
	data[dataidx++]=tabixQuery_region(fin, ft, r);
	}
return data;
}

void tabixFreeResult(struct beditem *sl)
{
// TODO
struct beditem *bi,*prev=NULL;
for(bi=sl; bi!=NULL; bi=bi->next)
	{
	if(prev!=NULL) free(prev);
	prev=bi;
	}
if(prev!=NULL) free(prev);
}




double *tabixQuery_bedgraph_dsp(struct displayedRegion *dsp, char *urlpath)
{
/* fetch average data at summary points from bedgraph file, return pointer of array,
   free after use
   argument is url or path
   won't validate the file, must be done before calling this routine
 */
tabix_t *fin=tabixOpen(urlpath);
if(fin==NULL)
	{
	fprintf(stderr, "%s(%s) failed\n", __FUNCTION__, urlpath);
	exit(0);
	}
double *data = malloc(sizeof(double) * dsp->usedSummaryNumber);
int i;
for(i=0; i<dsp->usedSummaryNumber; i++) 
    data[i] = 0;
i = 0;
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next)
    {
    if(r->summarySize > 0)
        {
		tabixQuery_bedgraph(fin, chrInfo[r->chromIdx]->name, r->dstart, r->dstop, r->summarySize, &data[i]);
		}
    else
        {
		if(SQUAWK)
			fprintf(stderr,"%s: skipped a 0-length region...\n", __FUNCTION__);
		}
    i += r->summarySize;
    }
ti_close(fin);
return data;
}


void tabixQuery_categorical(tabix_t *fin, char *chrom, unsigned int start, unsigned int stop, int spnum, int *data)
{
/* similar as tabixQuery_bedgraph
data must be initialized to be -1 to indicate "no information"
*/
char *query;
assert(asprintf(&query, "%s:%d-%d", chrom, start, stop)>0);

int chridx, begin, end;
if(ti_parse_region(fin->idx, query, &chridx, &begin, &end)<0)
	{
	fprintf(stderr, "%s: coord parsing error (%s)\n", __FUNCTION__, query);
	// don't abort, this could be the case when a chr (eg chrM) is not in the data file
	return;
	}
float step=((float)(stop-start))/spnum;
ti_iter_t iter=ti_queryi(fin, chridx, begin, end);
char delim[]="\t";
char *row, *tok;
int len;
unsigned int i,istart,istop,jstart,jstop;
boolean atbplevel=spnum>=(stop-start);

int value;
/* to properly display categorical data at low resolution
one summary point will need to only show category of max length
use the water-level method to do that...
*/
int plenArr[spnum]; // piece length
for(i=0; i<spnum; i++)
	plenArr[i]=0;

/* in fact, spnum should alway <= bp length, it should never be greater than bp length */
while((row=ti_read(fin, iter, &len)) != 0)
	{
	strtok(row, delim); // chr, discard
	if((tok=strtok(NULL,delim))==NULL) continue;
	if((istart=strMayPositiveInt(tok))==-1) continue;
	if((tok=strtok(NULL,delim))==NULL) continue;
	if((istop=strMayPositiveInt(tok))==-1) continue;
	if((tok=strtok(NULL,delim))==NULL) continue;
	if((value=strMayPositiveInt(tok))==-1) continue;
	jstart=max(start,istart);
	jstop=min(stop,istop);

	if(atbplevel)
		{
		for(i=jstart; i<jstop; i++)
			data[i-start]=value;
		}
	else
		{
		// i is summary point idx
		for(i=floor((jstart-start)/step); i<=floor((jstop-start)/step); i++)
			{
			if(i>=spnum) break;
			// compute the actual bp len of this item inside this summary point
			int bpl=min(start+step*(i+1), jstop)-max(start+step*i, jstart);
			if(bpl>plenArr[i])
				{
				data[i]=value;
				plenArr[i]=bpl;
				}
			}
		}
	}
ti_iter_destroy(iter);
}

int *tabixQuery_categorical_dsp(struct displayedRegion *dsp, char *urlpath)
{
/* similar as tabixQuery_bedgraph_dsp
 */
tabix_t *fin=tabixOpen(urlpath);
if(fin==NULL)
	{
	fprintf(stderr, "%s(%s) failed\n", __FUNCTION__, urlpath);
	exit(0);
	}
int *data = malloc(sizeof(int) * dsp->usedSummaryNumber);
int i;
for(i=0; i<dsp->usedSummaryNumber; i++) 
    data[i] = -1;
i = 0;
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next)
    {
    if(r->summarySize > 0)
        {
		tabixQuery_categorical(fin, chrInfo[r->chromIdx]->name, r->dstart, r->dstop, r->summarySize, &data[i]);
		}
    else
        {
		if(SQUAWK)
			fprintf(stderr,"%s: skipped a 0-length region...\n", __FUNCTION__);
		}
    i += r->summarySize;
    }
ti_close(fin);
//if(SQUAWK) fprintf(stderr, "%s (%s)\n", __FUNCTION__, urlpath);
return data;
}
void printJson_categorical(struct displayedRegion *dsp, char *urlpath)
{
int *data=tabixQuery_categorical_dsp(dsp, urlpath);
int i=0, j=0;
struct region *r;
printf("[");
for(r=dsp->head; r!=NULL; r=r->next)
    {
    if(r->summarySize == 0)
        continue;
    printf("[");
    for(j=0; j<r->summarySize; j++)
        printf("%d,", data[i++]);
    printf("],");
    }
printf("],");
}
void printJson_bigwig(struct displayedRegion *dsp, char *urlpath)
{
/* including the enclosing square bracket
   won't do validity check

   FIXME whether to print out [] for regions with zero summarySize?
 */
double *data = tabixQuery_bedgraph_dsp(dsp, urlpath);
int i=0, j=0;
struct region *r;
printf("[");
for(r=dsp->head; r!=NULL; r=r->next)
    {
    if(r->summarySize == 0)
        continue;
    printf("[");
    for(j=0; j<r->summarySize; j++)
        printf("%f,", data[i++]);
    printf("],");
    }
printf("],");
}




/**************************************
            making of dsp
 **************************************/
boolean atbplevel(struct displayedRegion *dsp)
{
return dsp->usedSummaryNumber == dsp->entireLength;
}

struct chritemsl *chritemsl_searchidx(struct displayedRegion *dsp, int chrIdx)
{
struct chritemsl *ci;
for(ci=dsp->chritemsl; ci!=NULL; ci=ci->next)
	{
	if(ci->chromIdx==chrIdx)
		return ci;
	}
return NULL;
}

void chritemslAppend(struct displayedRegion *dsp, int chrIdx, struct beditem *data)
{
// add new node to head of dsp->chritemsl
struct chritemsl *ci = malloc(sizeof(struct chritemsl));
ci->chromIdx = chrIdx;
ci->itemsl = data;
ci->next = dsp->chritemsl;
dsp->chritemsl = ci;
}

void makeBorder(struct displayedRegion *dsp)
{
/* only works for genome or juxtaposition
   not gene set view
   update global variables leftBorder/rightBorder

very inefficient for the case of juxtaposition
need improvement
 */
if(dsp->juxType == 0)
    {
    leftBorder.chromIdx = 0;
    leftBorder.coord = 0;
    rightBorder.chromIdx = lastChrIdx;
    rightBorder.coord = chrInfo[lastChrIdx]->length;
	return;
    }

if(dsp->juxType!=1 && dsp->juxType!=2)
	{
    fprintf(stderr, "%s: wrong dsp->juxType", __FUNCTION__);
	exit(0);
	}

/* juxtaposition
border are determined by first/last bed items from the list of chromosomes
to find that, all the items from a chr will be fetched to find either one of that
the data shall be cached in dsp->chritemsl in case
the chr will be used again in makeRegionSl_gf()

can we guarantee the sorting of the list generated by tabixQuery? no
the left most item is used for left border
the right most item is used for right border
must explicitly test this by coordinate comparison

always keep itemsl sorted with ascending start

TODO this should be improved by sorted bed list
 */
boolean notfound = TRUE;
struct beditem *itemsl, *slsorted, *it;
for(leftBorder.chromIdx=0; leftBorder.chromIdx<=lastChrIdx; leftBorder.chromIdx++)
	{
	itemsl=tabixQuery_regioncoord(dsp->tabix, dsp->juxFt, chrInfo[leftBorder.chromIdx]->name, 0, chrInfo[leftBorder.chromIdx]->length);
	if(itemsl != NULL)
		{
		slsorted=(struct beditem *)beditemsort_startAsc((struct genericItem *)itemsl);
		/* use the first item in data as left border
		explicitly iterate to find the left most coord
		*/
		leftBorder.coord = slsorted->start;
		notfound = FALSE;
		// store for later use
		chritemslAppend(dsp, leftBorder.chromIdx, slsorted);
		if(SQUAWK)
			fprintf(stderr, "%s: juxtaposition left border - %s %d\n", __FUNCTION__, chrInfo[leftBorder.chromIdx]->name, leftBorder.coord);
		break;
		}
	}
if(notfound==TRUE)
	{
	fprintf(stderr, "%s: left border not found, the tabix file is empty?? %s\n", __FUNCTION__, dsp->tabix->fn);
	exit(0);
	}

// right border
//notfound = TRUE;
struct chritemsl *ci;
for(rightBorder.chromIdx=lastChrIdx; rightBorder.chromIdx>=0; rightBorder.chromIdx--)
	{
	/* dude! beware of such rare case
	when left/right borders are on same chr
	*/
	if((ci=chritemsl_searchidx(dsp, rightBorder.chromIdx))!=NULL)
		{
		slsorted=ci->itemsl;
		assert(slsorted!=NULL);
		}
	else
		{
		itemsl=tabixQuery_regioncoord(dsp->tabix, dsp->juxFt, chrInfo[rightBorder.chromIdx]->name, 0, chrInfo[rightBorder.chromIdx]->length);
		slsorted=(struct beditem *)beditemsort_startAsc((struct genericItem *)itemsl);
		}
	if(slsorted != NULL)
		{
		// explicitly iterate to find right most stop coord
		unsigned int maxstop=0;
		for(it=slsorted; it!=NULL; it=it->next)
			{
			if(maxstop<it->stop)
				maxstop=it->stop;
			}
		rightBorder.coord = maxstop;
		if(SQUAWK)
			fprintf(stderr, "%s: juxtaposition right border - %s %d\n", __FUNCTION__, chrInfo[rightBorder.chromIdx]->name, rightBorder.coord);
		//notfound = FALSE;
		// store for later use
		if(ci==NULL)
			chritemslAppend(dsp, rightBorder.chromIdx, slsorted);
		return;
		}
	}
}

void setDspBoundary(struct displayedRegion *dsp, int startChr, int startCoord, int stopChr, int stopCoord)
{
dsp->start = malloc(sizeof(struct point));
dsp->stop = malloc(sizeof(struct point));
dsp->start->chromIdx = startChr;
dsp->start->coord = startCoord;
dsp->stop->chromIdx = stopChr;
dsp->stop->coord = stopCoord;
if(SQUAWK) fprintf(Squawk, "%s: %s %d %s %d\n", __FUNCTION__, chrInfo[startChr]->name, startCoord, chrInfo[stopChr]->name, stopCoord);
}



void computeEntireLength(struct displayedRegion *dsp)
{
/* region list defined by dsp->head and dsp->tail must be made prior to this
 */
dsp->entireLength = 0;
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next)
    dsp->entireLength += r->dstop - r->dstart;
if(SQUAWK) fprintf(Squawk, "\tentire length computed: %ld...\n", dsp->entireLength);
}
void computeEntireLength_itemlist(struct displayedRegion *dsp)
{
// curbed by dsp->head and dsp->tail, tell tail by item name
dsp->entireLength = 0;
struct region *r;
for(r=dsp->head; ; r=r->next) 
    {
    dsp->entireLength += r->dstop - r->dstart;
    if(strcmp(r->name, dsp->tail->name) == 0) 
        break;
    }
if(SQUAWK) fprintf(Squawk, "entire length computed: %ld...\n", dsp->entireLength);
}
void computeSummarySize_bplevel(struct displayedRegion *dsp)
{
struct region *r;
dsp->usedSummaryNumber = dsp->entireLength;
for(r=dsp->head; r!=NULL; r=r->next)
    r->summarySize = r->dstop - r->dstart;
dsp->atbplevel = TRUE; // just in case
}

boolean trycomputeSummarySize_bplevel(struct displayedRegion *dsp, int spnum)
{
/* spnum: expected ceiling of summary points, usually hmSpan or 3*hmSpan?

   computeEntireLength must have been called before this
   if at bp level: 
      summary size will equal to seq length
      return true
   else:
      return false
 */
dsp->atbplevel = FALSE; // just in case
if(dsp->entireLength <= spnum)
    {
    dsp->atbplevel = TRUE;
    computeSummarySize_bplevel(dsp);
    }
return dsp->atbplevel;
}
boolean trycomputeSummarySize_bplevel_itemlist(struct displayedRegion *dsp, int spnum)
{
/* special case for trycomputeSummarySize_bplevel, need to use dsp->tail->name to terminate loop
 */
if(dsp->entireLength <= spnum)
    {
    dsp->atbplevel = TRUE;
    dsp->usedSummaryNumber = dsp->entireLength;
    struct region *r;
    for(r=dsp->head; ; r=r->next)
        {
        r->summarySize = r->dstop - r->dstart;
	if(strcmp(r->name, dsp->tail->name) == 0)
            return TRUE;
	}
    }
dsp->atbplevel = FALSE;
return FALSE;
}
void computeSummarySize(struct displayedRegion *dsp, int totalSP)
{
/* run after computeEntireLength()
   roll over regions starting from dsp->head, compute its summary size
   keep track of how many summary points have been used
   which is curbed by totalSP
   when that's going to be exhausted, truncate displayed region

   region's summary size is proportional to its length of entire length
 */
if(SQUAWK) fprintf(Squawk, "\tcomputing summary size (might truncate dsp) expected %d...\n", totalSP);

if(trycomputeSummarySize_bplevel(dsp, totalSP))
    return;

dsp->usedSummaryNumber = 0;
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next)
    {
    int remainingSize = totalSP - dsp->usedSummaryNumber;
    int thisRegionSize = ceil(((float)(r->dstop - r->dstart)/dsp->entireLength)*totalSP);
    if(thisRegionSize < remainingSize) // no equals...
        {
        r->summarySize = thisRegionSize;
	dsp->usedSummaryNumber += thisRegionSize;
	}
    else
        {
	if(SQUAWK)
	    fprintf(Squawk, "\ttotal # of summarySize exhausted (expecting %d, %d left)...\n", thisRegionSize, remainingSize);
	r->summarySize = remainingSize;
	dsp->usedSummaryNumber += remainingSize;
	break;
	}
    }
// check if there's still regions in the list
if(r->next != NULL)
    {
    // truncate, reset stop point, recalculate entire length
    r->next = NULL;
    dsp->tail = r;
    if(SQUAWK)
        fprintf(Squawk, "\tdisplayed region truncated to (%s:%d)...\n", 
		chrInfo[r->chromIdx]->name, r->dstop);
    computeEntireLength(dsp);
    }
if(SQUAWK) fprintf(Squawk, "\tsummary size computed, %d used in total...\n", dsp->usedSummaryNumber);
}
void computeSummarySize_itemlist(struct displayedRegion *dsp)
{
/* ** special treatment for itemlist **

   must run computeEntireLength_itemlist() before this

   only do for items between head/tail

   hmSpan will be expected amount of total SP
   but be intelligent, if this is too little, increase to an reasonable amount
 */

if(trycomputeSummarySize_bplevel_itemlist(dsp, hmSpan))
    return;

// find smallest region
struct region *r;
int minRegionLen = dsp->head->dstop - dsp->head->dstart;
for(r=dsp->head->next; ; r=r->next)
    {
    if(r == NULL) break;
    if(strcmp(r->name, dsp->tail->name) == 0)
        break;
    int this = r->dstop - r->dstart;
    if(this < minRegionLen)
        minRegionLen = this;
    }

//fprintf(stderr, "min length: %d\n", minRegionLen);

// divide entireLength by such smallest region length, decide totalSP in this way
int totalSP;
float spfloat = (float)dsp->entireLength / minRegionLen;
if(spfloat < hmSpan)
    totalSP = hmSpan;
else if(spfloat > hmSpan*3)
    totalSP = hmSpan * 3;
else
    totalSP = ceil(spfloat);

if(SQUAWK) fprintf(Squawk, "\tcomputing summary size (no truncation addup) expected %d...\n", totalSP);

dsp->usedSummaryNumber = 0;

for(r=dsp->head; ; r=r->next)
    {
    int thisRegionSize = ceil(((float)(r->dstop-r->dstart)/dsp->entireLength)*totalSP);
    r->summarySize = thisRegionSize;
    dsp->usedSummaryNumber += thisRegionSize;
    if(strcmp(r->name, dsp->tail->name) == 0)
        break;
    }
if(SQUAWK) fprintf(Squawk, "\tsummary size computed, %d used in total...\n", dsp->usedSummaryNumber);
}


void makeRegionSl_genome(struct displayedRegion *dsp)
{
/* setDspBoundary() must be run prior to this
   make list of regions between dsp->head and dsp->tail, 
   one region for each chromosome
 */
struct point *start = dsp->start, *stop = dsp->stop;
// CHECK
if(start->chromIdx > stop->chromIdx) errabort("makeRegionSl_genome: start chrom idx >= stop chrom idx\n");
int i;
for(i=start->chromIdx; i<=stop->chromIdx; i++)
    {
    struct region *r = malloc(sizeof(struct region));
    r->bstart = 0;
    r->bstop = chrInfo[i]->length;
    r->dstart = (i==start->chromIdx) ? start->coord : r->bstart;
    r->dstop = (i==stop->chromIdx) ? stop->coord : r->bstop;
    r->isViewStart = FALSE;
    if(r->dstart == r->dstop)
        { // omit zero-length region
	free(r);
	continue;
	}
    r->chromIdx = i;
    dspAddRegionTail(dsp, r);
    }
if(SQUAWK) fprintf(Squawk, "chromSl made...\n");
}


int requestRegionAddTail(struct displayedRegion *dsp, struct beditem *itemsl, int chrIdx, unsigned int lookstopcoord, int regionNumLimit)
{
/* only called by makeRegionSl_gf()
itemsl must have already been sorted by ascending start coord

lookstopcoord: 0 means no curb

request new regions from raw item data from chromosome query, as prepared by makeChritemsl()
region means a continuous segment connected by bed items
# of regions will be capped by given number
return # of regions added
new region will be added to tail of dsp region list

works on one chr for each call
 */

assert(itemsl!=NULL);
if(regionNumLimit<=0) return 0;

// first bed item
int rstart = itemsl->start;
int rstop = itemsl->stop;
if(lookstopcoord>0 && rstart>=lookstopcoord) return 0;
int count = 0;
struct region *r;
struct beditem *t;
for(t=itemsl->next; t!=NULL; t=t->next)
    {
    // merge bed items when they overlap or are head-tail connected
	if(lookstopcoord>0)
		{
		if(t->start >= lookstopcoord)
			break;
		}
    if(rstop >= t->start)
		{
        rstop = (t->stop > rstop) ? t->stop : rstop;
		}
    else
		{
		/* current item is outside of existing range
		yield new region with existing range */
        r = malloc(sizeof(struct region));
		r->bstart = r->dstart = rstart;
		r->bstop = r->dstop = rstop;
		r->chromIdx = chrIdx;
		r->isViewStart = FALSE;
		dspAddRegionTail(dsp, r);
		count++;
		if(count == regionNumLimit) return count;
		// range initiated with current item
		rstart = t->start;
		rstop = t->stop;
		}
    }
// itemsl exhausted, make one last region
r = malloc(sizeof(struct region));
r->bstart = r->dstart = rstart;
r->bstop = r->dstop = rstop;
r->chromIdx = chrIdx;
r->isViewStart = FALSE;
dspAddRegionTail(dsp, r);
count++;
return count;
}

void makeChritemsl(struct displayedRegion *dsp)
{
/* separated from makeRegionSl_gf() to reduce indent level

find bed items covered by given boundary
if there's anything within boundaries, fill them in dsp->chritemsl
won't change dsp->start, dsp->stop

keep itemsl sorted by ascending start
*/

// try to make chritemsl object for all chromosomes between dsp->start/stop
int i = dsp->start->chromIdx;
boolean foundsth=FALSE;
struct beditem *itemsl, *slsorted;
for(; i<=dsp->stop->chromIdx; i++)
    {
	if(chritemsl_searchidx(dsp, i)!=NULL)
		{
		foundsth=TRUE;
		continue;
		}
	itemsl=tabixQuery_regioncoord(dsp->tabix, dsp->juxFt, chrInfo[i]->name, 0, chrInfo[i]->length);
	if(itemsl!=NULL)
		{
		slsorted=(struct beditem *)beditemsort_startAsc((struct genericItem *)itemsl);
		chritemslAppend(dsp, i, slsorted);
		foundsth=TRUE;
		}
	else
		{
		// got nothing from this query
		if(i==dsp->start->chromIdx && i==dsp->stop->chromIdx)
			{
			/* start/stop points are both within this chr
			not good, need to search remaining of this chr
			*/
			itemsl=tabixQuery_regioncoord(dsp->tabix, dsp->juxFt, chrInfo[i]->name, dsp->stop->coord, chrInfo[i]->length);
			if(itemsl!=NULL)
				{
				slsorted=(struct beditem *)beditemsort_startAsc((struct genericItem *)itemsl);
				chritemslAppend(dsp, i, slsorted);
				foundsth=TRUE;
				}
			}
		}
	}

if(foundsth) return;

/*  haven't found anything with above queries
need to seek to chrs behind stop point and issue additional queries
but won't go to chrs before start point, as makeBorder() has already filled things there...
quit upon finding anything...
*/
for(i=dsp->stop->chromIdx+1; i<=lastChrIdx; i++)
	{
	if(chritemsl_searchidx(dsp, i)!=NULL) return;
	itemsl=tabixQuery_regioncoord(dsp->tabix, dsp->juxFt, chrInfo[i]->name, 0, chrInfo[i]->length);
	if(itemsl!=NULL)
		{
		slsorted=(struct beditem *)beditemsort_startAsc((struct genericItem *)itemsl);
		chritemslAppend(dsp, i, slsorted);
		return;
		}
	}
/* it probably doesn't matter if execution would go here
as something must already been made in makeBorder()
*/
}

void makeRegionSl_gf(struct displayedRegion *dsp)
{
/* setDspBoundary() must be called prior to this
   first make dsp->chritemsl
   then determine dsp region by dsp->chritemsl
   curb region # by hmSpan
 */
if(SQUAWK)
    fputs("makeRegionSl_gf:\n", Squawk);

makeChritemsl(dsp);

struct chritemsl *ci;

if(SQUAWK)
    {
	// turn it off after debugging
	fputs("\tshow dsp->chritemsl ...\n", stderr);
	for(ci=dsp->chritemsl; ci!=NULL; ci=ci->next)
		fprintf(Squawk, "\t\t%s %d bed items\n", chrInfo[ci->chromIdx]->name, slCount2(ci->itemsl));
	fputs("\tdsp->chritemsl over\n", stderr);
    }

/*  will generate dsp regions based on chr raw data
try to exhaust bed data between dsp start/stop chromosomes
*/
int chrIdx;
int totalRegionAdded=0;
struct beditem *item;
for(chrIdx=dsp->start->chromIdx; chrIdx<=dsp->stop->chromIdx; chrIdx++)
	{
	if((ci=chritemsl_searchidx(dsp, chrIdx))!=NULL)
		{
		/* if the chr is dsp start/stop chr,
		need to curb the looking item by start/stop coord!!
		*/
		item=ci->itemsl;
		if(chrIdx==dsp->start->chromIdx)
			{
			for(; item!=NULL; item=item->next)
				{
				if(item->stop>dsp->start->coord)
					break;
				}
			}
		if(item==NULL) continue;
		unsigned int lookstopcoord= chrIdx==dsp->stop->chromIdx ? dsp->stop->coord : 0;

		totalRegionAdded += requestRegionAddTail(dsp, item, chrIdx, lookstopcoord, hmSpan-totalRegionAdded);
		if(totalRegionAdded >= hmSpan) break;
		}
	}
if(totalRegionAdded>0)
	{
	if(SQUAWK)
		fprintf(stderr, "\t%d regions generated between dsp start/stop\n", totalRegionAdded);
	}
else
	{
	/* no regions generated between dsp start/stop points
	look to the chrs on the right of dsp->stop
	*/
	for(chrIdx=dsp->stop->chromIdx+1; chrIdx<=lastChrIdx; chrIdx++)
		{
		if((ci=chritemsl_searchidx(dsp, chrIdx))!=NULL)
			{
			totalRegionAdded += requestRegionAddTail(dsp, ci->itemsl, chrIdx, 0, hmSpan-totalRegionAdded);
			if(totalRegionAdded >= hmSpan) break;
			}
		}
	if(totalRegionAdded==0)
		{
		/* still no regions added, start from the very first chr */
		for(chrIdx=0; chrIdx<=lastChrIdx; chrIdx++)
			{
			if((ci=chritemsl_searchidx(dsp, chrIdx))!=NULL)
				{
				totalRegionAdded += requestRegionAddTail(dsp, ci->itemsl, chrIdx, 0, hmSpan-totalRegionAdded);
				if(totalRegionAdded >= hmSpan) break;
				}
			}
		}
	}

 
/****** FIXME ******
   requestRegionAddTail() will set dstart/dstop same as bstart/bstop
   but for cases like drawing decor in juxtaposition mode
   dsp head/tail might have different dstart/dstop according to CGI param,

   if dsp->start is within dsp->head, reset head->dstart using start->coord,
   if dsp->stop is within dsp->tail, reset tail->dstop using stop->coord
   
   is this reliable??
 *******************/
if((dsp->start->chromIdx == dsp->head->chromIdx) &&
   (dsp->start->coord >= dsp->head->bstart) &&
   (dsp->start->coord <= dsp->head->bstop))
    {
    if(SQUAWK) fputs("\treset dsp->head->dstart using dsp->start->coord\n", Squawk);
    dsp->head->dstart = dsp->start->coord;
    }
if((dsp->stop->chromIdx == dsp->tail->chromIdx) &&
   (dsp->stop->coord >= dsp->tail->bstart) &&
   (dsp->stop->coord <= dsp->tail->bstop))
    {
    if(SQUAWK) fputs("\treset dsp->tail->dstop using dsp->stop->coord\n", Squawk);
    dsp->tail->dstop = dsp->stop->coord;
    }
if(SQUAWK) 
    {
    int i=0;
    struct region *r;
    for(r=dsp->head; r!=NULL; r=r->next) i++;
    fprintf(Squawk, "\tregionLst made, %d in total...\n", i);
    }
}



void extendRegionDstart(struct region *r, double spsize, int *spnum, boolean atbplevel)
{
/* extend region's dstart to left by trying fit in a number of summary points
   region's attributes must be initialized:
   - summarySize
   - bstart
   - dstart
 */
if(r->dstart <= r->bstart)
    return;
if(*spnum == 0)
    return;
int dist = (int)(spsize * *spnum); // dist to move in bp
if(atbplevel)
    {
    int this = r->dstart - r->bstart; // available bp
    if(this >= dist)
        {
        r->summarySize += *spnum;
        r->dstart -= dist;
        *spnum = 0;
        }
    else
        {
        r->dstart = r->bstart;
        r->summarySize += (int)(this/spsize);
        *spnum -= (int)(this/spsize);
        }
    }
else
    {
    double this = (r->dstart - r->bstart) / spsize;
    if(this >= *spnum)
        {
        r->summarySize += *spnum;
        r->dstart -= dist;
        *spnum = 0;
        }
    else
        {
        r->dstart = r->bstart;
        r->summarySize += ceil(this);
        *spnum -= ceil(this);
        }
    }
}
void extendRegionDstop(struct region *r, double spsize, int *spnum, boolean atbplevel)
{
/* extend region's dstop to right by trying to region's attributes must be initialized:
   - summarySize
   - bstop
   - dstop
 */
if(r->dstop >= r->bstop)
    return;
if(*spnum == 0)
    return;
int dist = (int)(spsize * *spnum); // dist to move in bp
if(atbplevel)
    {
    int this = r->bstop - r->dstop;
    if(this >= dist)
        {
        r->summarySize += *spnum;
        r->dstop += dist;
        *spnum = 0;
        }
    else
        {
        r->dstop = r->bstop;
        r->summarySize += (int)(this/spsize);
        *spnum -= (int)(this/spsize);
        }
    }
else
    {
    double this = (r->bstop - r->dstop) / spsize;
    if(this >= *spnum)
        {
        r->summarySize += *spnum;
        r->dstop += dist;
        *spnum = 0;
        }
    else
        {
        r->dstop = r->bstop;
        r->summarySize += ceil(this);
        *spnum -= ceil(this);
        }
    }
}



long moveBoundary_genome(struct displayedRegion *dsp, char side, long distance, int *spnum, double spsize)
{
if(SQUAWK)
    fprintf(stderr, "moveBoundary_genome distance: %ld spnum: %d spsize: %f\n", distance, *spnum, spsize);
/* move a point along genome, out side of existing list, 
   always need to extend/add new regions to list

   args:
       side: 'l' for moving dsp->head to left
             'r' for moving dsp->tail to right
       distance: distance in bp to be moved
       spnum: number of expected summary point to allocate
       spsize: # bp each summary point spans

   return 0 when all distance moved successfully
   else if hit border, return remaining distance not moved
 */
int oldpos;
while(distance > 0)
    {
    if(side == 'l')
        {
	struct region *head = dsp->head;
	oldpos = head->dstart;
	extendRegionDstart(head, spsize, spnum, dsp->atbplevel);
	distance -= oldpos - head->dstart;
	if(distance <= 0) // is this possible??
	    return 0;
	if(*spnum == 0)
	    return distance;
	if(head->chromIdx == leftBorder.chromIdx) // hit left border
	    return distance;
	// not hitting left border, step into one chromosome on left...
	struct region *r = malloc(sizeof(struct region));
	r->chromIdx = head->chromIdx-1;
	r->bstart = 0;
	r->bstop = chrInfo[r->chromIdx]->length;
	r->dstart = r->bstop;
	r->dstop = r->bstop;
	r->summarySize = 0;
	r->isViewStart = FALSE;
	dspAddRegionHead(dsp, r);
	}
    else
        {
	struct region *tail = dsp->tail;
	oldpos = tail->dstop;
	extendRegionDstop(tail, spsize, spnum, dsp->atbplevel);
	distance -= tail->dstop - oldpos;
	if(distance <= 0)
	    return 0;
	if(*spnum == 0)
	    return distance;
	if(tail->chromIdx == rightBorder.chromIdx) // hit right border
	    return distance;
	// not hitting right border, step into one chromosome on right...
	struct region *r = malloc(sizeof(struct region));
	r->chromIdx = tail->chromIdx +1;
	r->bstart = 0;
	r->bstop = chrInfo[r->chromIdx]->length;
	r->dstart = 0;
	r->dstop = 0;
	r->summarySize = 0;
	r->isViewStart = FALSE;
	dspAddRegionTail(dsp, r);
	}
    }
return 0;
}




struct region *newRegionFromBeditem(int chrIdx, struct beditem *item)
{
// dstart/dstop will be unspecified!!
struct region *r = malloc(sizeof(struct region));
r->chromIdx = chrIdx;
r->bstop = item->stop;
r->bstart = item->start;
r->summarySize = 0;
r->isViewStart = FALSE;
return r;
}





void moveBoundary_gf_left(struct displayedRegion *dsp, long distance, int spnum)
{
/* juxtaposition
dsp region list must already have summary size computed
allowed moving distance and summary point number given

cached chr itemsl will be used, but will be sorted by stop coord!
 */
struct region *hRegion = dsp->head;
if(SQUAWK) fprintf(Squawk, "\tmoveBoundary_gf_left: from %s:%d to left by (%ld, %d)...\n", chrInfo[hRegion->chromIdx]->name, hRegion->dstart, distance, spnum);

double spsize = (double)distance / spnum;

// remaining distance in head region
extendRegionDstart(hRegion, spsize, &spnum, dsp->atbplevel);
if(spnum <= 0) return;

// fetch new bed items on left in *same chr* as head region
struct chritemsl *ci=chritemsl_searchidx(dsp, hRegion->chromIdx);
assert(ci!=NULL); // believe it can never be null
// sort by descending stop coord
struct beditem *itemsl=(struct beditem *)beditemsort_stopDsc((struct genericItem *)ci->itemsl);
// replace existing record
ci->itemsl=itemsl;
struct beditem *item;

/* try extending current head with overlaping bed items */
for(item=itemsl; item!=NULL; item=item->next)
	{
	if(item->stop >= hRegion->bstart)
		{
		if(item->start < hRegion->bstart)
			{
			// head bstart extendable with new item
			hRegion->bstart = item->start;
			}
		}
	else
		{
		// new item beyond head, stop
		break;
		}
	}
extendRegionDstart(hRegion, spsize, &spnum, dsp->atbplevel);
if(spnum <= 0) return;

if(item != NULL)
	{
	/* form new regions using remaining bed items in this chromosome 
	will append to head
	*/
	struct region *r = newRegionFromBeditem(hRegion->chromIdx, item);
	r->dstart = r->dstop = r->bstop; // set displayed portion as zero length
	// extend this region
	for(item=item->next; item!=NULL; item=item->next)
		{
		if(item->stop >= r->bstart)
			{
			if(item->start < r->bstart) // extend current region
				r->bstart = item->start;
			}
		else
			{
			// current region stops
			extendRegionDstart(r, spsize, &spnum, dsp->atbplevel);
			dspAddRegionHead(dsp, r);
			if(spnum <= 0) return;

			// if the program continues, create another region, initiate using current bed item
			r = newRegionFromBeditem(hRegion->chromIdx, item);
			r->dstart = r->dstop = r->bstop;
			}
		}
	extendRegionDstart(r, spsize, &spnum, dsp->atbplevel);
	dspAddRegionHead(dsp, r);
	if(spnum <= 0) return;
	}

/* looping through remaining chromosomes on left of h->chromIdx
   form new regions,
   add to head
 */
int chrIdx = hRegion->chromIdx -1;
//fputs("entering while loop...\n", stderr);
while(chrIdx >= 0)
    {
	itemsl=NULL;
	if((ci=chritemsl_searchidx(dsp, chrIdx))!=NULL)
		{
		itemsl=(struct beditem *)beditemsort_stopDsc((struct genericItem *)ci->itemsl);
		ci->itemsl=itemsl;
		}
	else
		{
		struct beditem *sl2=tabixQuery_regioncoord(dsp->tabix, dsp->juxFt, chrInfo[chrIdx]->name, 0, chrInfo[chrIdx]->length);
		if(sl2!=NULL)
			{
			itemsl=(struct beditem *)beditemsort_stopDsc((struct genericItem *)sl2);
			chritemslAppend(dsp, chrIdx, itemsl);
			}
		}
    if(itemsl == NULL)
        {
        chrIdx--;
        continue;
		}

    // received data for this chr, repeat above practice
	item=itemsl;
    struct region *r = newRegionFromBeditem(chrIdx, item);
    r->dstart = r->dstop = r->bstop;
    for(item=item->next; item!=NULL; item=item->next)
        {
		if(item->stop >= r->bstart)
			{
			if(item->start < r->bstart)
				r->bstart = item->start;
			}
		else
			{
			extendRegionDstart(r, spsize, &spnum, dsp->atbplevel);
			dspAddRegionHead(dsp, r);
			if(spnum <= 0) return;
			r = newRegionFromBeditem(chrIdx, item);
			r->dstart = r->dstop = r->bstop;
			}
		}
    extendRegionDstart(r, spsize, &spnum, dsp->atbplevel);
    dspAddRegionHead(dsp, r);
    if(spnum <= 0) return;
    chrIdx--;
    }
}



void moveBoundary_gf_right(struct displayedRegion *dsp, long distance, int spnum) 
{
/* growing on right
must re-sort all itemsl as it might have been modified in moveBoundary_gf_left()
*/
struct region *tRegion = dsp->tail;
if(SQUAWK) fprintf(Squawk, "\tmoveBoundary_gf_right: from %s:%d to right by (%ld, %d)...\n", chrInfo[tRegion->chromIdx]->name, tRegion->dstop, distance, spnum);

double spsize = (double)distance / spnum;

extendRegionDstop(tRegion, spsize, &spnum, dsp->atbplevel);
if(spnum <= 0) return;

// look for new bed items on right in tail chromosome
struct chritemsl *ci=chritemsl_searchidx(dsp, tRegion->chromIdx);
assert(ci!=NULL);
struct beditem *itemsl=(struct beditem *)beditemsort_startAsc((struct genericItem *)ci->itemsl);
struct beditem *item;
ci->itemsl=itemsl;
/* try extending tail with overlaping bed items */
for(item=itemsl; item!=NULL; item=item->next)
	{
	if(item->start <= tRegion->bstop)
		{
		if(item->stop > tRegion->bstop)
			{
			// tail extendable by this item
			tRegion->bstop = item->stop;
			}
		}
	else
		{
		// item beyond tail, stop
		break;
		}
	}
extendRegionDstop(tRegion, spsize, &spnum, dsp->atbplevel);
if(spnum <= 0) return;

if(item != NULL)
	{
	/* form new regions using remaining bed items in this chromosome */
	struct region *r = newRegionFromBeditem(tRegion->chromIdx, item);
	r->dstart = r->dstop = r->bstart;
	for(item=item->next; item!=NULL; item=item->next)
		{
		if(item->start <= r->bstop)
			{
			if(item->stop > r->bstop)
				r->bstop = item->stop;
			}
		else
			{
			// current region stops
			extendRegionDstop(r, spsize, &spnum, dsp->atbplevel);
			dspAddRegionTail(dsp, r);
			if(spnum <= 0) return;
			
			// if program continues, make new region
			r = newRegionFromBeditem(tRegion->chromIdx, item);
				r->dstart = r->dstop = r->bstart;
			}
		}
		extendRegionDstop(r, spsize, &spnum, dsp->atbplevel);
		dspAddRegionTail(dsp, r);
		if(spnum <= 0) return;
	}

/* looping through remaining chromosomes on right of tRegion->chromIdx
   form new regions,
   add to tail
 */
int chrIdx = tRegion->chromIdx +1;
while(chrIdx <= lastChrIdx)
    {
	itemsl=NULL;
	if((ci=chritemsl_searchidx(dsp, chrIdx))!=NULL)
		{
		itemsl=(struct beditem *)beditemsort_startAsc((struct genericItem *)ci->itemsl);
		ci->itemsl=itemsl;
		}
	else
		{
		struct beditem *sl2=tabixQuery_regioncoord(dsp->tabix, dsp->juxFt, chrInfo[chrIdx]->name, 0, chrInfo[chrIdx]->length);
		if(sl2!=NULL)
			{
			itemsl=(struct beditem *)beditemsort_startAsc((struct genericItem *)sl2);
			chritemslAppend(dsp, chrIdx, sl2);
			}
		}
    if(itemsl == NULL)
        {
		chrIdx++;
		continue;
		}
	item=itemsl;
    struct region *r = newRegionFromBeditem(chrIdx, item);
    r->dstart = r->dstop = r->bstart;
    for(item=item->next; item!=NULL; item=item->next)
        {
		if(item->start <= r->bstop)
			{
			if(item->stop > r->bstop)
				r->bstop = item->stop;
			}
		else
			{
			extendRegionDstop(r, spsize, &spnum, dsp->atbplevel);
			dspAddRegionTail(dsp, r);
			if(spnum <= 0) return;
			r = newRegionFromBeditem(chrIdx, item);
				r->dstart = r->dstop = r->bstart;
			}
        }
    extendRegionDstop(r, spsize, &spnum, dsp->atbplevel);
    dspAddRegionTail(dsp, r);
    if(spnum <= 0) return;
    chrIdx++;
    }
}


void computeUsedSummaryNumber(struct displayedRegion *dsp)
{
struct region *r;
dsp->usedSummaryNumber = 0;
for(r=dsp->head; r!=NULL; r=r->next)
    dsp->usedSummaryNumber += r->summarySize;
}

void finalizeDsp_gf(struct displayedRegion *dsp)
{
/* call this after running setDspBoundary()
   trigger_move will not come to this step, only others will

          |--left wing--|========DSP========|--right wing--|

   DSP will have hmSpan number of summary points,
   # of summary points for left/right wing will be given by their
   length proportional to dsp.entireLength

   make expansion to wing regions:
   - make regions (head/tail) if it's not there yet
   - compute entire length for DSP
   - seek left boundary to left by entireLength
   - compute left wing # of summary points (leftSPnum)
   - set dspStart
   - seek right boundary to right by entireLength
   - compute right wing # of summary points (rightSPnum)
   - recompute entire length for expanded DSP
   - recompute summary size for expanded DSP using (leftSPnum+hmSpan+rightSPnum)
 */
if(SQUAWK) fputs("finalizeDsp_gf()...\n", Squawk);
if(dsp->head == NULL)
    {
    if(dsp->tail == NULL)
        makeRegionSl_gf(dsp);
    else
        errabort("dsp->head is null but dsp->tail is NOT NULL");
    }
// set all rest regions as NOT being VIEW START
struct region *r;
for(r=dsp->head->next; r!=NULL; r=r->next)
    r->isViewStart = FALSE;
// and all the *wing* regions will be set as similar

// dsp->head is view start
dsp->head->isViewStart = TRUE;
dsp->head->viewStartCoord = dsp->head->dstart;

/* in order to get resolution size, first compute summary size of existing region list
   then use this resolution size to compute spnum for left/right wings
 */
computeEntireLength(dsp);
computeSummarySize(dsp, hmSpan);

// to remember if it should be at bp level, do special things after making wings...

moveBoundary_gf_left(dsp, dsp->entireLength, dsp->usedSummaryNumber);
moveBoundary_gf_right(dsp, dsp->entireLength, dsp->usedSummaryNumber);

computeEntireLength(dsp);

if(dsp->atbplevel)
    {
    // reassign summary size for each region using region seq length
    computeSummarySize_bplevel(dsp);
    }
else
    {
    computeUsedSummaryNumber(dsp);
    }
}




void finalizeDsp_genome(struct displayedRegion *dsp)
{
if(SQUAWK) fputs("finalizeDsp_genome()...\n", Squawk);
if(dsp->head == NULL)
    {
    if(dsp->tail == NULL)
        makeRegionSl_genome(dsp);
    else
        errabort("dsp->head is null but dsp->tail is NOT NULL");
    }
// set all rest regions as NOT being VIEW START
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next)
    r->isViewStart = FALSE;
// and all the *wing* regions will be set as similar

// dsp->head is view start
dsp->head->isViewStart = TRUE;
dsp->head->viewStartCoord = dsp->head->dstart;

computeEntireLength(dsp);

if(trycomputeSummarySize_bplevel(dsp, hmSpan))
    {
    computeUsedSummaryNumber(dsp);
    if(SQUAWK) fputs("\tnow at bp level\n", stderr);
    int a = dsp->usedSummaryNumber;
    moveBoundary_genome(dsp, 'l', dsp->entireLength, &a, 1);
    a = dsp->usedSummaryNumber;
    moveBoundary_genome(dsp, 'r', dsp->entireLength, &a, 1);
    computeUsedSummaryNumber(dsp);
    return;
    }

// assign hmSpan points to current dsp
computeSummarySize(dsp, hmSpan);
double sf = ((double)dsp->entireLength / dsp->usedSummaryNumber);

int spn = hmSpan;
moveBoundary_genome(dsp, 'l', dsp->entireLength, &spn, sf);
spn = hmSpan;
moveBoundary_genome(dsp, 'r', dsp->entireLength, &spn, sf);
computeEntireLength(dsp);
computeUsedSummaryNumber(dsp);
}




/**********************************
         move/zoom
 **********************************/

boolean dspAtLeftBorder(struct displayedRegion *dsp)
{
/* if at left border, return TRUE
   if downstream of left border, return FALSE
   else, squawk and die
 */
if(dsp->head->chromIdx > leftBorder.chromIdx)
    return FALSE;
if(dsp->head->chromIdx == leftBorder.chromIdx)
    {
    if(dsp->head->dstart == leftBorder.coord)
        return TRUE;
    if(dsp->head->dstart > leftBorder.coord)
        return FALSE;
    errabort("dsp left boundary beyond left border");
    }
errabort("dsp left boundary beyond left border");
return FALSE; // merely not to let compiler complain
}


boolean dspAtRightBorder(struct displayedRegion *dsp)
{
if(dsp->tail->chromIdx < rightBorder.chromIdx)
    return FALSE;
if(dsp->tail->chromIdx == rightBorder.chromIdx)
    {
    if(dsp->tail->dstop == rightBorder.coord)
        return TRUE;
    if(dsp->tail->dstop < rightBorder.coord)
        return FALSE;
    errabort("dsp right boundary beyond right border");
    }
errabort("dsp right boundary beyond right border");
return FALSE; // merely...
}


long moveBoundary_list_which(struct displayedRegion *dsp, char which, char side, long distance)
{
/* same code for genome/gf 

   args:
      which: h/t telling if it's head or tail that moves
      side: l/r to which side

   ** sort out the logic carefully ***
   move boundary within list of regions defined by dsp->head and dsp->tail
   and look at dstart/dstop of each region
   direction: 'l' for moving point to left, 'r' to right

   return current point
 */
if(which!='h' && which!='t') errabort("moveBoundary_list_which: which must be h/t");
if(side!='l' && side!='r') errabort("moveBoundary_list_which: side must be l/r");
if(SQUAWK) fprintf(stderr, "\tmoveBoundary_list_which: which (%c) side (%c) dist (%ld)\n", which, side, distance);
struct region *glider;
if(which == 'h')
    {
    // moving head, only modify dstart
    glider = dsp->head;
    if(side == 'r')
        { // shrink
        while(distance > 0)
            {
	    int movableDist = glider->bstop - glider->dstart;
	    if(distance < movableDist)
	        {
	        glider->dstart += distance;
	        distance = 0;
	        break;
	        }
	    distance -= movableDist;
	    glider->dstart = glider->bstop;
	    if(glider->next == NULL) break;
	    glider = glider->next;
	    glider->dstart = glider->bstart;
            }
	}
    else
        { // expand
	while(distance > 0)
	    {
	    int movableDist = glider->dstart - glider->bstart;
	    if(distance < movableDist)
	        {
	        glider->dstart -= distance;
	        distance = 0;
	        break;
	        }
	    distance -= movableDist;
	    glider->dstart = glider->bstart;
	    if(glider->prev == NULL) break;
	    glider = glider->prev;
	    glider->dstart = glider->dstop = glider->bstop; // enforced
            }
        }
    dsp->head = glider;
    }
else
    {
    // moving tail, only modify dstop
    glider = dsp->tail;
    if(side == 'r')
        { // expand
        while(distance > 0)
            {
	    int movableDist = glider->bstop - glider->dstop;
	    if(distance < movableDist)
	        {
	        glider->dstop += distance;
	        distance = 0;
	        break;
	        }
	    distance -= movableDist;
	    glider->dstop = glider->bstop;
	    if(glider->next == NULL) break;
	    glider = glider->next;
	    glider->dstop = glider->dstart = glider->bstart; // enforced
            }
	}
    else
        { // shrink
        while(distance > 0)
	    {
	    int movableDist = glider->dstop - glider->bstart;
	    if(distance < movableDist)
	        {
	        glider->dstop -= distance;
	        distance = 0;
	        break;
	        }
	    distance -= movableDist;
	    glider->dstop = glider->bstart;
	    if(glider->prev == NULL) break;
	    glider = glider->prev;
	    glider->dstop = glider->bstop; // enforced
            }
        }
    dsp->tail = glider;
    }
return distance;
}

void moveBoundary_list(struct displayedRegion *dsp, char side, long distance)
{
// wrapper of moveBoundary_list_which
if(side!='l' && side!='r') errabort("moveBoundary_list: side must be l/r");
if(side == 'l') // move head to right
    moveBoundary_list_which(dsp, 'h', 'r', distance);
else // move tail to left
    moveBoundary_list_which(dsp, 't', 'l', distance);
}





/***********************
   ITEMlist-specific functions
 **********************/
void genesetRuntime_insert(char *session, int statusId, char *itemlist)
{
char *query;
if(asprintf(&query, "delete from genesetRuntime where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
mysqlUpdate(query);
free(query);
if(asprintf(&query, "insert into genesetRuntime values('%s', %d, '%s')", session, statusId, itemlist)<0) errabort("bae");
mysqlUpdate(query);
free(query);
}
int itemlistsort_lenAsc(const void *a, const void *b)
{
// item length, ascending
const struct region *aa = (const struct region *)a;
const struct region *bb = (const struct region *)b;
int alen = aa->bstop - aa->bstart;
int blen = bb->bstop - bb->bstart;
return (alen > blen) - (alen < blen);
}
int itemlistsort_lenDesc(const void *a, const void *b)
{
// item length, descending
const struct region *aa = (const struct region *)a;
const struct region *bb = (const struct region *)b;
int alen = aa->bstop - aa->bstart;
int blen = bb->bstop - bb->bstart;
return (alen < blen) - (alen > blen);
}
int itemlistsort_tkmeanAsc(const void *a, const void *b)
{
// average track score, ascending
const struct region *aa = (const struct region *)a;
const struct region *bb = (const struct region *)b;
return (aa->fvalue > bb->fvalue) - (aa->fvalue < bb->fvalue);
}
int itemlistsort_tkmeanDesc(const void *a, const void *b)
{
// average track score, descending
const struct region *aa = (const struct region *)a;
const struct region *bb = (const struct region *)b;
return (aa->fvalue < bb->fvalue) - (aa->fvalue > bb->fvalue);
}
int itemlistsort_coord(const void *a, const void *b)
{
// item length, coordinate
const struct region *aa = (const struct region *)a;
const struct region *bb = (const struct region *)b;
if(aa->chromIdx != bb->chromIdx)
    return (aa->chromIdx > bb->chromIdx) - (aa->chromIdx < bb->chromIdx);
if(aa->bstart != bb->bstart)
    return (aa->bstart > bb->bstart) - (aa->bstart < bb->bstart);
return (aa->bstop > bb->bstop) - (aa->bstop < bb->bstop);
}
int getChromIdxByItemname(struct displayedRegion *dsp, char *itemname)
{
// regionSL must have been made
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next)
    {
    if(strcmp(r->name, itemname) == 0)
        return r->chromIdx;
    }
errabort("getChromIdxByItemname: item name not found in regionSL");
return -1;
}
void trimRegionSl_itemlist(struct displayedRegion *dsp, char *startItem, int startCoord, char *stopItem, int stopCoord)
{
/* regionSl between dsp->head/tail must be made
   and will seek for boundary inside this list
 */
struct region *r;
boolean headmissing=TRUE, tailmissing=TRUE;
for(r=dsp->head; r!=NULL; r=r->next)
    {
    if(strcmp(r->name, startItem) == 0)
        {
	r->dstart = startCoord;
	dsp->head = r;
	headmissing = FALSE;
	}
    if(strcmp(r->name, stopItem) == 0)
        {
	r->dstop = stopCoord;
	dsp->tail = r;
	tailmissing = FALSE;
	break;
	}
    }
if(headmissing) errabort("head item ID not found in regionSl");
if(tailmissing) errabort("head item ID not found in regionSl");
if(SQUAWK) fprintf(Squawk, "trimRegionSl_itemlist: head (%s) tail (%s)...\n", dsp->head->name, dsp->tail->name);
}

boolean dspRestoreByCleanItemlist(struct displayedRegion *dsp, char *session, int statusId)
{
/* itemlist is what's stored in collateitemlist.itemlist, must be clean and safe,
   use it to restore dsp, will make regionSl for all items, and might be modified later on
   upon error, return FALSE

   this is complete item list
 */
char *savedString = getItemlistfromdb(session, statusId);
if(savedString == NULL)
    return FALSE;

char delim[] = ",";
struct region *r;
char *tok = strtok(savedString, delim); assert(tok!=NULL);
while(tok != NULL)
    {
    r = malloc(sizeof(struct region));
    if(asprintf(&r->name, "%s", tok)<0) errabort("bae");
    assert((tok=strtok(NULL, delim))!=NULL);
    assert((r->chromIdx=strMayPositiveInt(tok))!=-1);
    assert((tok=strtok(NULL, delim))!=NULL);
    assert((r->bstart=r->dstart=strMayPositiveInt(tok))!=-1);
    assert((tok=strtok(NULL, delim))!=NULL);
    assert((r->bstop=r->dstop=strMayPositiveInt(tok))!=-1);
	// following values must be present but could be -1 indicating 'not applicable'
    assert((tok=strtok(NULL, delim))!=NULL);
    r->flank5start=strMayPositiveInt(tok);
    assert((tok=strtok(NULL, delim))!=NULL);
    r->flank5stop=strMayPositiveInt(tok);
    assert((tok=strtok(NULL, delim))!=NULL);
    r->flank3start=strMayPositiveInt(tok);
    assert((tok=strtok(NULL, delim))!=NULL);
    r->flank3stop=strMayPositiveInt(tok);
    r->isViewStart = FALSE;
    dspAddRegionTail(dsp, r);
    tok = strtok(NULL, delim);
    }
return TRUE;
}

void makeDspWing_itemlist(struct displayedRegion *dsp)
{
/* do this after dsp->head/tail are made
   first flip head->isViewStart

   make wings by summary size
 */
if(SQUAWK) fputs("makeDspWing_itemlist()...\n", stderr);
dsp->head->isViewStart = TRUE;
dsp->head->viewStartCoord = dsp->head->dstart;
computeEntireLength_itemlist(dsp);

if(trycomputeSummarySize_bplevel_itemlist(dsp, hmSpan))
    {
    moveBoundary_list_which(dsp, 'h', 'l', dsp->entireLength);
    moveBoundary_list_which(dsp, 't', 'r', dsp->entireLength);
    dsp->head->prev = NULL;
    dsp->tail->next = NULL;
    computeEntireLength(dsp);
    computeSummarySize_bplevel(dsp);
    return;
    }
    
computeSummarySize_itemlist(dsp);

float spsize = (float)dsp->entireLength / dsp->usedSummaryNumber;
int spnum = hmSpan;
struct region *r;

// seek to left to make left wing
r = dsp->head;
extendRegionDstart(r, spsize, &spnum, dsp->atbplevel);
if(spnum > 0)
    {
    r = r->prev;
    while(r != NULL)
        {
	r->summarySize = 0;
	r->dstart = r->dstop = r->bstop;
	extendRegionDstart(r, spsize, &spnum, dsp->atbplevel);
	dsp->head = r;
	if(spnum <= 0)
	    break;
	r = r->prev;
	}
    }
dsp->head->prev = NULL;

// seek to right to make right wing
r = dsp->tail;
spnum = hmSpan;
extendRegionDstop(r, spsize, &spnum, dsp->atbplevel);
if(spnum > 0)
    {
    r = r->next;
    while(r != NULL)
        {
	r->summarySize = 0;
	r->dstart = r->dstop = r->bstart;
	extendRegionDstop(r, spsize, &spnum, dsp->atbplevel);
	dsp->tail = r;
	if(spnum <= 0)
	    break;
	r = r->next;
	}
    }
dsp->tail->next = NULL;

computeEntireLength(dsp);

dsp->usedSummaryNumber = 0;
for(r=dsp->head; r!=NULL; r=r->next)
    dsp->usedSummaryNumber += r->summarySize;
}





/********************************
      draw decor tracks
      apply to both genome/gf mode
 *******************************/

int getServerDecorFiletype(char *gf)
{
// given name, query fileType in decorInfo
char *query;
if(asprintf(&query, "select fileType from decorInfo where name=\"%s\"",gf)<0) errabort("bae");
int re = mysqlGetPositiveInteger(query);
if(re == -1) errabort("getServerDecorFiletype got no result");
free(query);
return re;
}
struct tnode *parseParamDecor0(char *param)
{
/* similar operations for decor0-5, parse param string, returns list of tnode
   param string might be different...

   for server bigbed
   param: [track name],[mode]
 */
char delim[] = ",";
struct tnode *tt, *sl=NULL;
char *tok = strtok(param, delim);
while(tok != NULL)
    {
    tt = malloc(sizeof(struct tnode));
    if(asprintf(&tt->t1, "%s", tok)<0) errabort("bae");
	tt->t3=makefilepath(tok, FT_bigbed_n);
	/*
    if(binaryFileIsInvalid(tt->t3, FALSE))
        {
		printf("\"abort\":\"supposedly server bigbed but has error: %s\"}", tt->t3);
		exit(0);
		}
		*/
	// mode
    assert((tok=strtok(NULL,delim)) != NULL);
    tt->t4 = strMayPositiveInt(tok);
	if(tt->t4==-1)
		{
		fprintf(stderr, "%s: %s has wrong mode string\n", __FUNCTION__, tt->t1);
		exit(0);
		}
    tt->next = sl;
    sl = tt;
    tok = strtok(NULL, delim);
    }
return sl;
}
struct tnode *parseParamDecor1(char *param)
{
/* for custom bigbed
   param: name,label,url,mode
 */
char delim[] = ",";
struct tnode *tt, *sl=NULL;
char *tok = strtok(param, delim);
while(tok != NULL)
    {
    tt = malloc(sizeof(struct tnode));
    // name
    tt->t1 = strdup(tok);
    // label
    assert((tok=strtok(NULL,delim)) != NULL);
    tt->t2 = strdup(tok);
    // url
    assert((tok=strtok(NULL,delim)) != NULL);
    tt->t3 = strdup(tok);
    /*if(binaryFileIsInvalid(tt->t3, TRUE))
		{
		printf("\"abort\":\"custom bigbed url error: %s\"}", tt->t3);
		exit(0);
		}
		*/
    // mode
    assert((tok=strtok(NULL,delim)) != NULL);
    tt->t4 = strMayPositiveInt(tok);
	if(tt->t4==-1)
		{
		fprintf(stderr, "%s: %s has wrong mode string\n", __FUNCTION__, tt->t1);
		tt->t4=M_den;
		}
    tt->next = sl;
    sl = tt;
    tok = strtok(NULL, delim);
    }
return sl;
}
struct tnode *parseParamDecor9(char *param)
{
// server long-range, similar as bigbed but got extra fields of positive/negative score cutoffs
char delim[] = ",";
struct tnode *tt, *sl=NULL;
char *tok = strtok(param, delim);
while(tok != NULL)
    {
    tt = malloc(sizeof(struct tnode));
    if(asprintf(&tt->t1, "%s", tok)<0) errabort("bae");
	tt->t3=makefilepath(tok, FT_chiapet_n);
	/*
    if(binaryFileIsInvalid(tt->t3, FALSE))
        {
		printf("\"abort\":\"supposedly server long-range but has error: %s\"}", tt->t3);
		exit(0);
		}
		*/
    assert((tok=strtok(NULL,delim)) != NULL); // mode
    tt->t4 = strMayPositiveInt(tok);
	if(tt->t4==-1)
		{
		fprintf(stderr, "%s: %s has wrong mode string\n", __FUNCTION__, tt->t1);
		exit(0);
		}
    assert((tok=strtok(NULL,delim)) != NULL); // positive score cutoff
    tt->fnum = strtod(tok, NULL);
    assert((tok=strtok(NULL,delim)) != NULL); // negative score cutoff
    tt->fnum2 = strtod(tok, NULL);
    tt->next = sl;
    sl = tt;
    tok = strtok(NULL, delim);
    }
return sl;
}
struct tnode *parseParamDecor10(char *param)
{
// custom long-range, similar as custom bigbed but with extra score cutoff field
char delim[] = ",";
struct tnode *tt, *sl=NULL;
char *tok = strtok(param, delim);
while(tok != NULL)
    {
    tt = malloc(sizeof(struct tnode));
    tt->t1 = strdup(tok); // name
    assert((tok=strtok(NULL,delim)) != NULL); // label
    tt->t2 = strdup(tok);
    assert((tok=strtok(NULL,delim)) != NULL); // url
    tt->t3 = strdup(tok);
	/*
    if(binaryFileIsInvalid(tt->t3, TRUE))
        {
		printf("\"abort\":\"custom long-range track url error: %s\"}", tt->t3);
		exit(0);
		}
		*/
    assert((tok=strtok(NULL,delim)) != NULL); // mode
    tt->t4 = strMayPositiveInt(tok);
	if(tt->t4==-1)
		{
		fprintf(stderr, "%s: %s has wrong mode string\n", __FUNCTION__, tt->t1);
		exit(0);
		}
    assert((tok=strtok(NULL,delim)) != NULL); // positive score cutoff
    tt->fnum = strtod(tok, NULL);
    assert((tok=strtok(NULL,delim)) != NULL); // negative score cutoff
    tt->fnum2 = strtod(tok, NULL);
    tt->next = sl;
    sl = tt;
    tok = strtok(NULL, delim);
    }
return sl;
}
struct tnode *parseParamDecor8(char *param)
{
/* for server decor bigwig
   param: [track name],[mode]
 */
char delim[] = ",";
struct tnode *tt, *sl=NULL;
char *tok = strtok(param, delim);
while(tok != NULL)
    {
    tt = malloc(sizeof(struct tnode));
	tt->t1=strdup(tok);
	tt->t3=makefilepath(tok, FT_qdecor_n);
	/*
    if(binaryFileIsInvalid(tt->t3, FALSE))
        {
		printf("\"abort\":\"supposedly server bigwig but has error: %s\"}", tt->t3);
		exit(0);
		}
		*/
	assert((tok=strtok(NULL, delim))!=NULL);
	tt->t4=strMayPositiveInt(tok);
	if(tt->t4==-1)
		{
		fprintf(stderr, "%s: %s has wrong mode string\n", __FUNCTION__, tt->t1);
		exit(0);
		}
    tt->next = sl;
    sl = tt;
    tok = strtok(NULL, delim);
    }
return sl;
}
struct tnode *parseParamDecor4(char *param)
{
/* for server BAM
   param: [track name],[mode]
 */
char delim[] = ",";
struct tnode *tt, *sl=NULL;
char *tok = strtok(param, delim);
while(tok != NULL)
    {
    tt = malloc(sizeof(struct tnode));
    tt->t1 = strdup(tok);
    if(asprintf(&tt->t3, "%sbam/%s.bam", bbiDir, tok)<0) errabort("bae");
	/*
    if(binaryFileIsInvalid(tt->t3, FALSE))
        {
		printf("\"abort\":\"supposedly server BAM but has error: %s\"}", tt->t3);
		exit(0);
		}
		*/
    assert((tok=strtok(NULL,delim))!=NULL);
    tt->t4 = strMayPositiveInt(tok);
	if(tt->t4==-1)
		{
		fprintf(stderr, "%s: %s has wrong mode string\n", __FUNCTION__, tt->t1);
		exit(0);
		}
    tt->next = sl;
    sl = tt;
    tok = strtok(NULL, delim);
    }
return sl;
}
struct tnode *parseParamDecor5(char *param)
{
/* for custom BAM, almost identical with parseParamDecor1()
   param: name,label,url,mode
 */
char delim[] = ",";
struct tnode *tt, *sl=NULL;
char *tok = strtok(param, delim);
while(tok != NULL)
    {
    tt = malloc(sizeof(struct tnode));
    // name
    if(asprintf(&tt->t1, "%s", tok)<0) errabort("bae");
    // label
    assert((tok=strtok(NULL,delim)) != NULL);
    tt->t2 = strdup(tok);
    // url
    assert((tok=strtok(NULL,delim)) != NULL);
    tt->t3 = strdup(tok);
	/*
    if(binaryFileIsInvalid(tt->t3, TRUE))
        {
	printf("\"abort\":\"custom bam url error: %s\"}", tt->t3);
	exit(0);
	}
	*/
    // mode
    assert((tok=strtok(NULL,delim)) != NULL);
    tt->t4 = strMayPositiveInt(tok);
	if(tt->t4==-1)
		{
		fprintf(stderr, "%s: %s has wrong mode string\n", __FUNCTION__, tt->t1);
		exit(0);
		}
    tt->next = sl;
    sl = tt;
    tok = strtok(NULL, delim);
    }
return sl;
}

void parseParamHtest(struct track *tracksl)
{
int grpnum = cgiInt("htestgrpnum");
char *tok; char delim[] = ",";
char *param;
struct track *track;
int i;
for(i=1; i<=grpnum; i++)
    {
    if(asprintf(&param, "htestgrp%d", i)<0) errabort("bae");
    tok = strtok(cgiString(param), delim); assert(tok!=NULL);
    while(tok != NULL)
	{
	for(track=tracksl; track!=NULL; track=track->next)
	    {
	    if(strcmp(track->name, tok)==0)
		{
		track->gid = i;
		break;
		}
	    }
	tok = strtok(NULL, delim);
	}
    }
}

void tabixQuery_regiondensity(tabix_t *fin, int ft, struct region *r, double *data)
{
/* fetch bed items for a region and compute density
only deal with coord, so use generic item
*/
int startArr[r->summarySize], stopArr[r->summarySize], i;
float pieceLength = (float)(r->dstop-r->dstart) / r->summarySize;
for(i=0; i<r->summarySize; i++)
	{
	startArr[i] = (int)(r->dstart + pieceLength*i);
	stopArr[i] = (int)(r->dstart + pieceLength*(i+1));
	}

struct genericItem *itemsl=(struct genericItem *)tabixQuery_region(fin, ft, r);
struct genericItem *item;
for(item=itemsl; item!=NULL; item=item->next)
	{
	// collapse this bed item onto the density counter
	for(i=0; i<r->summarySize; i++)
		{
		if(item->start > stopArr[i]) continue;
		if(item->stop < startArr[i]) break;
		if(intMax(item->start,startArr[i]) < intMax(item->stop,stopArr[i])) data[i]++;
		}
	}
// TODO free
//tabixFreeResult(beddata);
}

void printJson_itemDensity(struct displayedRegion *dsp, char *urlpath, int ft)
{
/* decor density data printed out, not storing
*/
struct region *r;
tabix_t *fin = tabixOpen(urlpath);
printf("[");
for(r=dsp->head; r!=NULL; r=r->next)
    {
    double *data = malloc(sizeof(double)*r->summarySize);
    int i;
    for(i=0; i<r->summarySize; i++) 
        data[i] = 0;
    tabixQuery_regiondensity(fin, ft, r, data);
    printf("[");
    for(i=0; i<r->summarySize; i++)
		printf("%d,", (int)data[i]);
    printf("],");
    free(data);
    }
printf("],");
ti_close(fin);
if(SQUAWK) fprintf(stderr, "ok: %s(%s)\n", __FUNCTION__, urlpath);
}



void printJson_bed_scorefilter(struct displayedRegion *dsp, char *urlpath, int ft, float pscoreCutoff, float nscoreCutoff, boolean withinRegionFiltering)
{
/* args:
     pscoreCutoff/nscoreCutoff: score cutoff
     withinRegionFiltering: boolean, if true, will only fetch items whose mate is within current region
	(e.g. for track displaying in the small long-range panel BUT not main panel)

difference with printJson_bedstack()
- it won't deal with gene tracks, only long-range??
- always apply score cutoff
- no stacking
- may apply within region filtering
 */

char delim[] = "\t";
char delim2[] = ",";
int skip_outsideRegion=0;

/* this is guaranteed to be long-range */
struct beditem *item;
struct beditem **data=(struct beditem **)tabixQuery_dsp(dsp, urlpath, ft);

int dataidx=0;

struct region *r;
char *name, *id, *strand; // to be used at each bed item
printf("[");
for(r=dsp->head; r!=NULL; r=r->next)
    {
    printf("[");
    for(item=data[dataidx]; item!=NULL; item=item->next)
        {
		if((name=strtok(item->rest,delim))==NULL) continue;
		if(strcmp(name, ".")==0) continue;
		if((id=strtok(NULL,delim))==NULL) continue;
		strand=strtok(NULL,delim);

		// apply score cutoff
		char *namec = strdup(name);
		char *matecoordstr = strtok(namec, delim2);
		if(matecoordstr==NULL) continue;
		char *tmp = strtok(NULL, delim2);
		if(tmp==NULL) continue; // supposed to be the score
		float thisscore = strtod(tmp, NULL);

		if(thisscore >= 0)
			{
			if(thisscore<pscoreCutoff) continue;
			}
		else
			{
			if(thisscore>nscoreCutoff) continue;
			}

		if(withinRegionFiltering)
			{
			int *matecoord = dissectCoordString(matecoordstr);
			if(matecoord[0]==-1 || matecoord[1]==-1 || matecoord[2]==-1) continue;
			if(matecoord[0]!=r->chromIdx)
				{
				skip_outsideRegion++;
				continue;
				}
			if(max(matecoord[1],r->dstart) >= min(matecoord[2],r->dstop))
				{
				skip_outsideRegion++;
				continue;
				}
			free(matecoord);
			}

		printf("[,,%s,", id);
		if(name != NULL)
			printf("'%s',", name);
		else
			printf(",");
		if(strand != NULL)
			printf("'%c',", strand[0]=='+'?'>':(strand[0]=='-'?'<':strand[0]));
		else
			printf(",");
		printf(",,,%d,%d,,,,,,,],",item->start,item->stop);
		}
	dataidx++;
    printf("],");
    }
printf("],");

/*
dataidx=0;
for(r=dsp->head; r!=NULL; r=r->next)
	tabixFreeResult(data[dataidx++]);
	*/
free(data);

if(SQUAWK) fprintf(stderr, "ok: %s(%s)\n", __FUNCTION__, urlpath);
return;
}


int printJson_bedstack(struct displayedRegion *dsp, char *urlpath, int ft, char *decorname, float *pscoreCutoffPtr, float *nscoreCutoffPtr)
{
/* args:
     file: path or url
	 ft: file type
     decorname: NULL if it is custom
     scoreCutoffPtr: pointer to float or NULL
       if NULL, won't apply cutoff

   nasty similarity with printJson_bed_scorefilter()

   score filtering is only reserved for future use!

   do a preliminary stacking only using item coordinate,
   stacking for each region separately,

   for gene track, tell from belonging to gene group and the hasStruct field is True
   will retrieve symbol and struct data for each item

   for gene part tracks like promoters, tell from belonging to gene group,
   but hasStruct field is False, will only retrieve symbol

   !! symbol or struct table name is assumed to be [x]symbol, [x]struct
      where [x] is decorname

   only purpose of stacking here is to prevent from sending too many items to clientside
   TODO return # skipped items
        identify region with skipped items, report to JS
   TODO should be extendable for generic genomic feature track with structure
        where only struct data will be retrieved, not symbol
   TODO better error report
 */


boolean queryStruct = FALSE;
boolean querySymbol = FALSE;
// in case track is promoter track, symbol table will take name of parent track
char *symbolTableBasename = NULL;
char *structTableBasename = NULL;

char *query;

/* decide whether it is a gene track
and if to query gene structure */
if(decorname!=NULL && genetracksl!=NULL)
    {
    int genegrpid = mysqlGetGenesGroupId();
	if(genegrpid!=-1)
		{
		if(asprintf(&query, "select grp from decorInfo where name=\"%s\"", decorname)<0) errabort("bae");
		int thisgrpid = mysqlGetPositiveInteger(query);
		free(query);
		if(thisgrpid == genegrpid)
			{
			// will query symbol, is gene or gene part (promoter stuff)
			querySymbol = TRUE;
			if(asprintf(&query, "select parent from decorInfo where name=\"%s\"", decorname)<0) errabort("bae");
			char *parentName = mysqlGetOnestring(query);
			free(query);
			if(parentName == NULL)
				{
				// no parent, so it is a gene track, see if it has structure
				symbolTableBasename = decorname;
				if(asprintf(&query, "select hasStruct from decorInfo where name='%s'", decorname)<0) errabort("bae");
				char *re = mysqlGetOnestring(query);
				free(query);
				if(re[0] == '1')
					{
					queryStruct = TRUE;
					structTableBasename = decorname;
					}
				}
			else
				{
				// has parent, so symbol table takes name of parent track
				symbolTableBasename = parentName;
				// currently gene part doesn't have structure, but if things change, extend here
				}
			}
		else
			{
			/* TODO extend here for generic genomic feature tracks that don't belong to gene group
			   test if the track has structure
			 */
			}
		}
	}

int stackNumber=300, stackIdx; // TODO make it a parameter
int stack[stackNumber];
int id_strand=0, id_txstart=1, id_txend=2, id_cdsstart=3, 
    id_cdsend=4, id_exoncount=5, id_exonstarts=6, id_exonends=7;
char delim[] = "\t";
char delim2[] = ",";
int returnedCount=0,skipCount=0;
MYSQL_RES *sr;
char **row;

float pscoreCutoff=0, nscoreCutoff=0;
if(pscoreCutoffPtr != NULL)
    {
    pscoreCutoff = *pscoreCutoffPtr;
    nscoreCutoff = *nscoreCutoffPtr;
    }

struct genericItem *item;
struct genericItem **data=(struct genericItem **)tabixQuery_dsp(dsp, urlpath, ft);

boolean isSam=(ft==FT_bam_n||ft==FT_bam_c);

int dataidx=0;

printf("[");
char *name=NULL, *id=NULL, *strand=NULL; // to be used at each bed item, but not sam read
struct region *r;
for(r=dsp->head; r!=NULL; r=r->next)
    {
    // stacking using item coordinate, so do separately for each region
    for(stackIdx=0; stackIdx<stackNumber; stackIdx++)
		stack[stackIdx] = 0; // will be item coordinate
	printf("[");
	struct genericItem *itemsl=beditemsort_startAsc(data[dataidx]);
	for(item=itemsl; item!=NULL; item=item->next)
        {
		if(!isSam)
			{
			/** is bed item **/
			// chop up item->rest
			struct beditem *item2=(struct beditem *)item;
			if((name=strtok(item2->rest,delim))==NULL) continue;
			if((id=strtok(NULL,delim))==NULL) continue;
			strand=strtok(NULL,delim);
			// done chopping

			if(strcmp(name, ".") == 0) name = NULL;

			/* see if to apply score cutoff
			lots of freaky assumptions here, only apply to long-range data
			a copy of the name string will be chopped
			likely to be revised in future */
			if(pscoreCutoffPtr != NULL)
				{
				// only long-range track has score, it need to be chopped off from the name
				char *namec = strdup(name);
				strtok(namec, delim2);
				char *tmp = strtok(NULL, delim2);
				if(tmp == NULL)
					continue;
				float thisscore = strtod(tmp, NULL);
				if(thisscore >= 0)
					{
					if(thisscore<pscoreCutoff) continue;
					}
				else
					{
					if(thisscore>nscoreCutoff) continue;
					}
				}
			}

	    // stacking
		boolean notStacked = TRUE;
	    for(stackIdx=0; stackIdx<stackNumber; stackIdx++)
			{
			if(stack[stackIdx] <= item->start)
				{
				// slot found
				stack[stackIdx] = item->stop;
				notStacked = FALSE;
				returnedCount++;
				break;
				}
			}
		if(notStacked) 
			{
			skipCount++;
			continue;
			}

		// compose json array
		if(isSam)
			{
			/** sam read output **/
			struct readitem *read=(struct readitem *)item;
			printf("[,,'%s',,,,,,%d,%d,,", read->id, read->start, read->stop);
			if(read->mismatch!=NULL)
				printf("'%s'", read->mismatch);
			// flag is never NULL
			printf(",%s,,'%s',,,false],", read->flag,read->seq);
			}
		else
			{
			/** bed item output **/
			printf("[,,%s,", id);
			if(name != NULL)
				printf("'%s',", name);
			else
				printf(",");
			if(strand != NULL)
				printf("'%c',", strand[0]=='+'?'>':(strand[0]=='-'?'<':strand[0]));
			else
				printf(",");
			printf(",,,%d,%d,,,,,,",item->start,item->stop);
			if(querySymbol && symbolTableBasename!=NULL)
				{
				if(asprintf(&query, "select symbol from %ssymbol where id=%s", symbolTableBasename, id)<0) errabort("bae");
				char *symbol = mysqlGetOnestring(query);
				free(query);
				if(symbol != NULL)
					printf("'%s'", symbol);
				free(symbol);
				}
			printf(",");

			if(queryStruct && structTableBasename!=NULL)
				{
				if(asprintf(&query, "select strand,txStart,txEnd,cdsStart,cdsEnd,exonCount,exonStarts,exonEnds from %sstruct where id=%s", structTableBasename, id)<0) errabort("bae");
				sr=mysqlGetResult(query);
				assert(sr!=NULL);
				free(query);
				row = mysql_fetch_row(sr);
				if(row==NULL ||
					row[id_strand]==NULL ||
					row[id_txstart]==NULL ||
					row[id_txend]==NULL ||
					row[id_cdsstart]==NULL ||
					row[id_cdsend]==NULL ||
					row[id_exoncount]==NULL ||
					row[id_exonstarts]==NULL ||
					row[id_exonends]==NULL)
					{
					// don't break program
					}
				else
					{
					int txstart = strMayPositiveInt(row[id_txstart]);
					if(txstart==-1)
						{
						fprintf(stderr, "%s: incorrect txstart\n", __FUNCTION__);
						exit(0);
						}
					int txstop = strMayPositiveInt(row[id_txend]);
					if(txstop==-1)
						{
						fprintf(stderr, "%s: incorrect txstop\n", __FUNCTION__);
						exit(0);
						}
					int cdsstart = strMayPositiveInt(row[id_cdsstart]);
					if(cdsstart==-1)
						{
						fprintf(stderr, "%s: incorrect cdsstart\n", __FUNCTION__);
						exit(0);
						}
					int cdsstop = strMayPositiveInt(row[id_cdsend]);
					if(cdsstop==-1)
						{
						fprintf(stderr, "%s: incorrect cdsstop\n", __FUNCTION__);
						exit(0);
						}
					char strand = row[id_strand][0];

					// exons, dissect exon start/ends/frame string, put into arrays
					int exoncount = strMayPositiveInt(row[id_exoncount]);
					if(exoncount==-1)
						{
						fprintf(stderr, "%s: incorrect exoncount\n", __FUNCTION__);
						exit(0);
						}
					int *exonstartarr = str2intArr(row[id_exonstarts], exoncount);
					int *exonstoparr = str2intArr(row[id_exonends], exoncount);

					printf("[");

					/* 5' UTR
					 start is always transcription start
					 if 1st exon stop is upstream of cds start, utr stops at 1st exon stop
					 else, utr stops at cds start
					   print out start/length
					 */
					if(strand == '+')
						{
						printf("%d,", txstart);
						if(cdsstart > exonstoparr[0])
							{
							printf("%d,", exonstoparr[0]-txstart);
							// make 1st exon unusable...
							exonstartarr[0] = -1; exonstoparr[0]=-1;
							}
						else
							{
							printf("%d,", cdsstart-txstart);
							// reset first exon start if it is beyond cdsstart
							if(cdsstart > exonstartarr[0])
								exonstartarr[0] = cdsstart;
							}
						}
					else
						{
						int utrstart;
						if(exonstoparr[exoncount-1] > cdsstop)
							{
							utrstart = exonstartarr[exoncount-1];
							// make last exon usuable...
							exonstartarr[exoncount-1]=-1; exonstoparr[exoncount-1]=-1;
							}
						else
							{
							utrstart = cdsstop;
							// reset last exon stop if it is beyond cdsstop
							if(exonstoparr[exoncount-1] > cdsstop)
								exonstoparr[exoncount-1] = cdsstop;
							}
						printf("%d,%d,", utrstart, txstop-utrstart);
						}
					/* 3' UTR
					 stop is always transcription stop
					 if last exon start is upstream of cds stop, utr starts at cds stop
					 else, utr starts at last exon start
					 */
					if(strand == '+')
						{
						int utrstart;
						if(exonstartarr[exoncount-1] > cdsstop)
							{
							utrstart = exonstartarr[exoncount-1];
							// make last exon usuable
							exonstartarr[exoncount-1]=-1; exonstoparr[exoncount-1]=-1;
							}
						else
							{
							utrstart = cdsstop;
							if(exonstoparr[exoncount-1] > cdsstop)
								exonstoparr[exoncount-1] = cdsstop;
							}
						printf("%d,%d,", utrstart, txstop-utrstart);
						}
					else
						{
						printf("%d,", txstart);
						if(cdsstart > exonstoparr[0])
							{
							printf("%d,", exonstoparr[0]-txstart);
							// make first exon unusable
							exonstartarr[0]=-1; exonstoparr[0]=-1;
							}
						else
							{
							printf("%d,", cdsstart-txstart);
							if(exonstartarr[0] < cdsstart)
								exonstartarr[0] = cdsstart;
							}
						}
					// exons
					printf("[");
					int j;
					for(j=0; j<exoncount; j++)
						{
						if(exonstartarr[j]!=-1 && exonstoparr[j]!=-1)
							printf("[%d,%d],", exonstartarr[j], exonstoparr[j]);
						}
					printf("]"); // enclose exon list
					printf("]"); // enclose structure data holder
					free(exonstartarr);
					free(exonstoparr);
					}
				mysql_free_result(sr);
				}
			printf("],");
			}
	    }
	dataidx++; // never forget this...
    printf("],");
    }
printf("],");

/*
dataidx=0;
for(r=dsp->head; r!=NULL; r=r->next)
	tabixFreeResult(data[dataidx++]);
	*/
free(data);

if(SQUAWK) fprintf(stderr, "%s(%s), %d returned, %d skipped\n", __FUNCTION__, urlpath, returnedCount, skipCount);
return skipCount;
}




void printJsonDecor(struct displayedRegion *dsp, struct tnode *tt, int fileType, boolean overChiapet)
{
/* grand wrapper for decor processing routines
   takes one decor track, handles it according to its mode and file type
   expandable to support other file types and modes

   tt->t1: track name
   tt->t2: file path or url, depend on fileType
   tt->t4: mode, integer
   fileType: see the sticker note on my monitor... good luck!
 */
if(tt->t4==M_show)
    {
    if(fileType == FT_qdecor_n)
        printJson_bigwig(dsp, tt->t3);
    else
        errabort("printJsonDecor: decor mode show, but file type is not 8 (server bigwig)");
    return;
    }
if(tt->t4==M_den)
    {
    if(fileType==FT_bigbed_n||fileType==FT_bigbed_c||fileType==FT_chiapet_n||fileType==FT_chiapet_c)
		{
        printJson_itemDensity(dsp, tt->t3, fileType);
		}
    else if(fileType==FT_bam_n||fileType==FT_bam_c)
		{
        printJson_itemDensity(dsp, tt->t3, fileType);
		}
    else
		{
        fputs("printJsonDecor: mode density, getting unknown file type\n", stderr);
		}
    return;
    }
switch(fileType)
	{
	case FT_chiapet_n:
	case FT_chiapet_c:
		/* long-range track
		will always apply score cutoff
		if in arc/trihm mode and over chiapet panel, will apply within region filtering
		*/
		printJson_bed_scorefilter(dsp, tt->t3, fileType, tt->fnum, tt->fnum2, overChiapet?(tt->t4==M_arc||tt->t4==M_trihm):FALSE);
    	return;
	case FT_bigbed_n:
    	printJson_bedstack(dsp, tt->t3, fileType, tt->t1, NULL,NULL);
		return;
	case FT_bigbed_c:
    	printJson_bedstack(dsp, tt->t3, fileType, NULL, NULL,NULL);
		return;
	case FT_bam_n:
	case FT_bam_c:
    	printJson_bedstack(dsp, tt->t3, fileType, NULL,NULL,NULL);
		return;
	default:
    	fputs("printJsonDecor: mode thin/full/arc/trihm, getting unknown file type\n", stderr);
		exit(0);
	}
}



/********************************
     one_time_deal triggers, 
     only run upon first-time invocation...
 ********************************/

void onetimedeal_geneset()
{
// gene set view
printf("\"tgt_geneset\":\""
"<div id=genesetnotinservice style='display:none;width:700px;height:250px;text-align:center;font-size:16px;color:white;padding-top:50px;'></div>" // not in service

"<div id=genesetinservice style='position:relative;'>" // in service
"<p id=genesetsaysno class=says>Viewing genome (gene set view is off)</p>"
"<p id=genesetsaysyes class=says style='display:none;'>Running gene set view <button type=button onclick=turnoffJuxtapose(true)>turn off and view genome</button></p>"

"<div id=genesetentrywrapper class=controlpaneldiv style='padding:60px;padding-bottom:30px;width:680px;'>" // wrapper of entry panels

  "<table cellspacing=0 style='position:absolute;left:50px;top:0px;'>" // tabs
    "<tr>"
      "<td id=genesettab_custom class=cptabon onclick=tabclick_geneset('custom') style='border-bottom-left-radius:10px;-moz-border-radius-bottomleft:10px;overflow:hidden;border-right:solid 1px #fff9d2;'>Custom gene set</td>"
      "<td id=genesettab_kegg class=cptaboff onclick=tabclick_geneset('kegg') style='border-bottom-right-radius:10px;-moz-border-radius-bottomright:10px;overflow:hidden;'>KEGG pathways</td>"
    "</tr>"
  "</table>"
  "<div class=cptabsig onclick=openManual('c-a')>?</div>"

  "<div id=genesetwrapper_custom style='display:block'>" // custom geneset entry panel
      "<table border=0 cellpadding=5>"
        "<tr>"
          "<td valign=top rowspan=2>"
            "<textarea rows=10 cols=30 id=genelisttextarea></textarea>"
          "</td><td valign=top>"
            "<p>Enter a list of genes or regions to run Gene Set View<br>"
            "<span style='color:#858585;'>Both gene names and coordinates are accepted, "
            "and can be mixed together for input (one item per line)</span></p>"
	    "<p>Display <span id=custgsi_gss_says style='text-decoration:underline;'>gene body</span> for genes<br>"
	    "<button type=button onclick=custgs_invokegss(event)>change &#187;</button> "
	    "<span style='color:#858585;'>no effect for genomic coordinates</span></p>"
	    "<span id=custgsi_gss_opt style='display:none;'>genebody</span>"
	    "<span id=custgsi_gss_origin style='display:none;'>txstart</span>"
	    "<span id=custgsi_gss_up style='display:none;'>2500</span>"
	    "<span id=custgsi_gss_down style='display:none;'>0</span>"
	  "</td>"
	"</tr><tr>"
	  "<td valign=bottom>"
            "<button id=custgenesetbutt type=button onclick=submitCustomgeneset()>SUBMIT</button> "
            "<button type=button onclick=\\\"document.getElementById('genelisttextarea').value=''\\\">Clear</button>"
          "</td>"
        "</tr>"
      "</table>"
  "</div>" // custom geneset entry panel ends

  "<div id=genesetwrapper_kegg style='display:none;position:relative;'>" // kegg entry panel
      "<img src=images/kegg2_menu.gif style='position:absolute;right:-25px;bottom:-30px;opacity:0.15;' onclick=window.open('http://www.kegg.jp')>"
      "<table cellspacing=10><tr>"
          "<td style='padding-right:40px;'><input type=text size=15 id=pathwaykwinput value='enter keywords' onfocus=\\\"if(this.value=='enter keywords') this.value='';\\\" onblur=\\\"if(this.value.length==0) this.value='enter keywords';\\\"> "
          "<button type=button onclick=keggpathwaykeywordlookup()>pathway lookup</button>"
	  "<br><span style='font-size:10px;color:#858585;'>separate keywords by space</span></td>"
          "<td><input type=text size=15 id=pathwayid value='enter pathway ID' onfocus=\\\"if(this.value=='enter pathway ID') this.value='';\\\" onblur=\\\"if(this.value.length==0) this.value='enter pathway ID';\\\"> "
          "<button type=button onclick=\\\"submitGeneset_kegg()\\\">use pathway</button>"
	  "<br><span style='font-size:10px;color:#858585;'>e.g. <span id=examplekeggpathid></span></span></td>"
      "</tr></table>"
      "<div style='width:450px;'>"
	"Display <span id=kegg_gss_says style='text-decoration:underline;'>gene body</span> <button type=button onclick=kegg_invokegss(event)>change &#187;</button>"
	"<span id=kegg_gss_opt style='display:none;'>genebody</span>"
	"<span id=kegg_gss_origin style='display:none;'>txstart</span>"
	"<span id=kegg_gss_up style='display:none;'>2500</span>"
	"<span id=kegg_gss_down style='display:none;'>0</span>"
      "</div>"

      // kegg pathway hits go here
      "<div id=gsikeggwrapper style='display:none;margin:10px;margin-bottom:30px;'>"
        "<div id=pathwaytablewrapper class=bordertb>"
	  "<div>Pathways matching keyword <span id=keggusingkeyword style='text-decoration:underline;'></span>"
	    "<div class=rclosebut onclick=\\\"this.parentNode.parentNode.parentNode.style.display='none';\\\">&#10005;</div>"
	  "</div>"
          "<table id=pathwaytable width=100%% cellspacing=0 cellpadding=2></table>"
        "</div>"
        "<span id=pathwaytablesaysyes style='padding-left:30px;color:#858585;'><span style='font-size:20px;'>&uarr;</span> click ID to run Gene Set View on genes of the pathway</span>"
      "</div>"
      "<p style='font-size:10px;color:#858585;'>Service depends on availability of <a href=http://www.kegg.jp target=_blank>KEGG database</a>, and could be interrupted by external causes</p>"
  "</div>" // kegg entry panel ends

"</div>" // entry wrapper ends

"</div>" // in service ends
"\",");
}

void onetimedeal_juxtapose()
{
/* juxtaposing on bigbed files, either server or custom
 */
printf("\"tgt_juxtapose\":\""
"<div id=juxtaposenotinservice style='display:none;width:680px;height:250px;text-align:center;font-size:16px;color:white;padding-top:50px;'></div>" // not in service
"<div id=juxtaposeinservice>" // in service
"<div class=controlpaneldiv style='padding:60px;padding-bottom:30px;width:680px;'>" // control panel
  "<div class=cptabstatic>Data juxtaposition</div>"
  "<div class=cptabsig onclick=openManual('c-b')>?</div>"
  "<p style='color:#A8A8A8;'>Data juxtaposition lets you focus on one type of genomic feature or subset of genome"
  "<br><a href=images/juxdiagram.png target=_blank>See a diagram on how it works &#187;</a></p>"
  "<div class=satpanel>" // satpanel
    "<div>"
      "<div id=juxtaposeinuse style='display:none;'>Running juxtaposition on <span id=juxtaposewhat></span> "
      "<button type=button onclick=turnoffJuxtapose(true)>turn off</button></div>"
      "<div id=juxtaposenotinuse><button type=button onclick=juxtapose_invoketksp(event)>select a genomic feature track &#187;</button></div>"
    "</div><div>"
      "Or right-click on genomic feature track image and select 'Juxtaposition' option<br><br><img src=images/juxtaposition.png style='opacity:0.5;'>"
    "</div>"
  "</div>" // satpanel ends
"</div>" // control panel ends
"</div>" // in service ends
"\",");
}


void onetimedeal_nativehmtk()
{
/* just a bare bone, client will fill out contents using metadata root attributes
 */
printf("\"tgt_nativehmtk\":\""
"<div class=controlpaneldiv style='padding:0px;padding-top:40px;padding-bottom:30px;'>"
"<div class=cptabstatic>Genome heatmap tracks</div>"
  "<div class=cptabsig onclick=openManual('b-a')>?</div>"
  "<img src=images/null.gif width=680 height=1>"
  "<p style='color:#858585;margin-left:50px;'><span id=howmanyhmtk2 class=r></span> on display | <span id=howmanyhmtktotal class=g></span> available from current data set(s)</p>"
  // tabpage div starts
  "<table cellpadding=10 cellspacing=0 style='margin-top:30px;margin-bottom:30px;'><tr>" 
    "<td id=tabpage_hmtk_tab1 style='border:solid 1px transparent;'><img src=images/null.gif width=50 height=1></td>"
    "<td id=tabpage_hmtk_tab6 align=center class=tabpageOff style='width:120px;'><button type=button which=6 id=tabpage_hmtk_butt6 onclick=toggle8(event)></button></td>"
    "<td id=tabpage_hmtk_tab7 style='width:15px;border:solid 1px transparent;'> </td>"
    "<td id=tabpage_hmtk_tab2 align=center class=tabpageOff style='width:120px;'><button type=button which=2 id=tabpage_hmtk_butt2 onclick=toggle8(event)></button></td>"
    "<td id=tabpage_hmtk_tab3 style='width:15px;border:solid 1px transparent;'> </td>"
    "<td id=tabpage_hmtk_tab4 align=center class=tabpageOff style='width:250px;'><button type=button which=4 id=tabpage_hmtk_butt4 onclick=toggle8(event)></button></td>"
    "<td id=tabpage_hmtk_tab5 style='border:solid 1px transparent;'><img src=images/null.gif width=50 height=1></td>"
    "</tr><tr>"
      "<td colspan=7 id=tabpage_hmtk_body class=tabpageBody style='display:none;'>"

// dataset div
"<div id=tabpage_hmtk_content2 style='display:none;'>" 
    "<img src=images/null.gif width=660 height=1><br>"
  );

// make a list of dataset names
MYSQL_RES *sr = mysqlGetResult("select tablename from dataset");
assert(sr!=NULL);
char **row;
struct tnode *sl=NULL, *tt;
while((row=mysql_fetch_row(sr)) != NULL)
    {
    assert(row[0] != NULL);
    tt = malloc(sizeof(struct tnode));
	tt->t1=strdup(row[0]);
    tt->next = sl;
    sl = tt;
    }
mysql_free_result(sr);
slReverse(&sl);

// get # of tracks for each dataset
char *query;
for(tt=sl; tt!=NULL; tt=tt->next)
    {
    if(asprintf(&query, "select count(tkname) from %s", tt->t1)<0) errabort("bae");
    assert((tt->num=mysqlGetPositiveInteger(query))!=-1);
    free(query);
    }
// print html for each dataset
printf("<table cellspacing=10 cellpadding=10>");
for(tt=sl; tt!=NULL; tt=tt->next)
    {
    if(tt->num <= 0)
        continue;
    if(asprintf(&query, "select * from dataset where tablename=\"%s\"", tt->t1)<0) errabort("bae");
    sr = mysqlGetResult(query);
	free(query);
	if(sr==NULL)
		continue;
    row = mysql_fetch_row(sr);
    printf("<tr><td colspan=2 style='background-color:#d4ddda;color:black;border-radius:20px;-moz-border-radius:20px;overflow:hidden;background:-webkit-gradient(linear,left top,left bottom,from(#d4ddda),to(#E8F2EE));background:-moz-linear-gradient(top,#d4ddda,#E8F2EE);'>"
    "<table>"
    "<tr>"
    "<td align=center valign=middle style='width:150px;padding-right:15px;'>");
    if(row[1] != NULL) // logo
        printf("<img src=%s width=150>", row[1]);
    else
        printf("No logo");
    printf("</td><td style='width:550px;'><p><span class=g>%s</span><br>", row[2]); // name
    if(row[3] != NULL) // url
        printf("<a href=%s target=_blank>%s</a>", row[3], row[3]); 
    printf("</p><p>%s</p></td></tr>", row[4]); // desc
    printf("<tr><td align=center><span class=r>%d</span> tracks in total</td>", tt->num); // num of tracks
    printf("<td style='padding-left:30px;'>"
    "<div id=%snotifier class=datasetno style='border-radius:20px;-moz-border-radius:20px;overflow:hidden;padding:3px;width:110px;text-align:center;'>"
    "<input type=checkbox name=datasetcheckbox value=%s id=%s_R onchange=\\\"var b=document.getElementById('loaddatasetbutton');b.disabled=false;b.innerHTML='Load data set';\\\">"
    " <label for=%s_R><span id=%ssaysyes style='display:none;'>in use</span><span id=%ssaysno>not in use</span></label>"
    "</div>", tt->t1, tt->t1, tt->t1, tt->t1, tt->t1, tt->t1);
    printf("</td></tr></table>"
    "</td></tr>");
    mysql_free_result(sr);
    }
slFree(sl);
printf("<tr>"
  "<td><button type=button id=loaddatasetbutton onclick=loaddataset() disabled>Data set loaded</button></td>"
  "<td style='color:#858585;'>Choose one or more data sets by checking the check boxes,<br>press left button to load the tracks into track selection panel.</td>"
  "</tr></table>");

printf("</div>"

// configure tkselect
"<div id=tabpage_hmtk_content4 style='display:none;width:640px;margin-left:auto;margin-right:auto;margin-top:15px;'>"
  "<p style='color:#858585;'>Define criteria to change layout of the track selection panel:</p>"
  "<table border=0 cellpadding=0 style=\\\"margin:10px;\\\">"
  "<tr>"
  "<td style='color:#858585;'>Row</td>"
  "<td style='color:#858585;'>Column</td>"
  "<td align=center valign=bottom rowspan=2 style='padding-left:20px;'>"
    "<button id=generatehmtksgridbutt type=button onclick=generateTrackselectionLayout()>Generate track selection panel</button>"
  "</td>"
  "</tr><tr>"
  "<td><select id=trackchoicemdr1 onchange=trackchoice1selectchange() style=\\\"margin-right:20px;\\\"></select></td>"
  "<td><select id=trackchoicemdr2 onchange=\\\"document.getElementById('generatehmtksgridbutt').style.display='block'\\\" style=\\\"margin-right:30px;\\\"></select></td>"
  "</tr></table>"
"</div>" // configure tkselect ends

// track selection panel
"<div id=tabpage_hmtk_content6 style='display:none;padding:10px;'>"
  "<img src=images/null.gif width=680 height=1>"
  "<p style='color:#858585;padding-left:100px;'>Click &#8862;/&#8863; to show/hide details, click numbers to select tracks</p>"
  "<div id=tkslayout1></div>"
  "<table id=tkslayout2 border=0></table>"
  "<p style='padding-left:20px;'>" // remove all buttons
  "<button type=button onclick=removeAllserverbigwig()>Remove all except custom tracks</button> "
  "<button type=button onclick=removeAlltracks()>remove everything</button>"
  "</p>"
"</div>"

    "</td>"
  "</tr>"
"</table>" // tabpage table ends

"<ul class=d style='color:#858585;width:600px;margin-left:50px;'>"
  "<li>This panel provides experimental assay tracks with quantitative data. They will be displayed in genome heatmap.</li>"
  "<li>Other assay tracks with positional data (e.g. long-range interaction) can be found in \\\"Genomic annotation\\\" panel.</li>"
"</ul>"

"</div>"
"\",");
}



void onetimedeal_corr()
{
printf("\"tgt_corr\":\"");
printf(
"<div class=controlpaneldiv style='padding:60px;padding-top:50px;padding-bottom:40px;width:680px;'>" // big wrapper
  "<div class=cptabstatic>Correlation analysis</div>"
  "<div class=cptabsig onclick=openManual('d-a')>?</div>"

"<p style='color:#858585;' id=corrnotinuse>"
  "<button type=button onclick=corr_invoketkssm(event)>Select a track ...</button>"
  " to compute its correlation with all heatmap tracks</p>"
"<p style='display:none;' id=corrinuse>Correlation against <span id=corrwhich style='text-decoration:underline;'></span> "
  "<button type=button onclick=turnoffCorrelation()>turn off correlation</button></p>"

"<p style='color:#858585;'>Or right-click on track image and select 'Correlation' option.</p>"

"</div>" // big wrapper ends
"\",");
}


void onetimedeal_pairwiseCompare()
{
printf("\"tgt_pairwiseCompare\":\""
"<p id=pairwisecompsaysno class=says>Pairwise comparison is off</p>"
"<p id=pairwisecompsaysyes class=says style='display:none;'>Pairwise comparison is on <button type=button onclick=turnoffPairwisecomp()>Turn off comparison</button></p>"
"<div class=controlpaneldiv>" // outmost div
  "<div class=cptabstatic>Pairwise comparison using log-ratio</div>"
  "<div class=cptabsig onclick=openManual('d-b')>?</div>"

  "<p><button type=button onclick=pwc_run()>Run pairwise comparison</button> "
  "<span style='color:#858585;'>Ratio is (GRP1 average)/(GRP2 average), and is log2-transformed for display</span></p>"
  "<table border=0 cellpadding=5>"
    "<tr>"
      "<td id=pwcgroupholder valign=top></td>"
      "<td valign=middle align=center style='color:#858585;'>"
	"Click 'add &#187;' button to add tracks to each group<br>"
	"Or, use context menu option on genome heatmap<br>"
	"<img src=images/menupwcchoice.png style='opacity:0.5;'>"
      "</td>"
    "</tr>"
  "</table>"
  "<p><button type=button onclick=pwc_run()>Run pairwise comparison</button>"
       "<button type=button onclick=pairwisecompClear() style='margin-left:30px;'>Clear</button></p>"
"</div>" // outmost div ends
"\",");
}

void onetimedeal_htest()
{
printf("\"tgt_htest\":\""
"<p id=htestsaysno class=says>Hypothesis test is off</p>"
"<p id=htestsaysyes class=says style='display:none;'>Hypothesis test is on <button type=button onclick=turnoffHtest()>Turn off test</button></p>"
"<div class=controlpaneldiv>"
  "<div class=cptabstatic>Finding statistically significant changes</div>"
  "<div class=cptabsig onclick=openManual('d-c')>?</div>"

"<p><button type=button onclick=cgiHtest()>Run hypothesis test</button> "
"<span style='color:#858585;'>P-values are log10-transformed for display</span></p>"
"<table border=0 cellpadding=5 style='padding-right:20px;'><tr>" // table 1
"<td valign=top>"
"<div id=htestgroupholder></div>"
"<button type=button onclick=addhtestgroup()>Add group</button> "
"<button type=button onclick=removehtestgroup() id=htestremovegrpbutton>Remove group</button> "
"<button type=button onclick=htestgroupclearcontent()>Clear</button>"
"</td>"
      "<td valign=middle align=center style='color:#858585;'>"
	"Click 'add &#187;' button to add tracks to each group<br>"
	"Or, use context menu option on genome heatmap<br>"
	"<img src=images/menuhtestchoice.png style='opacity:0.5;'>"
      "</td>"
"</tr></table>" // table 1 ends
"<p>"
  "P-value correction:"
  "<select id=htestc style='margin-right:30px;'>"
  "<option value=no selected>don't apply</option>"
  "<option disabled>--- family wise error rate ---</option>"
  "<option value=bonferroni> Bonferroni</option>"
  "<option value=holm> Holm (1979)</option>"
  "<option value=hochberg> Hochberg (1988)</option>"
  "<option value=hommel> Hommel (1988)</option>"
  "<option disabled>---- false discovery rate ----</option>"
  "<option value=BH> Benjamini & Hochberg (1995)</option>"
  "<option value=BY> Benjamini & Yekutieli (2001)</option>"
  "<option value=fdr> fdr</option>"
  "</select>"
  " <span style='color:#858585;'>Cutoff can be set after running hypothesis test</span>"
"</p>"
"<p><button type=button onclick=cgiHtest()>Run hypothesis test</button></p>"
"</div>"
"\",");
}


void onetimedeal_customTrack()
{
printf("\"tgt_customTrack\":\""

"<div class=controlpaneldiv style='padding:0px;padding-top:50px;padding-bottom:20px;'>" // big wrapper

  "<table style='position:absolute;left:50px;top:0px;' cellspacing=0>" // tabs
    "<tr>"
      "<td id=customtracktab_3 class=cptabon onclick=tabclick_customtrack(3) style='border-bottom-left-radius:10px;-moz-border-radius-bottomleft:10px;border-right:solid 1px #fff9d2;overflow:hidden;'>bedGraph</td>"
      "<td id=customtracktab_1 class=cptaboff onclick=tabclick_customtrack(1) style='border-right:solid 1px #fff9d2;position:relative;'>bed&nbsp;<div style='position:absolute;bottom:0px;right:0px;background-color:#AEA887;color:white;padding-left:2px;padding-right:2px;border-top-left-radius:5px;-moz-border-radius-topleft:5px;'>&#8914;</div></td>"
      "<td id=customtracktab_5 class=cptaboff onclick=tabclick_customtrack(5) style='border-right:solid 1px #fff9d2;'>sam</td>"
      "<td id=customtracktab_100 class=cptaboff onclick=tabclick_customtrack(100) style='border-right:solid 1px #fff9d2;'>dataHUB</td>"
      "<td id=customtracktab_101 class=cptaboff onclick=tabclick_customtrack(101) style='border-bottom-right-radius:10px;-moz-border-radius-bottomright:10px;overflow:hidden;'>Manage (<span id=custtrackhowmany>0</span>)</td>"
    "</tr>"
  "</table>" // tabs ends

  "<div id=manualbt_customtrack class=cptabsig onclick=openManual_customtrack(event)>?</div>"

"<table id=customtrackwrapper_3 border=0 cellspacing=0 cellpadding=10 width=100%%>" // bigwig wrapper
"<tr><td colspan=2 align=center valign=middle style='height:50px;color:#858585;'>"
  "<img src=images/null.gif width=780 height=1><br>"
  "<div class=alertmsg>bigWig files are no longer supported, please use tabix files instead. <a style='color:black;text-decoration:underline;' href=http://washugb.blogspot.com/2012/09/generate-tabix-files-from-bigwig-files.html target=_blank>Learn more</a></div>"
"</td></tr>"
"<tr>"
   "<td align=right style='width:300px;'>bedgraph file URL</td>"
   "<td><input type=text id=newcustombigwigfileurl size=50></td>"
"</tr><tr>"
   "<td align=right>Track name</td>"
   "<td><input type=text id=newcustombigwigtkname size=20> <button type=button onclick=\\\"document.getElementById('newcustombigwigfileurl').value='';document.getElementById('newcustombigwigtkname').value='';\\\">Clear</button></td>"
"</tr><tr id=bait36 style='background-color:#F4EEC7;display:none;'>"
   "<td style='border-top:solid 1px #E0DAB5;' align=right valign=top>"
     "<table id=custpriorholder3 cellspacing=1 cellpadding=3 style='background-color:#c7c7c7;'><tbody><tr><td colspan=3 style='color:white;font-size:12px;'>Selected terms will be listed below</td></tr></tbody></table>"
   "</td><td style='border-top:solid 1px #E0DAB5;' valign=top>"
     "<div style='position:relative;'>"
       "<button type=button onclick=custprior3_invokemds(event)>annotate with metadata &#187;</button> "
       "<span style='color:#858585;'>this step is optional</span> "
       "<button type=button onclick=toggle36() style='position:absolute;top:0px;right:0px;'>&#10005;</button>"
     "</div>"
  "</td>"
"</tr><tr>"
   "<td style='border-top:solid 1px #E0DAB5;padding-bottom:20px;' align=right>"
     "<button type=button onclick=submitCustomHmtkNumerical()>SUBMIT &#10148;</button>"
   "</td>"
   "<td style='border-top:solid 1px #E0DAB5;padding-bottom:20px;' align=right>"
     "<button type=button id=hook36 onclick=toggle36()>metadata annotation (optional)</button>"
   "</td>"
"</tr>"
"</table>" // bigwig wrapper ends

"<table id=customtrackwrapper_1 style='display:none;' cellspacing=0 cellpadding=10 width=100%%>" // bigbed wrapper
"<tr><td colspan=2 align=center valign=middle style='height:50px;color:#858585;'>"
  "<img src=images/null.gif width=780 height=1><br>"
  "<div class=alertmsg>bigBed files are no longer supported, please use tabix files instead. <a style='color:black;text-decoration:underline;' href=http://washugb.blogspot.com/2012/09/generate-tabix-files-from-bigbed-files.html target=_blank>Learn more</a></div>"
"</td></tr>"
"<tr>"
   "<td align=right style='width:300px;'>bed file URL</td>"
   "<td><input type=text id=newcustombigbedfileurl size=50></td>"
"</tr><tr>"
   "<td align=right>Track name</td>"
   "<td><input type=text id=newcustombigbedtkname size=20> <button type=button onclick=\\\"document.getElementById('newcustombigbedfileurl').value='';document.getElementById('newcustombigbedtkname').value='';\\\">Clear</button></td>"
"</tr><tr>"
   "<td align=right>Display mode</td>"
   "<td>"
       "<select id=newcustombigbedmode><option value="M_thin_s">thin</option><option value="M_full_s">full</option><option value="M_den_s">density</option></select>"
   "</td>"
"</tr><tr>"
  "<td colspan=2 align=center valign=middle style='padding:0px;'>"
    "<table cellspacing=0 cellpadding=6 style='margin-bottom:10px;'><tr>"
      "<td style='background-color:#F4EEC7;'>"
      "<input type=checkbox id=newcustombigbed_islongrange> <label for=newcustombigbed_islongrange>This track contains long-range interaction data</lable>"
      "</td><td style='color:ebe5c2;font-size:18px;font-weight:bold;text-shadow:0px -1px 0px #676346;background-color:#aa839c;border-top-right-radius:10px;border-bottom-right-radius:10px;moz-border-radius-topright:10px;moz-border-radius-bottomright:10px;font-size:20px;cursor:pointer;' onmouseover=\\\"this.style.backgroundColor='#956584'\\\" onmouseout=\\\"this.style.backgroundColor='#aa839c'\\\" onclick=openManual('c-c')>&#8914;</td>"
    "</table>"
  "</td>"
"</tr><tr id=bait37 style='background-color:#F4EEC7;display:none;'>"
   "<td style='border-top:solid 1px #E0DAB5;' align=right valign=top>"
     "<table id=custpriorholder1 cellspacing=1 cellpadding=3 style='background-color:#c7c7c7;'><tbody><tr><td colspan=3 style='color:white;font-size:12px;'>Selected terms will be listed below</td></tr></tbody></table>"
   "</td><td style='border-top:solid 1px #E0DAB5;' valign=top>"
     "<div style='position:relative;'>"
       "<button type=button onclick=custprior1_invokemds(event)>annotate with metadata &#187;</button> "
       "<span style='color:#858585;'>this step is optional</span>"
       "<button type=button onclick=toggle37() style='position:absolute;top:0px;right:0px;'>&#10005;</button>"
     "</div>"
  "</td>"
 "</tr><tr>"
   "<td style='border-top:solid 1px #E0DAB5;'>"
     "<div style='position:relative;width:300px;height:25px;'>"
     "<button type=button onclick=submitNewcustombigbed() style='position:absolute;top:0px;right:0px;'>SUBMIT &#10148;</button>"
     "</div>"
   "</td>"
   "<td align=right style='border-top:solid 1px #E0DAB5;'>"
     "<button type=button id=hook37 onclick=toggle37()>metadata annotation (optional)</button>"
   "</td>"
"</tr>"
"</table>" // bigbed wrapper ends

"<table id=customtrackwrapper_5 style='display:none;' border=0 cellspacing=0 cellpadding=10 width=100%%>" // BAM wrapper
"<tr><td colspan=2 align=center valign=middle style='height:50px;color:#858585;'>"
  "<img src=images/null.gif width=780 height=1><br>"
  "<div class=alertmsg>BAM files are no longer supported, please use tabix files instead. <a style='color:black;text-decoration:underline;' href=http://washugb.blogspot.com/2012/09/generate-tabix-file-from-bam-file.html target=_blank>Learn more</a></div>"
"</td></tr>"
"<tr>"
   "<td align=right valign=top style='width:300px;'>sam file URL</td>"
   "<td><input type=text id=newcustombamfileurl size=50><br>"
     "<span style='font-size:12px;color:#ccc;'>If sam file is: http://yourdomain/folder/fatone.gz<br>"
     "index file must be: http://yourdomain/folder/fatone.gz.tbi</span>"
   "</td>"
"</tr><tr>"
   "<td align=right>Track name</td>"
   "<td><input type=text id=newcustombamtkname size=20> <button type=button onclick=\\\"document.getElementById('newcustombamfileurl').value='';document.getElementById('newcustombamtkname').value='';\\\">Clear</button></td>"
"</tr><tr>"
   "<td align=right>Display mode</td>"
   "<td>"
       "<select id=newcustombammode><option value="M_thin_s">thin</option><option value="M_full_s">full</option><option value="M_den_s">density</option></select>"
   "</td>"
"</tr><tr id=bait38 style='background-color:#F4EEC7;display:none;'>"
   "<td style='border-top:solid 1px #E0DAB5;' align=right valign=top>"
     "<table id=custpriorholder5 cellspacing=1 cellpadding=3 style='background-color:#c7c7c7;'><tbody><tr><td colspan=3 style='color:white;font-size:12px;'>Selected terms will be listed below</td></tr></tbody></table>"
   "</td><td style='border-top:solid 1px #E0DAB5;' valign=top>"
     "<div style='position:relative;'>"
     "<button type=button onclick=custprior5_invokemds(event)>annotate with metadata &#187;</button> "
     "<span style='color:#858585;'>this step is optional</span>"
       "<button type=button onclick=toggle38() style='position:absolute;top:0px;right:0px;'>&#10005;</button>"
     "</div>"
  "</td>"
"</tr><tr>"
  "<td style='border-top:solid 1px #E0DAB5;'>"
    "<div style='position:relative;width:300px;height:25px;'>"
    "<button type=button class=s style='position:absolute;left:0px;top:0px;font-size:10px;' onclick=\\\"this.parentNode.parentNode.parentNode.nextSibling.firstChild.firstChild.style.display='block'\\\">Caution with BAM track</button>"
    "<button type=button style='position:absolute;right:0px;top:0px;' onclick=submitNewcustombam()>SUBMIT &#10148;</button> "
    "</div>"
  "</td>"
  "<td align=right style='border-top:solid 1px #E0DAB5;'>"
    "<button type=button id=hook38 onclick=toggle38()>metadata annotation (optional)</button>"
  "</td>"
"</tr><tr>"
  "<td align=center colspan=2>"
    "<div style='display:none;position:relative;margin-top:10px;padding:5px;padding-right:35px;text-align:left;border:solid 1px #E0DAB5;background-color:#F4EEC7;width:550px;'>"
      "<button type=button style='position:absolute;top:5px;right:5px;' onclick=\\\"this.parentNode.style.display='none'\\\">&#10005;</button>"
      "<table><tr><td style='padding-right:15px;opacity:0.5;'><img src=images/cow2.jpg></td>"
      "<td valign=top style='color:#858585;'>Beware that displaying sam file over large genomic region may overload our server, and increases the risk of crashing your computer</td></tr></table>"
    "</div>"
  "</td>"
"</tr>"
"</table>" // BAM wrapper ends

"<div id=customtrackwrapper_100 style='display:none;padding:30px;padding-top:10px;text-align:center;'>" // hub
    "<img src=images/null.gif width=740 height=1><br>"
  "dataHUB is essentially batch uploading of custom tracks. "
  "<span id=samplehuburl></span>"
  "<br><br>--- this function is experimental ---"
  "<br><br>"
  "<input type=text size=50 id=datahuburl value='Enter URL of hub descriptor file' onfocus='if(this.value==\\\"Enter URL of hub descriptor file\\\") this.value=\\\"\\\"' onblur='if(this.value.length==0) this.value=\\\"Enter URL of hub descriptor file\\\"'>"
  "<br><br>"
  "<button type=button id=loadhubbutt onclick=loaddatahub()>Load data hub</button> "
  "<button type=button onclick='document.getElementById(\\\"datahuburl\\\").value=\\\"\\\"'>Clear</button>"
"</div>" // hub ends

"<div id=customtrackwrapper_101 style='display:none;padding:30px;padding-top:40px;'>" // manage
"<div class=bordertb>"
  "<div>Available custom tracks by file type"
    "<div class=rclosebut id=hook35 onclick=toggle35() style='font-size:large;-webkit-transform:rotate(-90deg);-moz-transform:rotate(-90deg);top:0px;'>&#10140;</div>"
  "</div>"
  "<div id=bait35 style='display:block;'>"
    "<img src=images/null.gif width=720 height=1>"
    "<table style='background-color:#C9B0C0;' cellspacing=1>"
    "<tr><td style='color:white;' align=center><img src=images/null.gif width=718 height=1><br>Heatmap track (<span id=cust3howmany>0</span>)</td></tr>"
    "<tr><td style='background-color:#fcf8ee;'><div><table id=custHolder3 width=100%%><tbody></tbody></table></div></td></tr>"
    "<tr><td style='color:white;' align=center>Genome annotation track (<span id=cust1howmany>0</span>)</td></tr>"
    "<tr><td style='background-color:#fcf8ee;'><div><table id=custHolder1 width=100%%><tbody></tbody></table></div></td></tr>"
    "<tr><td style='color:white;' align=center>Long range interaction track (<span id=cust10howmany>0</span>)</td></tr>"
    "<tr><td style='background-color:#fcf8ee;'><div><table id=custHolder10 width=100%%><tbody></tbody></table></div></td></tr>"
    "<tr><td style='color:white;' align=center>Read alignment track (<span id=cust5howmany>0</span>)</td></tr>"
    "<tr><td style='background-color:#fcf8ee;'><div><table id=custHolder5 width=100%%><tbody></tbody></table></div></td></tr>"
    "</table>"
    "<div style='color:#aaa;'>Click delete button to permanently remove a custom track</div>"
  "</div>"
"</div>"
"<br>"
"<div class=bordertb>"
  "<div>Your custom tracks in an organized way"
    "<div class=rclosebut id=hook34 onclick=toggle34() style='font-size:large;-webkit-transform:rotate(-90deg);-moz-transform:rotate(-90deg);top:0px;'>&#10140;</div>"
  "</div>"
  "<div id=bait34 style='display:block;'>"
    "<img src=images/null.gif width=720 height=1>"
    "<table cellspacing=5>"
      "<tr><td style='color:#858585;'>Row</td><td style='color:#858585;'>Column</td><td rowspan=2 valign=bottom align=center style='padding-left:20px;'><button type=button onclick=custmd_makegrid()>Generate</button></td></tr>"
      "<tr><td><select id=custmdselect_row onchange=custmdselect_toggle()></select></td><td><select id=custmdselect_col><option value='|'>don't use</option</select></td></tr>"
    "</table>"
    "<br>"
    "<table id=custmdgrid><tbody></tbody></table>"
  "</div>"
"</div>"
"</div>" // manage ends

"</div>" // big wrapper ends
"\",");
}

void onetimedeal_session()
{
printf("\"tgt_session\":\""
"<div class=controlpaneldiv style='width:800px;padding:0px;'>" // control panel div
  "<div class=cptabstatic>Save &amp; retrieve browsing status</div>"
  "<div class=cptabsig onclick=openManual('f')>?</div>"
  // session id
  "<div style='display:table;margin-top:60px;margin-left:auto;margin-right:auto;padding:3px;padding-left:8px;padding-right:8px;border-top-left-radius:3px;-moz-border-radius-topleft:3px;border-top-right-radius:3px;-moz-border-radius-topright:3px;overflow:hidden;border:solid 1px #B4C9E4;border-bottom-width:0px;background-color:#FFFFCC;background:-webkit-gradient(linear,left top,left bottom,from(#ffffcc),to(#EBEAB2));background:-moz-linear-gradient(top,#ffffcc,#EBEAB2);'>"
    "<span style='font-size:100%%;color:#95ACD6;'>Current session ID &nbsp;&nbsp;&nbsp;</span>"
    "<div id=sessionId style='display:table-cell;font:bold 150%% courier;color:#809FFF;'></div>"
  "</div>"
  // status list
  "<div style='margin-bottom:3px;border:solid 1px #B4C9E4;border-left-width:0px;border-right-width:0px;background-color:#EDF1F8;text-align:center;'>"
    "<table id=statusHolder cellspacing=5 style='width:100%%'></table>"
  "</div>"
  "<div id=sessionsaysyes style='display:none;color:#858585;font-size:12px;padding-left:20px;'>&uarr; click on note to restore status</div>"
  // big buttons
  "<table border=0 cellpadding=20 style='margin-left:auto;margin-right:auto;margin-bottom:20px;margin-top:17px;'><tr>"
   "<td align=center valign=top>"
     "<button type=button onclick=saveStatus() style='margin-bottom:20px;'>"
       "<table><tr><td><img src=images/savestatus.png height=40></td><td align=center valign=middle>Save status</td></tr></table>"
     "</button><br>"
     "<input type=text id=statusNote size=12><br>"
     "<span style='color:#858585;'>optionally, enter a short<br>note to describe this status</span>"
   "</td>"
   "<td style='width:100px;'> </td>"
   "<td align=center valign=top>"
     "<button type=button onclick=retrieveSession() style='margin-bottom:20px;'>"
       "<table><tr><td><img src=images/retrievestatus.png height=40></td><td align=center valign=middle>Retrieve status</td></tr></table>"
     "</button><br>"
     "<input type=text id=oldSessionId size=12><br>"
     "<span style='color:#858585;'>session ID must be provided</span>"
   "</td>"
  "</tr></table>"
"</div>" // control panel div ends
"\",");
}








char strMayGetgeneStrand(struct slNode *genetracksl, char *what)
{
/* query gene table for given string, if found, return its strand +/-
   else, return '.'

   The strand must be +/-
 */
struct slNode *table;
char *query;
for(table=genetracksl; table!=NULL; table=table->next)
    {
    if(asprintf(&query, "select t.strand from %sstruct as t,%ssymbol as s where (s.name=\"%s\" or s.symbol=\"%s\") and s.id=t.id", table->name, table->name, what, what)<0) errabort("bae");
    char *re = mysqlGetOnestring(query);
    if(re != NULL)
        return re[0];
    }
return '.';
}




long getScaffoldLength(char *name)
{
char *query;
if(asprintf(&query, "select childLength from scaffoldInfo where child='%s'", name)<0) errabort("bae");
long len = mysqlGetPositiveInteger(query);
free(query);
return len;
}

void reviveScaffold()
{
/* session and status obtained from global variable
   given session and status, revive scaffold from table scaffoldRuntime
 */
char *query;
if(asprintf(&query, "select count,names from scaffoldRuntime where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
MYSQL_RES *sr = mysqlGetResult(query);
assert(sr!=NULL);
free(query);
char **row = mysql_fetch_row(sr);
assert(row[0] != NULL);
assert(row[1] != NULL);
assert((lastChrIdx=strMayPositiveInt(row[0]))!=-1);
chrInfo = malloc(sizeof(struct chrInfoNode *) * lastChrIdx);
lastChrIdx--;
int i = 0;
char delim[] = ",";
char *tok = strtok(row[1], delim);
while(tok != NULL)
    {
    chrInfo[i] = (struct chrInfoNode *)malloc(sizeof(struct chrInfoNode));
    if(asprintf(&chrInfo[i]->name, "%s", tok)<0) errabort("bae");
    tok = strtok(NULL, delim);
    assert(tok != NULL);
    assert((chrInfo[i]->length=strMayPositiveInt(tok))!=-1);
    i++;
    tok = strtok(NULL, delim);
    }
assert(i == lastChrIdx+1);
mysql_free_result(sr);
if(SQUAWK)
    fputs("reviveScaffold() done\n", stderr);
if(0)
    {
    for(i=0; i<=lastChrIdx; i++)
        fprintf(stderr, "%s %u\n", chrInfo[i]->name, chrInfo[i]->length);
    }
}

void scaffoldAddnew(char *name)
{
/* runtime adding new scaffold into chrInfo and runtime table,
   not reviving!
   lucky we are dealing with a bunch of global variables...
 */
// make new and extended chrInfo array
if(SQUAWK)
    fprintf(stderr, "scaffoldAddnew() adding %s...\n", name);
lastChrIdx++;
struct chrInfoNode **new = malloc(sizeof(struct chrInfoNode *) * (lastChrIdx+1));
int i = 0;
for(; i<lastChrIdx; i++)
    {
    new[i] = malloc(sizeof(struct chrInfoNode));
    new[i]->name = strdup(chrInfo[i]->name);
    new[i]->length = chrInfo[i]->length;
    }
new[lastChrIdx] = malloc(sizeof(struct chrInfoNode));
new[lastChrIdx]->name = strdup(name);
new[lastChrIdx]->length = getScaffoldLength(name);
assert(new[lastChrIdx]->length != -1);
free(chrInfo);
chrInfo = new;
if(SQUAWK)
    fputs("chrInfo extended\n", stderr);
// update runtime table
char *query;
if(asprintf(&query, "select names from scaffoldRuntime where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
char *tmp = mysqlGetOnestring(query);
free(query);
if(asprintf(&query, "update scaffoldRuntime set count=%d,names='%s%s,%u,' where session='%s' and statusId=%d", lastChrIdx+1, tmp, chrInfo[lastChrIdx]->name, chrInfo[lastChrIdx]->length, session, statusId)<0) errabort("bae");
mysqlUpdate(query);
free(query);
}




struct nnode *itemQueryRefGene(struct slNode *genetracksl, char *item, char *genetype, char *genestruct, char *origintype, int leftlength, int rightlength)
{
/* args:
      genetracksl: list of gene track table names
      item: gene name, could be symbol or name of one gene type
      genetype: NULL or a gene table name to query, if NULL, "item" shall be arbitrary type and will iterate over all gene tables
      genestruct: "genebody", "promoter", ...
      origintype, leftlength, rightlength: parameters given by glider options

   query [genetype]symbol table using name, query [genetype]struct table for coord

   in case of exon/intron, will return a list of intervals, thus using struct nnode *
   return NULL for not matching with anything
 */
assert(genetracksl != NULL);
char *query, **row,
     *chrom=NULL, *exonStarts=NULL, *exonEnds=NULL;
char strand='+';
int txStart=0, txEnd=0, cdsStart=0, cdsEnd=0, exonCount=0;
MYSQL_RES *sr;
if(genetype != NULL)
    {
    // only query one table
    if(asprintf(&query, "select st.* from %sstruct as st,%ssymbol as sy where (sy.name=\"%s\" or sy.symbol=\"%s\") and sy.id=st.id", genetype, genetype, item, item)<0) errabort("bae");
    sr = mysqlGetResult(query);
	assert(sr!=NULL);
    free(query);
    if((row=mysql_fetch_row(sr)) == NULL)
		{
		mysql_free_result(sr);
		return NULL;
		}
    chrom = strdup(row[1]);
    exonStarts = strdup(row[8]);
    exonEnds = strdup(row[9]);
    strand = row[2][0];
	assert((txStart=strMayPositiveInt(row[3]))!=-1);
	assert((txEnd=strMayPositiveInt(row[4]))!=-1);
	assert((cdsStart=strMayPositiveInt(row[5]))!=-1);
	assert((cdsEnd=strMayPositiveInt(row[6]))!=-1);
	assert((exonCount=strMayPositiveInt(row[7]))!=-1);
    }
else
    {
    // iterate gene tables and query, quit whenever a hit is found
    struct slNode *table = genetracksl;
    for(; table!=NULL; table=table->next)
        {
		if(asprintf(&query, "select st.* from %sstruct as st,%ssymbol as sy where (sy.name=\"%s\" or sy.symbol=\"%s\") and sy.id=st.id", table->name, table->name, item, item)<0) errabort("bae");
		sr = mysqlGetResult(query);
		assert(sr!=NULL);
		free(query);
		if((row=mysql_fetch_row(sr)) != NULL)
			{
			chrom = strdup(row[1]);
			exonStarts = strdup(row[8]);
			exonEnds = strdup(row[9]);
			strand = row[2][0];
			assert((txStart=strMayPositiveInt(row[3]))!=-1);
			assert((txEnd=strMayPositiveInt(row[4]))!=-1);
			assert((cdsStart=strMayPositiveInt(row[5]))!=-1);
			assert((cdsEnd=strMayPositiveInt(row[6]))!=-1);
			assert((exonCount=strMayPositiveInt(row[7]))!=-1);
			break;
			}
		}
    if(chrom == NULL)
		{
		mysql_free_result(sr);
		return NULL;
		}
    }
mysql_free_result(sr);

struct nnode *sl=NULL, *t;
int chrIdx = strMayChrID(chrom);
if(chrIdx == -1)
    {
    /* upon new scaffold sequence, not in chrInfo
       insert this into chrInfo
     */
    scaffoldAddnew(chrom);
    chrIdx = lastChrIdx;
    }
long thischrlen = chrInfo[chrIdx]->length;
if(strcmp(genestruct, "genebodypromoter") == 0)
    {
    t = malloc(sizeof(struct nnode));
    t->chrIdx = chrIdx;
    t->flank3start = t->flank3stop = -1;
    if(strand == '+')
        {
	t->stop = txEnd;
	t->start = (txStart>=3000) ? txStart-3000 : 0;
	t->flank5start = t->start;
	t->flank5stop = txStart;
	}
    else
        {
	t->start = txStart;
	t->stop = (txEnd+3000 >= thischrlen) ? thischrlen : txEnd+3000;
	t->flank5start = txEnd;
	t->flank5stop = t->stop;
	}
    t->next = sl;
    sl = t;
    }
else if(strcmp(genestruct, "genebody") == 0)
    {
    t = malloc(sizeof(struct nnode));
    t->chrIdx = chrIdx;
    t->start = txStart;
    t->stop = txEnd;
    t->flank5start = t->flank5stop = t->flank3start = t->flank3stop = -1;
    t->strand = strand;
    t->next = sl;
    sl = t;
    }
else if(strcmp(genestruct, "promoter") == 0)
    {
    t = malloc(sizeof(struct nnode));
    t->chrIdx = chrIdx;
    t->flank5start = t->flank5stop = t->flank3start = t->flank3stop = -1;
    if(strand == '+')
        {
	t->stop = txStart;
	t->start = (txStart>=3000) ? txStart-3000 : 0;
	}
    else
        {
	t->start = txEnd;
	t->stop = (txEnd+3000 >= thischrlen) ? thischrlen : txEnd+3000;
	}
    t->strand = strand;
    t->next = sl;
    sl = t;
    }
else if(strcmp(genestruct, "custom") == 0)
    {
    t = malloc(sizeof(struct nnode));
    t->chrIdx = chrIdx;
    t->strand = strand;
    if(strcmp(origintype, "txstart") == 0)
        {
	if(strand == '+')
	    {
	    t->start = (txStart>=leftlength) ? txStart-leftlength : 0;
	    t->stop = (txStart+rightlength>=thischrlen) ? thischrlen : txStart+rightlength;
	    t->flank5start = t->start;
	    t->flank5stop = t->flank3start = txStart;
	    t->flank3stop = t->stop;
	    }
	else
	    {
	    t->start = (txEnd>=rightlength) ? txEnd-rightlength : 0;
	    t->stop = (txEnd+leftlength>=thischrlen) ? thischrlen : txEnd+leftlength;
	    t->flank3start = t->start;
	    t->flank3stop = t->flank5start = txEnd;
	    t->flank5stop = t->stop;
	    }
	}
    else if(strcmp(origintype, "txstop") == 0)
        {
	if(strand == '+')
	    {
	    t->start = (txEnd>=leftlength) ? txEnd-leftlength : 0;
	    t->stop = (txEnd+rightlength>=thischrlen) ? thischrlen : txEnd+rightlength;
	    t->flank5start = t->start;
	    t->flank5stop = t->flank3start = txEnd;
	    t->flank3stop = t->stop;
	    }
	else
	    {
	    t->start = (txStart>=rightlength) ? txStart-rightlength : 0;
	    t->stop = (txStart+leftlength>=thischrlen) ? thischrlen : txStart+leftlength;
	    t->flank3start = t->start;
	    t->flank3stop = t->flank5start = txStart;
	    t->flank5stop = t->stop;
	    }
	}
    else if(strcmp(origintype, "genebody") == 0)
        {
	if(strand == '+')
	    {
	    t->start = (txStart>=leftlength) ? txStart-leftlength : 0;
	    t->stop = (txEnd+rightlength>=thischrlen) ? thischrlen : txEnd+rightlength;
	    t->flank5start = t->start;
	    t->flank5stop = txStart;
	    t->flank3start = txEnd;
	    t->flank3stop = t->stop;
	    }
	else
	    {
	    t->start = (txStart>=rightlength) ? txStart-rightlength : 0;
	    t->stop = (txEnd+leftlength>=thischrlen) ? thischrlen : txEnd+leftlength;
	    t->flank3start = t->start;
	    t->flank3stop = txStart;
	    t->flank5start = txEnd;
	    t->flank5stop = t->stop;
	    }
	}
    else
        errabort("itemQueryRefGene: unknown origin type");
    t->next = sl;
    sl = t;
    }
else
    {
    /* remaining struct options are utrs, exons, introns
       all require exon coord
     */
    int *exonstartarr = str2intArr(exonStarts, exonCount);
    int *exonstoparr = str2intArr(exonEnds, exonCount);

    if(strcmp(genestruct, "utr5") == 0)
        {
	int start,stop;
	if(strand == '+')
	    {
	    start = txStart;
	    stop = (cdsStart > exonstoparr[0]) ? exonstoparr[0] : cdsStart;
	    }
	else
	    {
	    stop = txEnd;
	    start = (exonstartarr[exonCount-1] > cdsEnd) ? exonstartarr[exonCount-1] : cdsEnd;
	    }
        t = malloc(sizeof(struct nnode));
        t->chrIdx = chrIdx;
        t->start = start;
        t->stop = stop;
        t->flank5start = t->flank5stop = t->flank3start = t->flank3stop = -1;
        t->strand = strand;
        t->next = sl;
        sl = t;
	}
    else if(strcmp(genestruct, "utr3") == 0)
        {
	int start,stop;
	if(strand == '+')
	    {
	    stop = txEnd;
	    start = (exonstartarr[exonCount-1] > cdsEnd) ? exonstartarr[exonCount-1] : cdsEnd;
	    }
	else
	    {
	    start = txStart;
	    stop = (cdsStart > exonstoparr[0]) ? exonstoparr[0] : cdsStart;
	    }
        t = malloc(sizeof(struct nnode));
        t->chrIdx = chrIdx;
        t->start = start;
        t->stop = stop;
        t->flank5start = t->flank5stop = t->flank3start = t->flank3stop = -1;
        t->strand = strand;
        t->next = sl;
        sl = t;
	}
    else if(strcmp(genestruct, "exons") == 0)
        {
	int i;
	for(i=0; i<exonCount; i++)
	    {
	    t = malloc(sizeof(struct nnode));
	    t->chrIdx = chrIdx;
	    t->start = exonstartarr[i];
	    t->stop = exonstoparr[i];
            t->flank5start = t->flank5stop = t->flank3start = t->flank3stop = -1;
	    t->strand = strand;
	    t->next = sl;
	    sl = t;
	    }
        }
    else if(strcmp(genestruct, "introns") == 0)
        {
	if(exonCount == 1)
	    { 
	    // no intron if only one exon
	    mysql_free_result(sr);
	    return NULL;
	    }
	int i;
        for(i=0; i<exonCount-1; i++)
            {
	    t = malloc(sizeof(struct nnode));
	    t->chrIdx = chrIdx;
	    t->start = exonstoparr[i];
	    t->stop = exonstartarr[i+1];
            t->flank5start = t->flank5stop = t->flank3start = t->flank3stop = -1;
	    t->strand = strand;
	    t->next = sl;
	    sl = t;
	    }
        }
    else
        errabort("itemQueryRefGene: unknown genestruct option");
    }
return sl;
}



void makeDspBoundaryFromCgi(struct displayedRegion *dsp)
{
char *s=cgiString(StartChrom_cgi);
assert(s!=NULL);
int startChr = strMayChrID(s);
assert(startChr!=-1);
int startCoord = cgiInt(StartCoord_cgi);
s=cgiString(StopChrom_cgi);
assert(s!=NULL);
int stopChr = strMayChrID(s);
assert(stopChr!=-1);
int stopCoord = cgiInt(StopCoord_cgi);
setDspBoundary(dsp, startChr, startCoord, stopChr, stopCoord);
}

void printJson_hmtk4datasets(struct slNode *sl)
{
/* this is supposed to be the only place using gnu hash
argument is a list of data set name
assemble hmtk info from multiple tables to:
- reduce amount of json text to transfer
- reduce number of mysql queries
tables:
- track2Label for label
- track2Annotation for metadata annotation
- track2Ft for filetype
- track2Categorical for categorical info
*/
// count # of hmtk
char *query, **row;
int count=0;
struct slNode *t;
struct slNode *tksl=NULL, *newtk; // as there's no way to iterate the hash
struct tnode *record;
for(t=sl; t!=NULL; t=t->next)
	{
	assert(asprintf(&query, "select count(tkname) from %s", t->name)>0);
	int c=mysqlGetPositiveInteger(query);
	assert(c!=-1);
	count+=c;
	free(query);
	}
assert(hcreate((size_t)count*1.25)!=0);
// for each dataset
for(t=sl; t!=NULL; t=t->next)
	{
	// label
	assert(asprintf(&query, "select b.name,b.label from track2Label as b,%s as a where a.tkname=b.name", t->name)>0);
	MYSQL_RES *sr=mysqlGetResult(query);
	assert(sr!=NULL);
	free(query);
	while((row=mysql_fetch_row(sr))!=NULL)
		{
		assert(row[0]!=NULL);
		assert(row[1]!=NULL);
		record=malloc(sizeof(struct tnode));
		record->t1=strdup(row[1]);
		record->t2=NULL; record->t4=-1;
		ENTRY ent;
		ent.key=strdup(row[0]);
		ent.data=(char *)record;
		hsearch(ent, ENTER);
		newtk=malloc(sizeof(struct slNode));
		newtk->name=ent.key;
		newtk->next=tksl;
		tksl=newtk;
		}
	mysql_free_result(sr);

	// md anno
	assert(asprintf(&query, "select b.name,b.attridx from track2Annotation as b,%s as a where a.tkname=b.name", t->name)>0);
	sr=mysqlGetResult(query);
	assert(sr!=NULL);
	free(query);
	while((row=mysql_fetch_row(sr))!=NULL)
		{
		assert(row[0]!=NULL);
		assert(row[1]!=NULL);
		ENTRY ent;
		ent.key=strdup(row[0]);
		ENTRY *ent2=hsearch(ent,FIND);
		if(ent2==NULL)
			{
			// enter
			record=malloc(sizeof(struct tnode));
			record->t2=strdup(row[1]);
			record->t1=NULL; record->t4=-1;
			ent.data=(char *)record;
			hsearch(ent, ENTER);
			newtk=malloc(sizeof(struct slNode));
			newtk->name=ent.key;
			newtk->next=tksl;
			tksl=newtk;
			}
		else
			{
			record=(struct tnode *)(ent2->data);
			record->t2=strdup(row[1]);
			free(ent.key);
			}
		}
	mysql_free_result(sr);

	// filetype, all tracks must have file type
	assert(asprintf(&query, "select b.name,b.ft from track2Ft as b,%s as a where a.tkname=b.name", t->name)>0);
	sr=mysqlGetResult(query);
	assert(sr!=NULL);
	free(query);
	while((row=mysql_fetch_row(sr))!=NULL)
		{
		assert(row[0]!=NULL);
		assert(row[1]!=NULL);
		ENTRY ent;
		ent.key=strdup(row[0]);
		ENTRY *ent2=hsearch(ent,FIND);
		assert(ent2!=NULL);
		record=(struct tnode *)(ent2->data);
		record->t4=strMayPositiveInt(row[1]);
		free(ent.key);
		}
	mysql_free_result(sr);
	}


// json output
// meanwhile query info for categorical tracks
printf("'hmtkinfo':{");
for(newtk=tksl; newtk!=NULL; newtk=newtk->next)
	{
	ENTRY ent;
	ent.key=newtk->name;
	ENTRY *ent2=hsearch(ent, FIND);
	assert(ent2!=NULL);
	record=(struct tnode *)(ent2->data);
	printf("'%s':{label:\"%s\", md:[%s], ft:%d,", newtk->name, record->t1, record->t2, record->t4);
	if(record->t4==FT_cat_n)
		{
		assert(asprintf(&query, "select info from track2Categorical where name='%s'", newtk->name)>0);
		char *re=mysqlGetOnestring(query);
		free(query);
		if(re!=NULL)
			{
			printf("cateInfo:{%s}", re);
			free(re);
			}
		}
	printf("},");
	free(newtk->name);
	free(record->t1);
	free(record->t2);
	free(record);
	}
printf("},");
slFree(newtk);
hdestroy();
}

void printJson_scaffoldRuntimeInfo()
{
// for client to stuff info into cpholder
int i;
printf("'chrInfo':{");
for(i=0; i<=lastChrIdx; i++)
    printf("'%s':%u,", chrInfo[i]->name, chrInfo[i]->length);
printf("},");
printf("'scaffoldOrder':[");
for(i=0; i<=lastChrIdx; i++)
    printf("'%s',", chrInfo[i]->name);
printf("],");
}

struct slNode *tryMakeGenetracksl()
{
/* need to be already connected to a genome database
   return NULL upon failure
 */
char *query = "select hasGene from config";
char *re = mysqlGetOnestring(query);
if(re[0] == '0')
    return NULL;

int genegrpid = mysqlGetGenesGroupId();
if(genegrpid == -1)
    return NULL;

struct slNode *genetracksl=NULL, *tt;
char **row;
if(asprintf(&query, "select name from decorInfo where parent is NULL and grp=%d", genegrpid)<0) errabort("bae");
MYSQL_RES *sr = mysqlGetResult(query);
assert(sr!=NULL);
free(query);
while((row=mysql_fetch_row(sr)) != NULL)
    {
    tt = malloc(sizeof(struct slNode));
    tt->name = strdup(row[0]);
    tt->next = genetracksl;
    genetracksl = tt;
    }
mysql_free_result(sr);
return genetracksl;
}



int main()
{

clock_t cpuTimeStart, cpuTimeTemp;
if(CHECKCPUTIME) cpuTimeStart = clock();

if(SQUAWK) fputs(">>>>>\n", Squawk);


{
/* initiate cgi hash 
this program only deals with "get", not "post"
all parameters passed via cgi must be escaped and be decoded here
** no empty value allowed, e.g. k1=v1&k2=&k3=v3&...
as =& will be used to chop up things...
TODO use singly linked list instead of gnu hash to get rid of entry limit
*/
	char *tmp=getenv("QUERY_STRING");
	if(tmp==NULL)
		{
		if(SQUAWK) fputs("cgi got no param\n", stderr);
		return 1;
		}
	if(strstr(tmp, "NODECODE")!=tmp)
		{
		int len=strlen(tmp);
		// decode
		char *tmp2 = malloc(sizeof(char) * (len+1));
		strDecode(tmp, tmp2, len);
		tmp=tmp2;
		}
	if(0) fprintf(stderr, "%s\n\n", tmp);
	char delim[]="=&";
	struct tnode *t;
	char *tok=strtok(tmp,delim);
	assert(tok!=NULL);
	while(tok!=NULL)
		{
		t=malloc(sizeof(struct tnode));
		t->t1=strdup(tok);
		assert((tok=strtok(NULL,delim))!=NULL);
		t->t2=strdup(tok);
		tok=strtok(NULL,delim);
		if(0) fprintf(stderr, "key: %s\n", t->t1);
		t->next=cgiparamsl;
		cgiparamsl=t;
		}
	if(SQUAWK) fputs("cgi param parsed\n", stderr);
}


/* on page start up proccedures
   dealing with url parameters, generating selection dialog etc.
 */
if(cgiVarExists("validateurlparam_genome"))
	{
	// user provides reference genome name from url, need to convert it into dbname
	puts("Content-Type:application/text\n");
	mysqlConnect(CentralDB);
	char *query;
	if(asprintf(&query, "select dbName from dbTable where ucscmirrordb='%s'", cgiString("validateurlparam_genome"))<0) errabort("bae");
	char *re = mysqlGetOnestring(query);
	if(re == NULL)
		printf("NULL");
	else
		printf("%s",re);
	done();
	return 1;
	}
if(cgiVarExists("validateurlparam_session"))
    {
    // got dbname and session, see if session is valid
    puts("Content-Type:application/text\n");
    mysqlConnect(cgiString("dbName"));
    char *query;
    if(asprintf(&query, "select statusId from session where session='%s'", cgiString("session"))<0) errabort("bae");
    MYSQL_RES *sr = mysqlGetResult(query);
    char **row = mysql_fetch_row(sr);
    if(row == NULL)
        {
        printf("NULL");
		}
    else
        {
		while(row != NULL)
			{
			printf("%s,", row[0]);
			row = mysql_fetch_row(sr);
			}
		}
    mysql_free_result(sr);
	done();
    return 1;
    }
if(cgiVarExists("oneshot"))
    {
    puts("Content-Type:application/text\n");
    mysqlConnect(CentralDB);
    MYSQL_RES *sr = mysqlGetResult("select dbName,dbLabel,organism from dbTable");
	assert(sr!=NULL);
    char **row;
    while((row=mysql_fetch_row(sr)) != NULL)
        {
        assert(row[0] != NULL);
		assert(row[1] != NULL);
		assert(row[2] != NULL);
		printf("%s,%s,%s,", row[0], row[1], row[2]);
		}
    mysql_free_result(sr);
	mysql_close(conn);
	done();
    return 1;
    }




if(cgiVarExists("session"))
    session = cgiString("session");
if(cgiVarExists("statusId"))
    statusId = cgiInt("statusId");

// upon isFirst, need to do page initiation on client
// if client changes db, also triggers isFirst

/* determine which db is in use
 */
char *dbName;
if(cgiVarExists("dbName"))
    dbName = cgiString("dbName");
else
    {
    // use default db
    mysqlConnect(CentralDB);
    dbName = mysqlGetOnestring("select dbName from dbTable where isDefault=1");
	assert(dbName!=NULL);
	mysql_close(conn);
    }

mysqlConnect(dbName);

assert((bbiDir=mysqlGetOnestring("select bbiPath from config"))!=NULL);
assert((formatdbpath=mysqlGetOnestring("select formatdb from config"))!=NULL);

/*** fetch information on a genome
     exit when done
 ***/
if(cgiVarExists("getgenomeinfo"))
    {
    puts("Content-Type:application:text\n");
    printf("%s", mysqlGetOnestring("select information from config"));
	done();
    return 1;
    }


/*** fetch desc for one repeat
     (for showing decor item info)
     exit when done
 ***/
if(cgiVarExists("getrepeatdesc"))
    {
    puts("Content-Type:application/text\n");
    char *query;
    if(asprintf(&query, "select repName,repClass,repFamily,swScore,milliDiv,milliDel,milliIns from rmsk where genoName=\"%s\" and genoStart=%s and genoEnd=%s", cgiString("chr"), cgiString("start"), cgiString("stop"))<0) errabort("bae");
    MYSQL_RES *sr = mysqlGetResult(query);
	assert(sr!=NULL);
    free(query);
    char **row = mysql_fetch_row(sr);
    if(row!=NULL && row[0]!=NULL)
        {
		if(cgiVarExists("repName"))
			{
			if(strcmp(row[0], cgiString("repName"))==0)
				printf("class: %s<br>family: %s<br>SW score: %s<br>divergence: %.1f%%<br>deletions: %.1f%%<br>insertions: %.1f%%", row[1], row[2], row[3], strtod(row[4],NULL)/10, strtod(row[5],NULL)/10, strtod(row[6],NULL)/10);
			}
		}
    mysql_free_result(sr);
	done();
    return 1;
    }

/*** fetch desc for one metadata term
     exit when done
 ***/
if(cgiVarExists("getmdtermdesc"))
    {
    puts("Content-Type:application/text\n");
    char *query;
    if(asprintf(&query, "select description from trackAttr2idx where idx=\"%s\"", cgiString("getmdtermdesc"))<0) errabort("bae");
    char *desc = mysqlGetOnestring(query);
    free(query);
    if(desc == NULL)
		puts("NODATA");
    else
        puts(desc);
	done();
    return 1;
    }

/*** get sam read info
	exit when done
 ***/
if(cgiVarExists("getsamreadinfo"))
    {
    puts("Content-Type:application/text\n");

	char *read=cgiString("read1");
	char *tok;
	char delim[]=",";
	char *chrom=strtok(read,delim);
	if(chrom==NULL) { fputs("sam read1 invalid chrom\n", stderr); return 1; }
	if((tok=strtok(NULL,delim))==NULL) { fputs("sam read1 no start coord\n", stderr); return 1;}
	int start=strMayPositiveInt(tok);
	if(start==-1) {fputs("sam read1 invalid start\n", stderr);return 1;}
	if((tok=strtok(NULL,delim))==NULL) { fputs("sam read1 no stop coord\n", stderr); return 1;}
	int stop=strMayPositiveInt(tok);
	if(stop==-1) {fputs("sam read1 invalid stop\n", stderr);return 1;}
	//char *strand=strtok(NULL,delim);

	char *seq=getSeq(chrom, start+1, stop);
	if(seq==NULL)
		printf("ERROR");
	else
		{
		printf("%s",seq);
		free(seq);
		}
	
	if(cgiVarExists("read2"))
		{
		printf(",");
		read=cgiString("read2");
		chrom=strtok(read,delim);
		if(chrom==NULL) { fputs("sam read2 invalid chrom\n", stderr); return 1; }
		if((tok=strtok(NULL,delim))==NULL) { fputs("sam read2 no start coord\n", stderr); return 1;}
		start=strMayPositiveInt(tok);
		if(start==-1) {fputs("sam read2 invalid start\n", stderr);return 1;}
		if((tok=strtok(NULL,delim))==NULL) { fputs("sam read2 no stop coord\n", stderr); return 1;}
		stop=strMayPositiveInt(tok);
		if(stop==-1) {fputs("sam read2 invalid stop\n", stderr);return 1;}
		//strand=strtok(NULL,delim);
		seq=getSeq(chrom, start+1, stop);
		if(seq==NULL)
			printf("ERROR");
		else
			{
			printf("%s",seq);
			free(seq);
			}
		}
	done();
    return 1;
    }



/*** save pieces of long URL
     exit when done
 ***/
if(cgiVarExists("saveURLpiece"))
    {
	fputs("saving URL piece...\n", stderr);
    char *query;
    if(asprintf(&query, "insert into tempURL values('%s', %s, '%s')", session, cgiString("offset"), cgiString("saveURLpiece"))<0) errabort("bae");
    mysqlUpdate(query);
    puts("Content-Type:application/text\n\n");
    if(SQUAWK) fputs("url piece saved\n", Squawk);
	done();
    return 1;
    }


if(cgiVarExists("removeGenesetrecord"))
    {
    /* clean up db, called by cancelling gene set view
     */
    char *query;
    if(asprintf(&query, "delete from genesetRuntime where session='%s' and statusId=%s", session, cgiString("statusId"))<0) errabort("bae");
    mysqlUpdate(query);
    free(query);
    puts("Content-Type:application/text\n");
	done();
    return 1;
    }


/* pushing the "get sequence" button
*/
if(cgiVarExists("getChromseqtemp"))
	{
	puts("Content-Type:application/text\n");
	srand(time(0));
	int randnum = rand();
	char *outfile;
	if(asprintf(&outfile, "%s/%s.%d.fa", WWWT, session, randnum)<0) errabort("bae");
	FILE *fout = fopen(outfile, "w");
	if(fout == NULL)
		errabort("failed to open temp file to write");
	free(outfile);

	char *regions = cgiString("regionlst");
	char delim[] = " \t-:";
	char *tok = strtok(regions, delim);
	while(tok != NULL)
		{
		char *chr = tok;
		assert((tok=strtok(NULL, delim))!=NULL);
		int start = strMayPositiveInt(tok);
		assert(start!=-1);
		assert((tok=strtok(NULL, delim))!=NULL);
		int stop = strMayPositiveInt(tok);
		assert(stop!=-1);
		tok = strtok(NULL, delim);
		char *s=getSeq(chr, start+1, stop);
		fprintf(fout, ">%s:%d-%d\n%s\n", chr,start,stop,s);
		}
	fclose(fout);
	printf("%d", randnum);
	done();
	return 1;
	}

/* make gene decor track list 
 */
genetracksl = tryMakeGenetracksl();



/****************************************

  any following output must be JSON hash

 ****************************************/
printf("Content-Type:application/json\n\n{");


if(cgiVarExists("kkquerygene"))
    {
    if(genetracksl==NULL) return 1;
    char *query, **row;
    struct slNode *node;
    struct tnode *result=NULL, *t;
    int count=0;
    for(node=genetracksl; node!=NULL; node=node->next)
        {
		if(asprintf(&query, "select symbol from %ssymbol where symbol like \"%s%%\"", node->name, cgiString("ui"))<0) errabort("bae");
		MYSQL_RES *sr=mysqlGetResult(query);
		free(query);
		while((row=mysql_fetch_row(sr))!=NULL)
			{
			t=malloc(sizeof(struct tnode));
			t->t1=strdup(row[0]);
			t->t2=node->name;
			t->next=result;
			result=t;
			count++;
			}
		mysql_free_result(sr);
		}
    printf("'count':%d}", count);
	done();
	return 1;
    }


/* in case of having session and statusId, retrieve scaffolds in use,
   and initiate lastChrIdx, chrInfo
   the code will have to be ahead of any other code that uses lastChrIdx and chrInfo
   TODO make sure following "exit when done" branches need it
   if they don't need it, move them upward
 */
if(session!=NULL && statusId!=-1)
    {
    // but some cases this won't happen
    // isfirst, gene set view, restore status about gene set view...
    char *query;
    if(asprintf(&query, "select count from scaffoldRuntime where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
    char *re = mysqlGetOnestring(query);
    free(query);
    if(re != NULL)
		{
		reviveScaffold();
		}
	else
		{
		if(SQUAWK) fputs("not loading up scaffold...\n", stderr);
		}
    }

/*** fetch data to make small wiggle plots accompanying mini ideogram
     exit when done
 ***/
if(cgiVarExists("ideogramwiggle"))
	{
	if(SQUAWK) fputs("ideogramwiggle...\n", stderr);

	printf("'which':%s,", cgiString("which")); // spit back

	char *fname = cgiString("fname");
	int ft = cgiInt("ft");
	char *url = cgiString("url");
	char *urlpath = makefilepath(fname==NULL?url:fname, ft);

	struct displayedRegion dsp; // simulate a dsp
	dsp.head = NULL;
	dsp.tail = NULL;

	char delim[] = ",";
	if(cgiVarExists("scaffold"))
		{
		// retrieving data over entire scaffold sequences
		char *tok = strtok(cgiString("scaffold"), delim);
		while(tok != NULL)
			{
			int chridx = strMayChrID(tok);
			if(chridx == -1)
				{
				scaffoldAddnew(tok);
				chridx = lastChrIdx;
				}
			struct region *r = malloc(sizeof(struct region));
			r->bstart = r->dstart = 0;
			r->bstop = r->dstop = chrInfo[chridx]->length;
			r->isViewStart = FALSE;
			r->chromIdx = chridx;
			assert((tok=strtok(NULL, delim)) != NULL);
			assert((r->summarySize=strMayPositiveInt(tok))!=-1);
			dspAddRegionTail(&dsp, r);

			tok = strtok(NULL, delim);
			}
		}
	else
		{
		// retrieving data over list of coords
		assert(cgiVarExists("coordlst"));
		char *tok = strtok(cgiString("coordlst"), delim);
		while(tok != NULL)
			{
			int chridx = strMayChrID(tok);
			if(chridx == -1)
				{
				scaffoldAddnew(tok);
				chridx = lastChrIdx;
				}
			struct region *r = malloc(sizeof(struct region));
			assert((tok=strtok(NULL,delim)) != NULL);
			assert((r->bstart=r->dstart=strMayPositiveInt(tok))!=-1);
			assert((tok=strtok(NULL,delim)) != NULL);
			assert((r->bstop=r->dstop=strMayPositiveInt(tok))!=-1);
			r->isViewStart = FALSE;
			r->chromIdx = chridx;
			assert((tok=strtok(NULL,delim)) != NULL);
			assert((r->summarySize=strMayPositiveInt(tok))!=-1);
			dspAddRegionTail(&dsp, r);

			tok = strtok(NULL, delim);
			}
		}
	dsp.usedSummaryNumber = 0;
	struct region *r;
	for(r=dsp.head; r!=NULL; r=r->next)
		dsp.usedSummaryNumber += r->summarySize;
	// retrieve data
	printf("'data':");
	switch(ft)
		{
		case FT_bigbed_n:
		case FT_bigbed_c:
		case FT_chiapet_n:
		case FT_chiapet_c:
			printJson_itemDensity(&dsp, urlpath, ft);
			break;
		case FT_cat_c:
		case FT_cat_n:
			printJson_categorical(&dsp, urlpath);
			break;
		case FT_hmtk_n:
		case FT_hmtk_c:
			printJson_bigwig(&dsp, urlpath);
			break;
		default: errabort("ideogramwiggle: unknown filetype");
		}
	printf("}");
	done();
	return 1;
	}


/*** fetch detail for one track
     this never gonna make long url
     exit when done
 ***/
if(cgiVarExists("gettrackdetails"))
    {
    if(!cgiVarExists("tkname"))
        {
	printf("'abort':'no track name given'}");
	return 1;
	}
    char *query;
    char *result;
    char *tkname = cgiString("tkname");

    // general
    printf("'general':\"");
    if(asprintf(&query, "select detail from track2Detail where name=\"%s\"", tkname)<0) errabort("bae");
    result = mysqlGetOnestring(query);
    free(query);
    if(result == NULL)
	printf("NULL");
    else
        printf("%s",result);
    printf("\",");

    // processing
    printf("'processing':\"");
    if(asprintf(&query, "select detail from track2ProcessInfo where name='%s'", tkname)<0) errabort("bae");
    result = mysqlGetOnestring(query);
    free(query);
    if(result == NULL)
        printf("NULL");
    else
        printf("%s",result);
    printf("\",");

    // geo
    char *geo;
    printf("'geo':\"");
    if(asprintf(&query, "select geo from track2GEO where name='%s'", tkname)<0) errabort("bae");
    geo = mysqlGetOnestring(query);
    free(query);
    if(geo == NULL)
        printf("NULL");
    else
        printf("%s", geo);
    printf("\",");

    // other versions
    printf("'other':[");
    if(geo != NULL)
        {
        if(asprintf(&query, "select b.name,b.info,c.label from track2GEO as a,track2VersionInfo as b,track2Label as c where a.geo='%s' and a.name=b.name and a.name=c.name", geo)<0) errabort("bae");
		MYSQL_RES *sr = mysqlGetResult(query);
		free(query);
		if(sr!=NULL)
			{
			char **row;
			while((row=mysql_fetch_row(sr)) != NULL)
				printf("[\"%s\",\"%s\", \"%s\"],", row[0], row[1], row[2]);
			mysql_free_result(sr);
			}
		}
    printf("],");

    // bam
    printf("'bam':[");
    if(asprintf(&query, "select bamfile,bamfilelabel from track2BamInfo where name='%s'", tkname)<0) errabort("bae");
    MYSQL_RES *sr = mysqlGetResult(query);
    free(query);
    if(sr!=NULL)
        {
		char **row;
		while((row=mysql_fetch_row(sr)) != NULL)
			printf("[\"%s\",\"%s\"],", row[0], row[1]);
		mysql_free_result(sr);
		}
    printf("],");

    printf("}");
	done();
    return 1;
    }


/*** revive URL after it has been completely saved in pieces
 ***/
if(cgiVarExists("reviveURL"))
	{
	// read everything from mysql, write into temp file, revive cgi param enviroment from file, clean up...
	char *query, **row;

	// count how many pieces are in db, to allocate memory for array...
	if(asprintf(&query, "select count(session) from tempURL where session=\"%s\"", session)<0) errabort("bae");
	int number = mysqlGetPositiveInteger(query);
	if(number == -1)
		{
		printf("\"abort\":\"cannot run query (supposedly cached URL missing)\"}");
		return 1;
		}

	struct urlpiece urp[number];
	int i=0;

	// having array, store url and offset into it
	if(asprintf(&query, "select offset,urlpiece from tempURL where session=\"%s\"", session)<0) errabort("bae");
	MYSQL_RES *sr = mysqlGetResult(query);
	while((row=mysql_fetch_row(sr)) != NULL)
		{
		assert((urp[i].offset=strMayPositiveInt(row[0]))!=-1);
		urp[i].text=strdup(row[1]);
		i++;
		}
	free(query);
	mysql_free_result(sr);

	// arrange pieces in correct order
	qsort(&urp, (size_t)number, sizeof(struct urlpiece), urlpiece_cmp);

	char *urlstring = NULL; // concatenate all of them into one string
	for(i=0; i<number; i++)
		{
		if(urlstring == NULL)
			{
			urlstring=strdup(urp[i].text);
			}
		else
			{
			char *tmp;
			if(asprintf(&tmp, "%s%s", urlstring, urp[i].text)<0) errabort("bae");
			free(urlstring);
			urlstring = tmp;
			}
		}
	if(0) fprintf(stderr,"assembled urlstring:\n%s\n\n", urlstring);

	//if(cgiVarExists("decodeURL"))
		{
		/* always decode URL */
		int len=strlen(urlstring);
		char *out = malloc(sizeof(char) * len);
		strDecode(urlstring, out, len);
		free(urlstring);
		urlstring = out;
		if(0) fprintf(stderr, "decoded urlstring:\n%s\n\n", urlstring);
		}


	/* dissect original url, use cgiVarSet on each param...
	must not free tsl->name
	as its values will be used in cgi enviroment
	*/
	struct slNode *tsl = NULL, *t;
	char delim[] = "&";
	// first param
	char *tok = strtok(urlstring, delim); assert(tok!=NULL);
	while(tok != NULL)
		{
		t = malloc(sizeof(struct slNode));
		t->name = tok;
		t->next = tsl;
		tsl = t;
		tok = strtok(NULL, delim);
		}
	char delim2[] = "=";
	char *tok1, *tok2;
	for(t=tsl; t!=NULL; t=t->next)
		{
		tok1 = strtok(t->name, delim2);
		tok2 = strtok(NULL, delim2);
		cgiVarSet(tok1, tok2);
		}

	if(0)
		{
		/* dump cgi into string again to verify
		struct dyString *tt = cgiUrlString();
		fprintf(stderr, "%s\n", tt->string);
		*/
		}

	// pieces in db must be cleaned up, or they will mess up new queries under same session
	if(asprintf(&query, "delete from tempURL where session=\"%s\"", session)<0) errabort("bae");
	mysqlUpdate(query);
	free(query);

	if(SQUAWK) fputs("url revived...\n", Squawk);
	}

if(0)
    {
    /* dump cgi into string again to verify
    struct dyString *tt = cgiUrlString();
    fprintf(stderr, "%s\n", tt->string);
	*/
    }





/*** fetch desc for one gene for showing decor item info
     providing gene track name and item id for querying
     gene description must not contain double quote
     TODO geneontology
     exit when done
 ***/
if(cgiVarExists("getgenedesc"))
    {
    char *query;
    if(asprintf(&query, "select description from %ssymbol where id=%s", cgiString("genetype"), cgiString("itemid"))<0) errabort("bae");
    char *desc = mysqlGetOnestring(query);
    free(query);
    printf("'desc':\"%s\"}", desc==NULL?"No description":desc);
	done();
    return 1;
    }


/****************************
  SESS save one status under session
      exit when done
 ****************************/
if(cgiVarExists("saveStatus"))
    {
    /* when saving status, the status ID will be re-generated
       so need to update genesetRuntime table when doing gene set view
     */
	if(SQUAWK)
		fprintf(stderr, "saving status for %s %d...\n", session, statusId);

    // fields to be inserted
    // TODO decor4 is not saved
    char *clientCtrl,
         *note,
         *serverTrack,
	 *customTrack,
	 *customTrackAttr,
	 *juxWhat,
	 *juxNote,
	 *dspStat,
	 *corrStat,
	 *custmd,
	 *mdconshow,
	 *dataset,
	 *pairwisecomp,
	 //*decor4,
	 *decor0,*decor1,*decor8,*decor5,*decor9,*decor10,
	 *decorRenderingParams,
	 *qtc,
	 *gssparam,
	 *stickynote,
         *itemlist = NULL, // in case of running genesetview
         *scaffoldNames = NULL; // in case of using scaffold
    int scaffoldCount = 0;
    char *query;

    // make new status id
    int newstatusid;
    srand(time(0));
    do {
        newstatusid = rand();
       }
    while(sessionStatusExists(session, newstatusid));

    // always need to save scaffold, and update status id
    if(asprintf(&query, "select count,names from scaffoldRuntime where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
    MYSQL_RES *sr = mysqlGetResult(query);
	assert(sr!=NULL);
    free(query);
    char **row = mysql_fetch_row(sr);
    assert(row[0] != NULL);
    assert(row[1] != NULL);
    assert((scaffoldCount=strMayPositiveInt(row[0]))!=-1);
    if(asprintf(&scaffoldNames, "'%s'", row[1])<0) errabort("bae");
    mysql_free_result(sr);

    // need to update status in scaffoldRuntime table
    if(asprintf(&query, "update scaffoldRuntime set statusId=%d where session='%s' and statusId=%d", newstatusid, session, statusId)<0) errabort("bae");
    mysqlUpdate(query);
    free(query);

    int juxType = cgiInt("juxType");
    if(juxType==3 || juxType==4)
        {
		// gene set view string
        if(asprintf(&query, "select itemlist from genesetRuntime where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
		char *tmp = mysqlGetOnestring(query);
		assert(tmp != NULL);
        if(asprintf(&itemlist, "'%s'", tmp)<0) errabort("bae");
        free(query);
		// update status ID in collateitemlist
		if(asprintf(&query, "update genesetRuntime set statusId=%d where session='%s' and statusId=%d", newstatusid, session, statusId)<0) errabort("bae");
		mysqlUpdate(query);
		free(query);
		}

    // have note?
    if(cgiVarExists("statusNote"))
        note = cgiString("statusNote");
    else
        {
        char *cast[] = {"Shaun the sheep", "Wallace the British folk", "Gromit the clay-dog", "Bunny the were-rabbit", "Tachikoma the taranchula", "Bato the veteran", "Popeye the sailor", "Ginger the chicken", "Rocky the rooster", "Tweedy the rancher", "Emily the bride", "Remy the chef", "Roddy the pet", "Rita the stealth", "Shrek the ogre", "Lyra's Golden Compass", "Will's Subtle Knife", "A computerless wire"};
		note = cast[(int)(18*((float)rand()/RAND_MAX))];
		}


    // prepare the rest of insert strings
    if(cgiVarExists("clientCtrl"))
        {
		if(asprintf(&clientCtrl, "'%s'", cgiString("clientCtrl"))<0) errabort("bae");
		}
    else
        clientCtrl = "\\N";
    if(cgiVarExists("serverTrack"))
        {
		if(asprintf(&serverTrack, "'%s'", cgiString("serverTrack"))<0) errabort("bae");
		}
    else
        serverTrack = "\\N";
    if(cgiVarExists("customTrack"))
        {
		if(asprintf(&customTrack, "'%s'", cgiString("customTrack"))<0) errabort("bae");
		}
    else
        customTrack = "\\N";
    if(cgiVarExists("customTrackAttr"))
        {
		if(asprintf(&customTrackAttr, "'%s'", cgiString("customTrackAttr"))<0) errabort("bae");
		}
    else
        customTrackAttr = "\\N";
    if(cgiVarExists("juxWhat"))
        {
		if(asprintf(&juxWhat, "'%s'", cgiString("juxWhat"))<0) errabort("bae");
		}
    else
        juxWhat = "\\N";
    if(cgiVarExists("juxNote"))
        {
		if(asprintf(&juxNote, "'%s'", cgiString("juxNote"))<0) errabort("bae");
		}
    else
        juxNote= "\\N";
    if(cgiVarExists("dspStat"))
        {
		if(asprintf(&dspStat, "'%s'", cgiString("dspStat"))<0) errabort("bae");
		}
    else
        dspStat = "\\N";
    if(cgiVarExists("corrStat"))
        {
		if(asprintf(&corrStat, "'%s'", cgiString("corrStat"))<0) errabort("bae");
		}
    else
        corrStat = "\\N";
    if(cgiVarExists("custmd"))
        {
		if(asprintf(&custmd, "'%s'", cgiString("custmd"))<0) errabort("bae");
		}
    else
        custmd = "\\N";
    if(cgiVarExists("mdconshow"))
        {
		if(asprintf(&mdconshow, "'%s'", cgiString("mdconshow"))<0) errabort("bae");
		}
    else
        mdconshow = "\\N";
    if(cgiVarExists("dataset"))
        {
		if(asprintf(&dataset, "'%s'", cgiString("dataset"))<0) errabort("bae");
		}
    else
        dataset = "\\N";
    if(cgiVarExists("pairwisecomp"))
        {
		if(asprintf(&pairwisecomp, "'%s'", cgiString("pairwisecomp"))<0) errabort("bae");
		}
    else
        pairwisecomp = "\\N";

    // decors 0/1/8/4/5/9/10
    if(cgiVarExists("decor0"))
        {
		if(asprintf(&decor0, "'%s'", cgiString("decor0"))<0) errabort("bae");
		}
    else
        decor0 = "\\N";
    if(cgiVarExists("decor1"))
        {
		if(asprintf(&decor1, "'%s'", cgiString("decor1"))<0) errabort("bae");
		}
    else
        decor1 = "\\N";
    if(cgiVarExists("decor8"))
        {
		if(asprintf(&decor8, "'%s'", cgiString("decor8"))<0) errabort("bae");
		}
    else
        decor8 = "\\N";
    /*
    if(cgiVarExists("decor4"))
        {
	if(asprintf(&decor4, "\"%s\"", cgiString("decor4"))<0) errabort("bae");
	}
    else
        decor4 = "\\N";
	*/
    if(cgiVarExists("decor5"))
        {
		if(asprintf(&decor5, "'%s'", cgiString("decor5"))<0) errabort("bae");
		}
    else
        decor5 = "\\N";
    if(cgiVarExists("decor9"))
        {
		if(asprintf(&decor9, "'%s'", cgiString("decor9"))<0) errabort("bae");
		}
    else
        decor9 = "\\N";
    if(cgiVarExists("decor10"))
        {
		if(asprintf(&decor10, "'%s'", cgiString("decor10"))<0) errabort("bae");
		}
    else
        decor10 = "\\N";


    if(cgiVarExists("decorRenderingParams"))
        {
		if(asprintf(&decorRenderingParams, "'%s'", cgiString("decorRenderingParams"))<0) errabort("bae");
		}
    else
        decorRenderingParams = "\\N";
    if(cgiVarExists("qtc"))
        {
		if(asprintf(&qtc, "'%s'", cgiString("qtc"))<0) errabort("bae");
		}
    else
        qtc = "\\N";
    if(cgiVarExists("gssparam"))
        {
		if(asprintf(&gssparam, "'%s'", cgiString("gssparam"))<0) errabort("bae");
		}
    else
        gssparam = "\\N";
    if(cgiVarExists("stickynote"))
        {
		if(asprintf(&stickynote, "'%s'", cgiString("stickynote"))<0) errabort("bae");
		}
    else
        stickynote = "\\N";

    // save new status under this session, return status ID
	// status note must be double quoted, as some words contain single quote
    if(asprintf(&query, "insert into session values('%s',%d,\"%s\",%s,%s,%s,%s,"
    	"%d,%s,%s,%s,%s,"
		"%s,%s,%s,%s,%s,"
		"%s,%s,%s,\\N,%s,%s,%s,"
		"%s,%s,%s,%s,"
		"%d,%s)",
    	session, newstatusid, note, clientCtrl, serverTrack, customTrack, customTrackAttr, 
		juxType, juxWhat, juxNote, dspStat, corrStat,
		itemlist==NULL?"\\N":itemlist, custmd, mdconshow, dataset, pairwisecomp,
		decor0, decor1, decor8, decor5, decor9, decor10,
		decorRenderingParams, qtc, gssparam, stickynote, 
		scaffoldCount, scaffoldNames==NULL?"\\N":scaffoldNames)<0) 
        errabort("bae");
    mysqlUpdate(query);
    free(query);
    printf("'statusTicket':[%d,\"%s\"]}", newstatusid, note);
	done();
    return 1;
    }

if(cgiVarExists("pastSession"))
    {
    /* SESS retrieve saved status for a past session, 
       display on client side for user to choose which one to restore
     */
    char *session2use = cgiString("pastSession"); // session on which info will be retrieved
    // current session is still in global variable
    char *query, **row;
    // see if session exists
    if(asprintf(&query, "select statusId from session where session=\"%s\"", session2use)<0)
        errabort("bae");
	if(!mysqlResultAffirmative(query))
		{
		free(query);
		printf("'abort':'No status found for this session'}");
		return 0;
		}
	free(query);

    printf("\"statusLst\":[\"%s\",", session2use);
    // retrieve all saved status under this session and return
    if(asprintf(&query, "select decor5,decor1,statusId,statusNote,serverTrack,customTrack,dspStat,juxNote,decor10 from session where session=\"%s\"", session2use)<0) errabort("bae");
    MYSQL_RES *sr = mysqlGetResult(query);
	assert(sr!=NULL);
    char delim[]=",", *tok;
    int sid_decor5=0,sid_decor1=1,sid_decor10=8,sid_statusid=2,sid_statusnote=3,sid_servertrack=4,sid_customtrack=5,sid_dspstat=6,sid_jux=7;
    while((row=mysql_fetch_row(sr)) != NULL)
        {
		printf("[%s, \"%s\",", row[sid_statusid], row[sid_statusnote]);
		// dspStat string
		if((tok=strtok(row[sid_dspstat], delim)) == NULL) errabort("expecting start chr from dspStat string but got null...");
		char *startChr = tok;
		if((tok=strtok(NULL, delim)) == NULL) errabort("expecting start coord from dspStat string but got null...");
		char *startCoord = tok;
		if((tok=strtok(NULL, delim)) == NULL) errabort("expecting stop chr from dspStat string but got null...");
		char *stopChr = tok;
		if((tok=strtok(NULL, delim)) == NULL) errabort("expecting stop coord from dspStat string but got null...");
		char *stopCoord = tok;
		if(strcmp(startChr,stopChr) == 0)
			printf("\"%s from %s to %s\",", startChr, startCoord, stopCoord);
		else
			printf("\"from %s(%s) to %s(%s)\",", startChr, startCoord, stopChr, stopCoord);
		// report number of tracks, count any type of custom track together
		int nativehmtk=0, custtrack=0;
		if(row[sid_servertrack] != NULL)
			{
			// server hmtk
			tok = strtok(row[sid_servertrack], delim); // name
			while(tok != NULL)
				{
			nativehmtk++;
			tok = strtok(NULL, delim); // next name
			}
			}
		if(row[sid_customtrack] != NULL)
			{
			// custom hmtk
			tok = strtok(row[sid_customtrack], delim); // name
			while(tok != NULL)
				{
			custtrack++;
				strtok(NULL,delim);  // label
				strtok(NULL,delim);  // url
			tok = strtok(NULL, delim); // next name
			}
			}
		struct tnode *sl=NULL, *tt;
		if(row[sid_decor1] != NULL)
			{
			sl = parseParamDecor1(row[sid_decor1]);
			for(tt=sl; tt!=NULL; tt=tt->next)
				custtrack++;
			}
		if(row[sid_decor5] != NULL)
			{
			sl = parseParamDecor5(row[sid_decor5]);
			for(tt=sl; tt!=NULL; tt=tt->next)
				custtrack++;
				}
		if(row[sid_decor10] != NULL)
			{
			sl = parseParamDecor10(row[sid_decor10]);
			for(tt=sl; tt!=NULL; tt=tt->next)
				custtrack++;
				}
		printf("[%d,%d],\"%s\"],", nativehmtk, custtrack, row[sid_jux]);
		}
    mysql_free_result(sr);
    free(query);
    printf("]}");

    if(SQUAWK) fputs("done fetching saved statuses\n", stderr);

    if(cgiVarExists("updateRuntimetable"))
        {
	/* update run time tables as session ID has changed!! */
	if(asprintf(&query, "update scaffoldRuntime set session='%s' where session='%s' and statusId=%d", session2use, session, statusId)<0) errabort("bae");
	mysqlUpdate(query);
	free(query);
	int juxtype = cgiInt("juxType");
	if(juxtype==3 || juxtype==4)
	    {
	    // running gene set view, update that runtime table
	    if(asprintf(&query, "update genesetRuntime set session='%s' where session='%s' and statusId=%d", session2use, session, statusId)<0) errabort("bae");
	    mysqlUpdate(query);
	    free(query);
	    }
	}
	done();
    return 1;
    }

if(cgiVarExists("deleteStatus"))
    {
    char *statusId = cgiString("deleteStatus");
    char *session = cgiString("session");
    char *query;
    if(asprintf(&query, "delete from session where session=\"%s\" and statusId=%s", session, statusId)<0) errabort("bae");
    mysqlUpdate(query);
    free(query);
    printf("}");
	done();
    return 1;
    }



/*** longrange wreath track
     exit when done
 ***/
if(cgiVarExists("longrangewreath"))
	{
	if(SQUAWK) fputs("longrange wreath track\n", stderr);
	// regionlst
	struct displayedRegion dsp;
	dsp.gf = GENOME;
	dsp.head = NULL;
	dsp.tail = NULL;
	dsp.atbplevel = FALSE;
	dsp.usedSummaryNumber = 0;
	struct region *r;
	char delim[]=",";
	char *tok=strtok(cgiString("regionlst"), delim);
	while(tok!=NULL)
		{
		r=malloc(sizeof(struct region));
		r->chromIdx=strMayChrID(tok);
		if(r->chromIdx == -1)
			{
			scaffoldAddnew(tok);
			r->chromIdx = lastChrIdx;
			}
		assert((tok=strtok(NULL,delim))!=NULL);
		assert((r->dstart=strMayPositiveInt(tok))!=-1);
		assert((tok=strtok(NULL,delim))!=NULL);
		assert((r->dstop=strMayPositiveInt(tok))!=-1);
		assert((tok=strtok(NULL,delim))!=NULL);
		assert((r->summarySize=strMayPositiveInt(tok))!=-1);
		dsp.usedSummaryNumber+=r->summarySize;
		dspAddRegionTail(&dsp, r);
		tok=strtok(NULL, delim);
		}
	// dsp is ready
	if(0)
		{
		for(r=dsp.head; r!=NULL; r=r->next)
			fprintf(stderr, "%s %d %d %d\n", chrInfo[r->chromIdx]->name, r->dstart, r->dstop, r->summarySize);
		}
	/* for each track, print its data
	must not interlace strtok with tabix query */
	tok=strtok(cgiString("tklst"),delim);
	struct tnode *sl=NULL, *t;
	while(tok!=NULL)
		{
		t=malloc(sizeof(struct tnode));
		assert((t->t4=strMayPositiveInt(tok))!=-1);
		assert((tok=strtok(NULL, delim))!=NULL);
		t->t1=makefilepath(tok, t->t4);
		t->next=sl;
		sl=t;
		tok=strtok(NULL,delim);
		}
	slReverse(&sl);
	printf("'data':[");
	for(t=sl; t!=NULL; t=t->next)
		{
		switch(t->t4)
			{
			case FT_bigbed_n:
			case FT_bigbed_c:
			case FT_chiapet_n:
			case FT_chiapet_c:
				printJson_itemDensity(&dsp, t->t1, t->t4);
				break;
			case FT_hmtk_n:
			case FT_hmtk_c:
			case FT_qdecor_n:
				printJson_bigwig(&dsp, t->t1);
				break;
			case FT_cat_c:
			case FT_cat_n:
				printJson_categorical(&dsp, t->t1);
				break;
			default: errabort("wreath track: unknown filetype");
			}
		free(t->t1);
		}
	slFree(sl);
	printf("]}");
	done();
	return 1;
	}

/*** BEV bird's eye view
     exit when done
 ***/
if(cgiVarExists("birdseyeview"))
	{
	if(SQUAWK) fputs("running bev...\n", Squawk);
	int runtype = cgiInt("runtype");

	struct track *tracksl=NULL, *tk;
	char *tok;
	char delim[] = ",";
	if(cgiVarExists("nativetklst"))
		{
		tok=strtok(cgiString("nativetklst"),delim);
		assert(tok!=NULL);
		while(tok!=NULL)
			{
			tk=malloc(sizeof(struct track));
			tk->name=tok;
			assert((tok=strtok(NULL,delim))!=NULL);
			assert((tk->ft=strMayPositiveInt(tok))!=-1);
			tk->urlpath=makefilepath(tk->name, tk->ft);
			tk->next = tracksl;
			tracksl = tk;
			tok = strtok(NULL, delim);
			}
		}
	if(cgiVarExists("customtklst"))
		{
		tok=strtok(cgiString("customtklst"),delim);
		assert(tok!=NULL);
		while(tok!=NULL)
			{
			tk=malloc(sizeof(struct track));
			tk->name=tok;
			assert((tk->urlpath=strtok(NULL,delim))!=NULL);
			assert((tok=strtok(NULL,delim))!=NULL);
			assert((tk->ft=strMayPositiveInt(tok))!=-1);
			tk->next = tracksl;
			tracksl = tk;
			tok = strtok(NULL, delim);
			}
		}

	if(tracksl == NULL)
		{
		printf("\"abort\":\"no valid track\"}");
		return 1;
		}

	if(0)
		{
		fputs("all tracks:\n", stderr);
		for(tk=tracksl; tk!=NULL; tk=tk->next)
			fprintf(stderr, "\t%s\n", tk->name);
		}

	/* make a tnode sl for searching
	t1: scaffold name
	num: plot width (number of summary points)
	*/
	lastChrIdx = -1;
	int sptotal=0;
	struct tnode *sl=NULL, *tt;
	char *tmp = cgiString("plotwidth");
	tok = strtok(strdup(tmp), delim);
	while(tok != NULL)
		{
		lastChrIdx++;
		char *seqname = tok;
		// get seq summary size
		tok = strtok(NULL, delim);
		assert(tok!=NULL);
		int sp = strMayPositiveInt(tok);
		assert(sp!=-1);
		tt=malloc(sizeof(struct tnode));
		tt->t1=seqname;
		tt->num=sp;
		tt->next=sl;
		sl=tt;
		sptotal += sp;
		strtok(NULL, delim);
		tok = strtok(NULL, delim);
		}
	// fill up chrInfo
	chrInfo = malloc(sizeof(struct chrInfoNode *)*(lastChrIdx+1));
	tok = strtok(strdup(tmp), delim);
	int i=0;
	while(tok != NULL)
		{
		chrInfo[i] = malloc(sizeof(struct chrInfoNode));
		chrInfo[i]->name = tok;
		strtok(NULL, delim);
		tok = strtok(NULL, delim);
		assert(tok != NULL);
		assert((chrInfo[i++]->length=strMayPositiveInt(tok))!=-1);
		tok = strtok(NULL, delim);
		}
	assert(i==lastChrIdx+1);

	for(tk=tracksl; tk!=NULL; tk=tk->next)
		{
		tk->data = NULL;
		if(runtype == 3)
			{
			tk->data = malloc(sizeof(double) * sptotal);
			if(tk->data == NULL)
				{
				printf("\"abort\":\"Out of memory! Reduce chr plot width and try again\"}");
				return 1;
				}
			}

		int j;
		if(tk->ft==FT_hmtk_c || tk->ft==FT_hmtk_n || tk->ft==FT_qdecor_n)
			{
			printf("'%s':{", tk->name);
			tabix_t *fin=tabixOpen(tk->urlpath);
			int k=0;
			for(i=0; i<=lastChrIdx; i++)
				{
				int sSize = tnodesl_search4num(sl, chrInfo[i]->name);
				assert(sSize!=-1);
				double values[sSize];
				for(j=0; j<sSize; j++)
					values[j] = .0;
				tabixQuery_bedgraph(fin, chrInfo[i]->name, 0, chrInfo[i]->length, sSize, &values[0]);
				printf("\"%s\":[", chrInfo[i]->name);
				for(j=0; j<sSize; j++)
					printf("%.2f,", values[j]);
				printf("],");
				if(runtype == 3)
					{
					for(j=0; j<sSize; j++)
						(tk->data)[k++] = values[j];
					}
				}
			ti_close(fin);
			printf("},");
			}
		else if(tk->ft==FT_bigbed_c || tk->ft==FT_bigbed_n || tk->ft==FT_chiapet_n || tk->ft==FT_chiapet_c)
			{
			printf("'%s':{", tk->name);
			tabix_t *fin=tabixOpen(tk->urlpath);
			int k=0;
			for(i=0; i<=lastChrIdx; i++)
				{
				int sSize = tnodesl_search4num(sl, chrInfo[i]->name);
				assert(sSize!=-1);
				int sLen = chrInfo[i]->length;
				double values[sSize];
				for(j=0; j<sSize; j++)
					values[j] = .0;
				struct region r;
				r.dstart = 0;
				r.dstop = sLen;
				r.chromIdx = i;
				r.summarySize = sSize;
				tabixQuery_regiondensity(fin, tk->ft, &r, &values[0]);
				printf("\"%s\":[", chrInfo[i]->name);
				for(j=0; j<sSize; j++)
					printf("%.2f,", values[j]);
				printf("],");
				if(runtype == 3)
					{
					for(j=0; j<sSize; j++)
						(tk->data)[k++] = values[j];
					}
				}
			ti_close(fin);
			printf("},");
			}
		else if(tk->ft==FT_cat_c || tk->ft==FT_cat_n)
			{
			printf("'%s':{", tk->name);
			tabix_t *fin=tabixOpen(tk->urlpath);
			int k=0;
			for(i=0; i<=lastChrIdx; i++)
				{
				int sSize = tnodesl_search4num(sl, chrInfo[i]->name);
				assert(sSize!=-1);
				int values[sSize];
				for(j=0; j<sSize; j++)
					values[j] = -1;
				tabixQuery_categorical(fin, chrInfo[i]->name, 0, chrInfo[i]->length, sSize, &values[0]);
				printf("'%s':[", chrInfo[i]->name);
				for(j=0; j<sSize; j++)
					printf("%d,", values[j]);
				printf("],");
				if(runtype == 3)
					{
					for(j=0; j<sSize; j++)
						(tk->data)[k++] = values[j];
					}
				}
			ti_close(fin);
			printf("},");
			}
		//if(fout != NULL) fclose(fout);
		}

	if(runtype == 3)
		{
		// data are ready now, run htest, compute and return pvalues
		parseParamHtest(tracksl);

		// horrible duplication of code below...
		if(SQUAWK) fputs("Running bev htest...\n", Squawk);
		char *rsourcefile;
		if(asprintf(&rsourcefile, "%s/%s.R", trashDir, session)<0) errabort("bae");
		FILE *fout = fopen(rsourcefile, "w");
		if(fout == NULL) errabort(rsourcefile);
		char *routfile;
		if(asprintf(&routfile, "%s/%s.Rout", trashDir, session)<0) errabort("bae");
		char *pvfile;
		if(asprintf(&pvfile, "%s/%s.pvalues", trashDir, session)<0) errabort("bae");
		fputs("options(echo=FALSE)\n", fout);
		fputs("grp=c(", fout);
		for(tk=tracksl; tk!=NULL; tk=tk->next)
			{
			if(tk->gid != 0)
			fprintf(fout, "%d,", tk->gid);
			}
		fseek(fout, -1, SEEK_CUR);
		fputs(")\npv=numeric()\n", fout);
		// write track data, one vector for each summary point over participating tracks
		int j;
		int k=0; // cumulative over all regions, index of tk->data
		for(i=0; i<=lastChrIdx; i++)
			{
			int sSize=tnodesl_search4num(sl, chrInfo[i]->name);
			assert(sSize!=-1);
			for(j=0; j<sSize; j++)
				{
				fputs("data = c(", fout);
				for(tk=tracksl; tk!=NULL; tk=tk->next)
					{
					if(tk->gid != 0)
					fprintf(fout, "%f,", (float)(tk->data)[k]);
					}
				fseek(fout, -1, SEEK_CUR);
				fprintf(fout, ")\npv[%d]=kruskal.test(data, grp)$p.value\n", k+1);
				k++;
				}
			}
		if(cgiVarExists("htestc"))
			fprintf(fout, "pv=p.adjust(pv, method=\"%s\")\n", cgiString("htestc"));
		fprintf(fout, "write(pv, \"%s\", sep=\"\\n\")\n", pvfile);
		fclose(fout);
		// run test
		char *command;
		if(asprintf(&command, "R CMD BATCH --no-save %s %s", rsourcefile, routfile)<0) errabort("BAE");
		if(system(command) == -1)
			errabort("cannot spawn process");
		free(command);
		// parse pvalue file, return pvalues
		printf("\"%s\":{", cgiString("htestvn"));
		FILE *fin = fopen(pvfile,"r");
		char *line = malloc(1);
		size_t s = 1;
		for(i=0; i<=lastChrIdx; i++)
			{
			printf("\"%s\":[", chrInfo[i]->name);
			int sSize=tnodesl_search4num(sl, chrInfo[i]->name);
			for(j=0; j<sSize; j++)
				{
				if(getline(&line, &s, fin) == -1)
					errabort("expecting more pvalues but reaches EOF...");
				if(line[0] == 'N') // NaN
					printf("1,");
				else if(line[0] == '1')
					printf("1,");
				else
					printf("%.4f,", strtod(line, NULL));
				}
			printf("],");
			}
		fclose(fin);
		printf("}");
		}

	slFree(sl);

	printf("}");
	done();
	return 1;
	}





/*** load track annotation in datasets 
     exit when done
 ***/
if(cgiVarExists("loaddataset"))
    {
    char *string = cgiString("loaddataset");
    char delim[] = ",";
	char *tok=strtok(string, delim);
	assert(tok!=NULL);
	struct slNode *sl=NULL;
	while(tok!=NULL)
		{
		struct slNode *t=malloc(sizeof(struct slNode));
		t->name=strdup(tok);
		t->next=sl;
		sl=t;
		tok=strtok(NULL,delim);
		}
	printJson_hmtk4datasets(sl);
	printf("}");
	done();
    return 1;
    }


/*** fetch chromosomal sequence 
     return to JS for overlaying on chr ideogram beneath genome heatmap
     exit when done
 ***/
if(cgiVarExists("getChromseq"))
    {
	if(SQUAWK) fputs("getChromseq...\n", stderr);
    // return one seq fragment for each region
    char *string = cgiString("regionlst");
    char delim[] = ",";
    char *tok = strtok(string, delim);

    printf("'lst':[");

    while(tok != NULL)
        {
		char *chr = tok;
		tok = strtok(NULL, delim); assert(tok!=NULL);
		int start = strMayPositiveInt(tok);
		assert(start!=-1);
		tok = strtok(NULL, delim); assert(tok!=NULL);
		int stop = strMayPositiveInt(tok);
		assert(stop!=-1);
		char *s=getSeq(chr, start+1, stop);
		assert(s!=NULL);
		printf("'%s',", s);
		free(s);
		tok = strtok(NULL, delim);
		}
    printf("]}");
	done();
    return 1;
    }








/*** fetch definition for genes
     genelist obtained from two possible ways: from db via status+session, or directly provided from URL

     extra work:
        as JS will compose url link for genes, need to tell gene type

     no gene source will be specified
     will have to iterate genetracksl but original name will be preserved
     exit when done
 ***/
if(cgiVarExists("getitemlistgenedef"))
    {
    char *genenamelst;
    if(cgiVarExists("statusId"))
        {
        int statusId = cgiInt("statusId");
        genenamelst = getItemlistfromdb(session, statusId);
		}
    else
		{
        genenamelst = cgiString("lst");
		}
    char delim[] = ",";
    char *query, *def;
    struct slNode *table;

    printf("\"lst\":[");
    /* each item is an array: [query name, desc, gene type]
       if item is valid gene, desc should be found, gene type and symbol will be returned
       else, it is supposed to be coordinate string, coord string will be returned in place of name
       no gene type will be returned
     */

    char *itemname = strtok(genenamelst, delim);

    while(itemname != NULL)
        {
		// drop remaining 7 numbers chr, start, stop
		strtok(NULL, delim);strtok(NULL, delim);strtok(NULL, delim);
		strtok(NULL, delim);strtok(NULL, delim);strtok(NULL, delim);strtok(NULL,delim);
		def=NULL;
		for(table=genetracksl; table!=NULL; table=table->next)
			{
			if(asprintf(&query, "select description from %ssymbol where name=\"%s\" or symbol=\"%s\"", table->name, itemname, itemname)<0) errabort("bae");
			def = mysqlGetOnestring(query);
			free(query);
			if(def != NULL)
				break;
			}
		if(def == NULL)
			{
			// no desc, should be coordinate string
			printf("[\"%s\",,],", itemname);
			}
		else
			{
			// has desc, is gene name
			printf("[\"%s\",\"%s\",\"%s\"],", itemname, def, table->name);
			}
		itemname = strtok(NULL, delim);
		}
    printf("]}");
	done();
    return 1;
    }



/* GP fetch data for gene plot
   exit when done
 */
if(cgiVarExists("makegeneplot"))
    {
    /***************************
       Step 1
       parse items from a number of possible sources
       any valid input will be taken
     ***************************/
    struct nnode *itemsl = NULL, *item=NULL;
    if(cgiVarExists("lst"))
		{
		// positional data: itemname, chr, start, stop, joined by comma
		char delim[] = ",";
		char *tok = strtok(cgiString("lst"), delim);
		while(tok != NULL)
			{
			item = malloc(sizeof(struct nnode));
			item->name = tok;
			assert((tok=strtok(NULL, delim))!=NULL);
			assert((item->chrIdx=strMayChrID(tok))!=-1);
			assert((tok=strtok(NULL, delim))!=NULL);
			assert((item->start=strMayPositiveInt(tok))!=-1);
			assert((tok=strtok(NULL, delim))!=NULL);
			assert((item->stop=strMayPositiveInt(tok))!=-1);
			item->strand = strMayGetgeneStrand(genetracksl, item->name);
			if(item->strand == '.')
				item->strand = '+';
			item->next = itemsl;
			itemsl = item;
			tok = strtok(NULL, delim);
			}
		}
    else if(cgiVarExists("tainput"))
        {
		// input from textarea, standalone mode
		char *genestruct = cgiString("gss_opt");
		char *origintype = cgiString("gss_origin");
		int leftlength = cgiInt("gss_up");
		int rightlength = cgiInt("gss_down");
		// dissect long string into list of items using comma
		struct slNode *tmpsl=NULL, *tmptt=NULL;
		char delim[] = ",";
		char *tok = strtok(cgiString("tainput"), delim);
		while(tok != NULL)
			{
			tmptt = malloc(sizeof(struct slNode));
			tmptt->name = tok;
			tmptt->next = tmpsl;
			tmpsl = tmptt;
			tok = strtok(NULL, delim);
			}
		if(tmpsl == NULL)
			{
			printf("'abort':'no recognizable items'}");
			fputs("makegeneplot: got nothing from dissecting tainput", stderr);
			exit(0);
			}

		if(0)
			{
			for(tmptt=tmpsl; tmptt!=NULL; tmptt=tmptt->next)
				fprintf(stderr, "raw item: %s\n", tmptt->name);
			}
		// make regions from each input item, slightly duplicating code as genesetview
		for(tmptt=tmpsl; tmptt!=NULL; tmptt=tmptt->next)
			{
			struct nnode *sl = itemQueryRefGene(genetracksl, tmptt->name, NULL, genestruct, origintype, leftlength, rightlength);
			if(sl != NULL)
				{
				struct nnode *t;
				for(t=sl; t!=NULL; t=t->next)
					{
					item = malloc(sizeof(struct nnode));
					item->chrIdx = t->chrIdx;
					item->name = tmptt->name;
					item->start = t->start;
					item->stop = t->stop;
					item->strand = t->strand;
					item->next = itemsl;
					itemsl = item;
					}
				slFree(sl);
				}
			else
				{
				// not a gene
				int *arr = dissectCoordString(tmptt->name);
				if(arr==NULL || arr[0]==-1 || arr[1]==-1 || arr[2]==-1) 
					{
					// skip invalid coords
					}
				else
					{
					item = malloc(sizeof(struct nnode));
					item->chrIdx = arr[0];
					if(asprintf(&item->name, "%s:%d-%d", chrInfo[arr[0]]->name, arr[1], arr[2])<0) errabort("bae");
					if(strcmp(genestruct, "custom")==0)
						{
						// add flanking
						if(arr[3] == 1)
							{
							item->start = arr[1]>=leftlength ? arr[1]-leftlength : 0;
							item->stop = arr[2]+rightlength>=chrInfo[arr[0]]->length ? chrInfo[arr[0]]->length : arr[2]+rightlength;
							}
						else
							{
							item->start = arr[1]>=rightlength ? arr[1]-rightlength : 0;
							item->stop = arr[2]+leftlength>=chrInfo[arr[0]]->length ? chrInfo[arr[0]]->length : arr[2]+leftlength;
							}
						}
					else
						{
						item->start = arr[1];
						item->stop = arr[2];
						}
					item->strand = arr[3]==1 ? '+' : '-';
					item->next = itemsl;
					itemsl = item;
					}
				}
			}
		}
    else if(cgiVarExists("forurl"))
		{
		// items from custom tabix file
		// limit items to be used by this Max number
		int maxitemnum = MaxBigbeditem4geneplot;
		char *fileurl=cgiString("forurl");
		tabix_t *fin=tabixOpen(fileurl);
		if(fin==NULL)
			{
			printf("'abort':'invalid tabix file'}");
			fputs("makegeneplot: failed to open tabix file", stderr);
			exit(0);
			}
		int chrIdx;
		struct beditem *btmsl, *btm;
		char delim[]="\t";
		char *tok;
		for(chrIdx=0; chrIdx<lastChrIdx; chrIdx++)
			{
			if(maxitemnum <= 0)
				break;
			btmsl=tabixQuery_regioncoord(fin, FT_bigbed_c, chrInfo[chrIdx]->name, 0, chrInfo[chrIdx]->length);
			if(btmsl == NULL)
				continue;
			// no need to sort btmsl, no need to cache, exit when done
			for(btm=btmsl; btm!=NULL; btm=btm->next)
				{
				item = malloc(sizeof(struct nnode));
				item->chrIdx = chrIdx;
				item->start = btm->start;
				item->stop = btm->stop;
				if(btm->rest == NULL)
					{
					if(asprintf(&item->name, "%s:%d-%d", chrInfo[chrIdx]->name, btm->start, btm->stop)<0)
						errabort("bae");
					item->strand='+';
					}
				else
					{
					tok = strtok(btm->rest, delim); // name
					if(tok == NULL)
						{
						if(asprintf(&item->name, "%s:%d-%d", chrInfo[chrIdx]->name, btm->start, btm->stop)<0)
							errabort("bae");
						item->strand='+';
						}
					else
						{
						item->name = tok;
						strtok(NULL, delim); // id
						tok = strtok(NULL, delim); // strand
						if(tok != NULL)
							{
							if(tok[0]!='+' && tok[0]!='-')
								item->strand='+';
							else
								item->strand=tok[0];
							}
						else
							item->strand='+';
						}
					}
				item->next = itemsl;
				itemsl = item;
				maxitemnum--;
				}
			}
		ti_close(fin);
		printf("'alert':'processed %d items',", MaxBigbeditem4geneplot-maxitemnum);
		}
    if(itemsl == NULL)
        {
		printf("'abort':'Gene Plot got no valid items'}");
		exit(0);
		}

    if(0)
        {
        fputs("testing>>>\n", stderr);
        for(item=itemsl; item!=NULL; item=item->next)
            fprintf(stderr, "\t%s %d %d %d %c\n", item->name, item->chrIdx, item->start, item->stop, item->strand);
        fputs("done<<<\n", stderr);
		}


    /******************************
       Step 2
       retrieve data and store in memory
     ******************************/
	char *tmp=cgiString("datatkft");
	int ft=strMayPositiveInt(tmp);
	if(ft==-1)
		{
		printf("'alert':'wrong data track filetype','gpabort':1}");
		return 1;
		}
	if(ft!=FT_hmtk_c && ft!=FT_hmtk_n && ft!=FT_qdecor_n)
		{
		printf("'alert':'data track not of quantitative','gpabort':1}");
		return 1;
		}
	// will all issue the tabixQuery_bedgraph() method
    char *urlpath=makefilepath(cgiString("datatk"),ft);
	tabix_t *fin=tabixOpen(urlpath);
    int spnum = cgiInt("spnum");
    int i;
    char *plottype = cgiString("plottype");
    boolean is_s1 = strcmp(plottype,"s1")==0;
    boolean is_s2 = strcmp(plottype,"s2")==0;
    boolean is_s3 = strcmp(plottype,"s3")==0;
    boolean is_s4 = strcmp(plottype,"s4")==0;
    if(is_s1 || is_s2 || is_s4)
        {
		/* these types will take the coordinates as provided, everything, no matter gene or coord
		   make single vector for each item
		 */
		for(item=itemsl; item!=NULL; item=item->next)
			{
			double *data = malloc(sizeof(double) * spnum);
			for(i=0; i<spnum; i++) 
				data[i] = 0;
			tabixQuery_bedgraph(fin, chrInfo[item->chrIdx]->name, item->start, item->stop, spnum, data);
			item->data = data;
			}
		}
    else if(is_s3)
        {
		/* 5 vectors for the 5 segment types, only process genes
		   5 vectors concatenated into one, follow the order:
			  promoter, utr5, exons, introns, utr3

		   for genes missing certain parts, the data value corresponding to that part
		   is indicated by LONG_MAX, and later during R code output,
		   this value will be detected and replaced by NA
		   so the summary value won't be affected
		   I just assume using LONG_MAX should be secure....
		 */
		double tmpdata[spnum], // store single vector
			   sumdata[spnum]; // store sum for exons/introns
		int validgenenum = 0;
		for(item=itemsl; item!=NULL; item=item->next)
			{
			/*** promoter ***/
			struct nnode *partsl = itemQueryRefGene(genetracksl, item->name, NULL, "promoter", "", 0,0);
			if(partsl == NULL)
				{
				// gene must have a promoter, or else it's not a gene
				item->data = NULL;
					continue;
				}
			validgenenum++;
			double *data = malloc(sizeof(double) * spnum * 5); // entire data vector containing sub vectors
			int dataIdx;
			dataIdx = 0;
			for(i=0; i<spnum; i++)
				tmpdata[i] = 0;
			tabixQuery_bedgraph(fin, chrInfo[item->chrIdx]->name, partsl->start, partsl->stop, spnum, &tmpdata[0]);
			if(item->strand == '-')
				{
				for(i=0; i<spnum; i++)
					data[dataIdx+i] = tmpdata[spnum-1-i];
				}
			else
				{
				for(i=0; i<spnum; i++)
					data[dataIdx+i] = tmpdata[i];
				}
			dataIdx += spnum;
			/*** 5' utr ***/
			partsl = itemQueryRefGene(genetracksl, item->name, NULL, "utr5", "", 0,0);
			if(partsl==NULL || partsl->stop<=partsl->start)
				{
				// no 5' utr, use special value to indicate
				//fprintf(stderr, "%s no 5' utr\n", item->name);
				for(i=0; i<spnum; i++)
					data[dataIdx+i] = LONG_MAX;
				}
			else
				{
				for(i=0; i<spnum; i++)
					tmpdata[i] = 0;
				tabixQuery_bedgraph(fin, chrInfo[item->chrIdx]->name, partsl->start, partsl->stop, spnum, &tmpdata[0]);
				if(item->strand == '-')
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = tmpdata[spnum-1-i];
					}
				else
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = tmpdata[i];
					}
				if(0)
					{
					fprintf(stderr, "%s %d --> ", item->name, partsl->stop-partsl->start);
					for(i=0; i<spnum; i++)
						fprintf(stderr, "%d ", (int)tmpdata[i]);
					fputs("\n", stderr);
					}
				}
			dataIdx += spnum;
			/*** exons (average vector is computed for each gene) ***/
			int totalnum = 0;
			struct nnode *tmpnode;
			partsl = itemQueryRefGene(genetracksl, item->name, NULL, "exons", "", 0,0);
			if(partsl == NULL)
				{
				// no exon
				//fprintf(stderr, "%s no exon\n", item->name);
				for(i=0; i<spnum; i++)
					data[dataIdx+i] = LONG_MAX;
				}
			else
				{
				for(i=0; i<spnum; i++) 
					sumdata[i]=0;
				for(tmpnode=partsl; tmpnode!=NULL; tmpnode=tmpnode->next)
					{
					if(tmpnode->stop <= tmpnode->start)
						continue;
					for(i=0; i<spnum; i++) 
						tmpdata[i]=0;
					tabixQuery_bedgraph(fin, chrInfo[item->chrIdx]->name, tmpnode->start, tmpnode->stop, spnum, &tmpdata[0]);
					for(i=0; i<spnum; i++)
						sumdata[i] += tmpdata[i];
					totalnum++;
					}
				if(item->strand == '-')
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = sumdata[spnum-1-i] / totalnum;
					}
				else
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = sumdata[i] / totalnum;
					}
				}
			dataIdx += spnum;
			/*** introns (average vector is computed) ***/
			partsl = itemQueryRefGene(genetracksl, item->name, NULL, "introns", "", 0,0);
			if(partsl == NULL)
				{
				// no intron
				//fprintf(stderr, "%s no intron\n", item->name);
				for(i=0; i<spnum; i++)
					data[dataIdx+i] = LONG_MAX;
				}
			else
				{
				totalnum = 0;
				for(i=0; i<spnum; i++) 
					sumdata[i]=0;
				for(tmpnode=partsl; tmpnode!=NULL; tmpnode=tmpnode->next)
					{
					if(tmpnode->stop <= tmpnode->start)
						continue;
					for(i=0; i<spnum; i++) 
						tmpdata[i] = 0;
					tabixQuery_bedgraph(fin, chrInfo[item->chrIdx]->name, tmpnode->start, tmpnode->stop, spnum, &tmpdata[0]);
					for(i=0; i<spnum; i++)
						sumdata[i] += tmpdata[i];
					totalnum++;
					}
				if(item->strand == '-')
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = sumdata[spnum-1-i] / totalnum;
					}
				else
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = sumdata[i] / totalnum;
					}
				}
			dataIdx += spnum;
			/*** 3' utr ***/
			partsl = itemQueryRefGene(genetracksl, item->name, NULL, "utr3", "", 0,0);
			if(partsl==NULL || partsl->stop<=partsl->start)
				{
				// no 3' utr
				//fprintf(stderr, "%s no 3' utr\n", item->name);
				for(i=0; i<spnum; i++)
					data[dataIdx+i] = LONG_MAX;
				}
			else
				{
				for(i=0; i<spnum; i++) 
					tmpdata[i] = 0;
				tabixQuery_bedgraph(fin, chrInfo[item->chrIdx]->name, partsl->start, partsl->stop, spnum, &tmpdata[0]);
				if(item->strand == '-')
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = tmpdata[spnum-1-i];
					}
				else
					{
					for(i=0; i<spnum; i++)
						data[dataIdx+i] = tmpdata[i];
					}
				}
			item->data = data;
			}
		if(validgenenum == 0)
			{
			// no valid gene to make s3 plot, need to abort
			ti_close(fin);
			printf("'alert':'no valid gene, please check your input','gpabort':1}");
			exit(0);
			}
		}
	ti_close(fin);
    
    /* Step 2.1
       make safe name for clustering
       this will be used in returning json data
     */
    struct slNode *clustersafenamesl = NULL, *namenode;
    if(is_s4)
        {
		i = 0;
		for(item=itemsl; item!=NULL; item=item->next)
			{
			namenode = malloc(sizeof(struct slNode));
			if(asprintf(&(namenode->name), "g%d", i++)<0) errabort("bae");
			namenode->next = clustersafenamesl;
			clustersafenamesl = namenode;
			}
		slReverse(&clustersafenamesl);
		}

    /* Step 2.2
       prepare to write data to temperary files
       - R rendering
       - clustering
     */
    boolean usingR = cgiVarExists("usingR"); // now this only means using R for rendering
    if(is_s4)
        usingR = FALSE;
    char *rfile; // a single file to hold R command
    char *pngfile;
    char *routfile; // dummy out file when calling R in batch mode
    char *rtmpfile; // temp file to store some R output (e.g. summary values)
    FILE *fout = NULL;
    if(is_s1 || is_s3 || is_s4 || usingR)
        {
		if(asprintf(&rfile, "%s/%s.geneplot", trashDir, session)<0) errabort("bae");
		fout = fopen(rfile, "w");
		if(fout == NULL)
			errabort("cannot open file for writing geneplot code");
		}
    if(asprintf(&routfile, "%s/%s.rout", trashDir, session)<0) errabort("bae");
    if(is_s1 || is_s3 || usingR)
        {
		// R code will be writen when using R for rendering or computing summary for s1/s3
		srand(time(0));
		if(asprintf(&pngfile, "%s/%d.png", WWWT, rand())<0) errabort("bae");
		if(asprintf(&rtmpfile, "%s/%s.rtmp", trashDir, session)<0) errabort("bae");
		if(usingR)
			fprintf(fout, "png(\"%s\", %s, %s)\n", pngfile, cgiString("width"), cgiString("height"));
		}


    /*********************************
       Step 3
       s2 json output of unprocessed data
       when doing R rendering, write to R source file
       finishes s2
     *********************************/
    double value;
    if(is_s2)
        {
		/* spaghetti plot, a list of vectors
		   [name string, v1, v2, v3, ...]
		 */
		printf("\"data\":[");
		if(usingR)
			fputs("mat = matrix(c(", fout);
		for(item=itemsl; item!=NULL; item=item->next)
			{
			printf("[\"%s\",", item->name);
			if(item->strand == '-')
				{ // reverse
				for(i=0; i<spnum; i++)
					{
					value = (item->data)[spnum-1-i];
					printf("%.2f,", value);
					if(usingR)
						fprintf(fout, "%.2f,", value);
					}
				}
			else
				{ // forward
				for(i=0; i<spnum; i++)
					{
					value = (item->data)[i];
					printf("%.2f,", value);
					if(usingR)
						fprintf(fout, "%.2f,", value);
					}
				}
			printf("],");
			}
		printf("],");
		if(usingR)
			{
			fseek(fout, -1, SEEK_CUR);
			fprintf(fout, "), nrow=%d)\n", spnum);
			fprintf(fout, "matplot(mat, type='l', lwd=%s, xlab=\"Genomic positions from 5' to 3'\", ylab='Data point values', xaxt='n')\ndev.off()\n", cgiString("lw"));
			fclose(fout);
			char *command;
			if(asprintf(&command, "R CMD BATCH --no-save %s %s", rfile, routfile)<0) errabort("bae");
			if(system(command) == -1)
			errabort("cannot spawn process to do clustering");
			printf("\"image\":\"%s\"", pngfile);
			}
		/*** s2 finishes ***/
		}

    /*********************************
       Step 4
       data processing/summarization for s1 and s3
       the summarization (calling summary function) has to be done in R
       summary numbers are writen to a text file
       parse it and return as json
       R rendering will be run in mean time if applicable
       this finishes up s1 and s3
     *********************************/
    if(is_s1)
        {
		// use R to summarize data
		fputs("mat = t(matrix(c(", fout);
		for(item=itemsl; item!=NULL; item=item->next)
			{
			if(item->strand == '-')
				{
				for(i=0; i<spnum; i++)
					fprintf(fout, "%.2f,", (item->data)[spnum-1-i]);
				}
			else
				{
				for(i=0; i<spnum; i++)
					fprintf(fout, "%.2f,", (item->data)[i]);
				}
			}
		fseek(fout, -1, SEEK_CUR);
		fprintf(fout, "), nrow=%d))\n", spnum);
		// no matter whether to use R to render or not, compute summary, save result in a file
		for(i=1; i<=spnum; i++)
			fprintf(fout, "write(summary(mat[,%d]), \"%s\", ncolumns=6, append=T, sep=\",\")\n", i, rtmpfile);
		if(usingR)
			{
			fprintf(fout, "boxplot(mat,outline=%s,range=%s,col=%s", cgiString("outlier"), cgiString("range"), cgiString("lc"));
			fseek(fout, -1, SEEK_CUR);
			fputs(",max=255),xlab=\"Genomic positions from 5' to 3'\",ylab=\"Data value distribution\")\n", fout);
			if(cgiVarExists("average"))
				{
				// draw average line
				fputs("lines(c(", fout);
				for(i=1; i<=spnum; i++)
					fprintf(fout, "%d,", i);
				fseek(fout, -1, SEEK_CUR);
				fputs("),c(", fout);
				for(i=1; i<=spnum; i++)
					fprintf(fout, "mean(mat[,%d],na.rm=T),", i);
				fseek(fout, -1, SEEK_CUR);
				fprintf(fout, "), lw=%s, col=%s", cgiString("lw"), cgiString("averagelc"));
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255))\n", fout);
				}
			fputs("dev.off()\n", fout);
			}
		fclose(fout);
		}
    else if(is_s3)
        {
		// won't reverse vector for genes on minus strand, this has already been done dude!
		fputs("mat = t(matrix(c(", fout);
		int all = spnum*5;
		for(item=itemsl; item!=NULL; item=item->next)
			{
			if(item->data == NULL)
				continue;
			for(i=0; i<all; i++)
				{
				float x = (item->data)[i];
				// FIXME why some values are printed out as "-nan" in maize??
				if(x==LONG_MAX || isnan(x))
					fputs("NA,", fout);
				else
					fprintf(fout, "%.2f,", (item->data)[i]);
				}
			}
		fseek(fout, -1, SEEK_CUR);
		fprintf(fout, "), nrow=%d))\n", all);
		// no matter whether to use R to render or not, compute summary, save result in a file
		for(i=1; i<=all; i++)
			fprintf(fout, "write(summary(mat[,%d])[1:6], \"%s\", ncolumns=6, append=T, sep=\",\")\n", i, rtmpfile);
		if(usingR)
			{
			fprintf(fout, "boxplot(mat,outline=%s,range=%s,xaxt='n',xlab=\"Genomic positions from 5' to 3'\",ylab=\"Data value distribution\",col=c(", cgiString("outlier"), cgiString("range"));
			char *col = cgiString("promoterc");
			for(i=0; i<spnum; i++)
				{
				fprintf(fout, "%s", col);
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255),", fout);
				}
			col = cgiString("utr5c");
			for(i=0; i<spnum; i++)
				{
				fprintf(fout, "%s", col);
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255),", fout);
				}
			col = cgiString("exonsc");
			for(i=0; i<spnum; i++)
				{
				fprintf(fout, "%s", col);
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255),", fout);
				}
			col = cgiString("intronsc");
			for(i=0; i<spnum; i++)
				{
				fprintf(fout, "%s", col);
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255),", fout);
				}
			col = cgiString("utr3c");
			for(i=0; i<spnum; i++)
				{
				fprintf(fout, "%s", col);
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255),", fout);
				}
			fseek(fout, -1, SEEK_CUR);
			fputs("))\n", fout);
			if(cgiVarExists("average"))
				{
				// draw average curve
				int j = 0;
				// promoter
				fputs("lines(c(", fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "%d,", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fputs("),c(",fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "mean(mat[,%d],na.rm=T),", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fprintf(fout, "),lw=%s,col=%s", cgiString("lw"), cgiString("average_promoterc"));
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255))\n", fout);
				j += spnum;
				// 5' utr
				fputs("lines(c(", fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "%d,", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fputs("),c(",fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "mean(mat[,%d],na.rm=T),", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fprintf(fout, "),lw=%s,col=%s", cgiString("lw"), cgiString("average_utr5c"));
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255))\n", fout);
				j += spnum;
				// exons
				fputs("lines(c(", fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "%d,", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fputs("),c(",fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "mean(mat[,%d],na.rm=T),", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fprintf(fout, "),lw=%s,col=%s", cgiString("lw"), cgiString("average_exonsc"));
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255))\n", fout);
				j += spnum;
				// introns
				fputs("lines(c(", fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "%d,", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fputs("),c(",fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "mean(mat[,%d],na.rm=T),", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fprintf(fout, "),lw=%s,col=%s", cgiString("lw"), cgiString("average_intronsc"));
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255))\n", fout);
				j += spnum;
				// 3' utr
				fputs("lines(c(", fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "%d,", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fputs("),c(",fout);
				for(i=0; i<spnum; i++)
					fprintf(fout, "mean(mat[,%d],na.rm=T),", j+i+1);
				fseek(fout, -1, SEEK_CUR);
				fprintf(fout, "),lw=%s,col=%s", cgiString("lw"), cgiString("average_utr3c"));
				fseek(fout, -1, SEEK_CUR);
				fputs(",max=255))\n", fout);
				}
			fprintf(fout, "axis(side=1, at=c(%d,%d,%d,%d,%d), labels=c(\"promoter\",\"5' UTR\",\"exons\",\"introns\",\"3' UTR\"))\n",spnum/2,spnum+spnum/2,spnum*2+spnum/2,spnum*3+spnum/2,spnum*4+spnum/2);
			fputs("dev.off()\n", fout);
			}
		fclose(fout);
		}
    // common step to run R code for s1 and s3, do json return
    if(is_s1 || is_s3)
        {
		/* the summarized data will be writen to rtmpfile
		   R "write" function is appending stuff to it
		   so have to remove this file if it exists (previous geneplot in same session)
		 */
		unlink(rtmpfile);
		char *command;
		if(asprintf(&command, "R CMD BATCH --no-save %s %s", rfile, routfile)<0) errabort("bae");
		if(system(command) == -1)
			errabort("cannot spawn process to do clustering");
		/* parse rtmpfile to read summary values and return as json

		   json: list of vectors, by number of spnum
		   each vector: [min, 1 qu, median, mean, 3 qu, max]
		   there's no item name!!
		 */
		char *line = malloc(1);
		size_t s = 1;
		char delim[] = "\n";
		FILE *fin = fopen(rtmpfile, "r");
		if(fin == NULL) errabort("s1/s3 rtmpfile not found");
		printf("\"data\":[");
		while(getline(&line, &s, fin) != -1)
			{
			printf("[%s],", strtok(line, delim));
			}
		printf("],");
		fclose(fin);
		if(usingR)
			printf("\"image\":\"%s\"", pngfile);
		/*** s1 and s3 finishes ***/
		}
    

    /*********************************
       Step 5
       clustering
       in certain clustering methods:
         - vectors with zero std need to be discarded in correlation-based distance metric
	 - should not transpose matrix in correlation-based distance metric
     *********************************/
    if(is_s4)
        {
		// make a logical vector in same length as itemsl
		int totalNum=0;
		for(item=itemsl; item!=NULL; item=item->next)
			totalNum++;
		int std0flag[totalNum]; // set to 1 for zero sd
		for(i=0; i<totalNum; i++)
			std0flag[i] = 0;
		int std0num = 0; // number of vectors with 0 std
		boolean transpose = TRUE; // whether to transpose matrix at creation
		if(cgiString("clustmethod")[0] == 'h')
			{
			if(cgiString("clustdist")[0] != 'e')
				{
				/* hierarchical, not using euclidean distance but using correlation based
				   need to escape 0-std vectors
				   need not to transpose matrix
				 */
				transpose = FALSE;
				i = 0;
				for(item=itemsl; item!=NULL; item=item->next)
					{
					if(standardDeviation(item->data, spnum) == 0)
					{
					std0num++;
					std0flag[i] = 1;
					}
					i++;
					}
				}
			}
		if(std0num > 0)
			{
			printf("\"zerosdgene\":[");
			i = 0;
			for(item=itemsl; item!=NULL; item=item->next)
				{
				if(std0flag[i++])
					{
					printf("\"%s\",", item->name);
					}
				}
			printf("],");
			}

		/* return data as json hash, key: safe name, value: [real name, v1, v2, ...]
		   also write data portion of R code
		   omit 0-std ones
		 */
		printf("\"data\":{");
		fprintf(fout, "mat = %smatrix(c(", transpose?"t(":"");
		namenode=clustersafenamesl;
		int k = 0;
		for(item=itemsl; item!=NULL; item=item->next)
			{
			if(!std0flag[k])
				{
				printf("\"%s\":[\"%s\",", namenode->name, item->name);
				if(item->strand == '-')
					{
					for(i=0; i<spnum; i++)
						{
						value = (item->data)[spnum-1-i];
						printf("%.2f,", value);
						fprintf(fout, "%f,", value);
						}
					}
				else
					{
					for(i=0; i<spnum; i++)
						{
						value = (item->data)[i];
						printf("%.2f,", value);
						fprintf(fout, "%f,", value);
						}
					}
				printf("],");
				}
			k++;
			namenode = namenode->next;
			}
		printf("},");
		fseek(fout, -1, SEEK_CUR);
		fprintf(fout, "), nrow=%d)", spnum);
		if(transpose)
			fputs(")\nrownames(mat)=c(", fout);
		else
			fputs("\ncolnames(mat)=c(", fout);
		i = 0;
		for(namenode=clustersafenamesl; namenode!=NULL; namenode=namenode->next)
			{
			if(!std0flag[i++])
				fprintf(fout, "\"%s\",", namenode->name);
			}
		fseek(fout, -1, SEEK_CUR);
		fputs(")\n", fout);

		/* clustering method specific processing */
		if(cgiString("clustmethod")[0] == 'k')
			{
			/* kmeans clustering */
			char *kmnamefile;
			char *kmclusterfile;
			if(asprintf(&kmnamefile, "%s/%s.kmname", trashDir, session)<0) errabort("bae");
			if(asprintf(&kmclusterfile, "%s/%s.kmcluster", trashDir, session)<0) errabort("bae");
			fprintf(fout, "k=kmeans(mat, %s, nstart=10)\n", cgiString("kmeanscnum"));
			fprintf(fout, "write(names(k$cluster), ncol=1, '%s')\n", kmnamefile);
			fprintf(fout, "write(k$cluster, ncol=1, '%s')\n", kmclusterfile);
			fclose(fout);
			char *command;
			if(asprintf(&command, "R CMD BATCH --no-save %s %s", rfile, routfile)<0) errabort("bae");
			if(system(command) == -1)
				errabort("cannot spawn process to do clustering");
			// return clustering result
			char *line = malloc(1); size_t s = 1;
			char delim[] = "\n";

			FILE *fin = fopen(kmnamefile, "r");
			if(fin == NULL) errabort("kmnamefile not found");
				printf("\"kmnames\":[");
			while(getline(&line, &s, fin) != -1)
				printf("\"%s\",", strtok(line, delim));
			printf("],");
			fclose(fin);
			fin = fopen(kmclusterfile, "r");
			if(fin == NULL) errabort("kmclusterfile not found");
				printf("\"kmnamecluster\":[");
			while(getline(&line, &s, fin) != -1)
				printf("%s,", strtok(line, delim));
			printf("]");
			fclose(fin);
			/*** kmeans done ***/
			}
		else
			{
			/* hclust: hierarchical clustering */
			char *hclustmergefile; // store hc$merge
			char *hclustlabelsfile; // store hc$labels
			char *hclustoutfile; // store hc$label[hc$order]
			char *hclustheightfile; // store hc$height
			if(asprintf(&hclustmergefile, "%s/%s.hclustmerge", trashDir, session)<0) errabort("bae");
			if(asprintf(&hclustoutfile, "%s/%s.hclustout", trashDir, session)<0) errabort("bae");
			if(asprintf(&hclustlabelsfile, "%s/%s.hclustlabels", trashDir, session)<0) errabort("bae");
			if(asprintf(&hclustheightfile, "%s/%s.hclustheight", trashDir, session)<0) errabort("bae");
			char dist = cgiString("clustdist")[0];
			char *agglomeration = cgiString("clustaglm");
			if(dist == 'e')
				{
				/* using euclidean distance, no filtering on vectors */
				fprintf(fout, "hc = hclust(dist(mat, method='e'), '%s')\n", agglomeration);
				}
			else
				{
				/* using spearman or pearson as distance metric, excluding 0-std vectors */
				fprintf(fout, "hc = hclust(as.dist(1-abs(cor(mat, method='%c'))), '%s')\n", dist, agglomeration);
				}
			fprintf(fout, "write(hc$labels[hc$order], '%s')\n", hclustoutfile);
			// write out hclust$merge, two children for each cluster, which number is validnum-1
			fprintf(fout, "write(hc$merge[1,], ncolumns=2, sep=',', '%s')\n", hclustmergefile);
			for(i=2; i<totalNum-std0num; i++)
				fprintf(fout, "write(hc$merge[%d,],ncolumns=2, append=T, sep=',', '%s')\n", i, hclustmergefile);
			fprintf(fout, "write(hc$labels, ncolumns=1, '%s')\n", hclustlabelsfile);
			fprintf(fout, "write(hc$height, ncolumns=1, '%s')\n", hclustheightfile);
			fclose(fout);

			char *command;
			if(asprintf(&command, "R CMD BATCH --no-save %s %s", rfile, routfile)<0) errabort("bae");
			if(system(command) == -1)
				errabort("cannot spawn process to do clustering");

			char *line = malloc(1); size_t s = 1;
			char delim[] = "\n";

			// return hc$labels, R's stubborn list of items
			FILE *fin = fopen(hclustlabelsfile, "r");
			if(fin == NULL) errabort("hclustlabelsfile not found");
			printf("\"hclustlabels\":[");
			while(getline(&line, &s, fin) != -1)
				printf("\"%s\",", strtok(line, delim));
			printf("],");
			fclose(fin);
			// return hc$labels[hc$order] the order of appearance of gene safe names
			fin = fopen(hclustoutfile, "r");
			if(fin == NULL) errabort("hclustoutfile not found");
				printf("\"hclustgenelst\":[");
			while(getline(&line, &s, fin) != -1)
				printf("\"%s\",", strtok(line, delim));
			printf("],");
			fclose(fin);
			// return hc$merge
			fin = fopen(hclustmergefile, "r");
			if(fin == NULL) errabort("hclustmergefile not found");
			printf("\"hclustmerge\":[");
			while(getline(&line, &s, fin) != -1)
				printf("[%s],", strtok(line, delim));
			printf("],");
			fclose(fin);

			// return hc$height
			fin = fopen(hclustheightfile, "r");
			if(fin == NULL) errabort("hclustheightfile not found");
			printf("\"hclustheight\":[");
			while(getline(&line, &s, fin) != -1)
				printf("%s,", strtok(line, delim));
			printf("],");
			fclose(fin);
			/*** hierarchical clustering done ***/
			}
		}

    printf("}");
	done();
    return 1;
    }


// TRI triggers
boolean isFirst = cgiVarExists("first");
boolean trigger_changeGF = cgiVarExists("changeGF");
boolean trigger_zoom = cgiVarExists("zoom");
boolean trigger_move = cgiVarExists("move");
boolean trigger_imgAreaSelect = cgiVarExists("imgAreaSelect"); // defunc, relic...
boolean trigger_jump = cgiVarExists("jump");
boolean trigger_addserverhmtk= cgiVarExists("addserverhmtk");
boolean trigger_correlation = cgiVarExists("correlation");
boolean trigger_htest = cgiVarExists("htest");
boolean trigger_decor0 = cgiVarExists("decor0"); // server bigbed
boolean trigger_decor1 = cgiVarExists("decor1"); // custom bigbed
boolean trigger_decor8 = cgiVarExists("decor8"); // server bigwig
boolean trigger_decor4 = cgiVarExists("decor4"); // server BAM
boolean trigger_decor5 = cgiVarExists("decor5"); // custom BAM
boolean trigger_decor9 = cgiVarExists("decor9"); // server chia-pet
boolean trigger_decor10 = cgiVarExists("decor10"); // custom chia-pet
trigger_getdata = cgiVarExists("getdata"); // this is global variable...
boolean trigger_restoreStatus = cgiVarExists("restoreStatus");
boolean trigger_genesetview = cgiVarExists("itemlist"); // running in gene set view mode
boolean trigger_newitemlist = FALSE;
boolean trigger_updateitemlist = FALSE;
boolean trigger_scaffoldUpdate = cgiVarExists("scaffoldUpdate");
/* following two triggers are associated with long-range tracks
trigger_newchiapet: requesting data to be displayed in chiapet panel, hm.dsp is only one region
trigger_chiapet: requesting data to be displayed in all chiapet panels,
  hm.dsp contains regions from main panel, NOT chiapet panel
  regions for all chiapet views are in hm.dsp_chiapet
*/
boolean trigger_newchiapet = cgiVarExists("newchiapet");
boolean trigger_chiapet = cgiVarExists("chiapetregion");

// making a new chiapet view, spit back the serial number
if(trigger_newchiapet)
    printf("'chiapetIdx':%s,", cgiString("newchiapet"));



struct displayedRegion dsp;
dsp.gf = GENOME;
dsp.head = NULL;
dsp.tail = NULL;
dsp.chritemsl=NULL;
dsp.atbplevel = FALSE;
dsp.usedSummaryNumber = 0;
dsp.juxType = 0;
dsp.juxFt=0;
dsp.tabix=NULL;


struct displayedRegion dsp_chiapet;
dsp_chiapet.gf = GENOME;
dsp_chiapet.chritemsl = NULL;
dsp_chiapet.head = NULL;
dsp_chiapet.tail = NULL;
dsp_chiapet.atbplevel = FALSE;
dsp_chiapet.usedSummaryNumber = 0;
dsp_chiapet.juxType = 0;

struct heatmap hm;
hm.dsp = &dsp;
hm.dsp_chiapet = &dsp_chiapet;
hm.trackSl = NULL;
hm.datasetSl = NULL;
hm.decor0 = NULL;
hm.decor1 = NULL;
hm.decor8 = NULL;
hm.decor4 = NULL;
hm.decor5 = NULL;
hm.decor9 = NULL;
hm.decor10 = NULL;
hm.genetracksl = genetracksl;

hmSpan = cgiInt("hmspan");


if(isFirst)
    {
    if(SQUAWK) fputs("Is first!\n", Squawk);

    // INIT all household stuff
    int i;

    // get server load
    char *trashfile;
    if(asprintf(&trashfile, "%s/sysload", trashDir)<0) errabort("bae");
    char *comm;
    if(asprintf(&comm, "uptime > %s", trashfile)<0) errabort("bae");
    if(system(comm) == -1)
        errabort("cannot do system call");
    FILE *fin = fopen(trashfile, "r");
    if(fin != NULL)
        {
		char *line = malloc(1);
		size_t s = 1;
		if(getline(&line, &s, fin))
			{
			// good idea to parse the string on client side
			char delim[] = "\n";
			printf("\"serverload\":\"%s\",",strtok(line, delim));
			}
		fclose(fin);
		}

	mysql_close(conn);
    mysqlConnect(CentralDB);

    // list of genome databases, appear in species selector
    MYSQL_RES *sr = mysqlGetResult("select dbName,dbLabel,organism,fontcolor from dbTable");
	assert(sr!=NULL);
    printf("\"dblist\":[");
    char **row;
    while((row=mysql_fetch_row(sr)) != NULL)
        {
        assert(row[0] != NULL);
		assert(row[1] != NULL);
		assert(row[2] != NULL);
		assert(row[3] != NULL);
		printf("['%s', '%s', '%s', '%s'],", row[0], row[1], row[2], row[3]);
		}
    printf("],");
    mysql_free_result(sr);


    // more info for current db
    printf("\"currentDb\":{\"name\":\"%s\",", dbName);
    char *query;
    if(asprintf(&query, "select mirrorlinkurl,organism,ucscmirrordb from dbTable where dbName=\"%s\"", dbName)<0) errabort("bae");
    sr = mysqlGetResult(query);
    free(query);
    assert((row=mysql_fetch_row(sr)) != NULL);
    printf("'mirrorlinkurl':'%s',"
		"'organism':'%s',"
		"'ucscmirrordb':'%s',",
		row[0], row[1], row[2]);
    mysql_free_result(sr);

    // close connection to CentralDB, connect to database of this genome
	mysql_close(conn);
    mysqlConnect(dbName);

    // default displayed position
	char *tmp = mysqlGetOnestring("select defaultPosition from config");
	assert(tmp!=NULL);
    printf("'defaultPosition':'%s'},", tmp);
    // let browser jump to default position using jump trigger
    trigger_jump = TRUE;
    cgiVarSet("jumppos2", tmp);
	free(tmp);

	assert((tmp=mysqlGetOnestring("select hasGene from config"))!=NULL);
	printf("'hasGene':%s,", tmp);
	free(tmp);
	assert((tmp=mysqlGetOnestring("select allowJuxtaposition from config"))!=NULL);
	printf("'allowJuxtaposition':%s,", tmp);
	free(tmp);

    tmp=mysqlGetOnestring("select ideogram_wiggle1 from config");
	if(tmp!=NULL)
		{
		printf("'ideogram_wiggle1':'%s',", tmp);
		free(tmp);
		}
    tmp=mysqlGetOnestring("select ideogram_wiggle2 from config");
	if(tmp!=NULL)
		{
		printf("'ideogram_wiggle2':'%s',", tmp);
		free(tmp);
		}

    tmp=mysqlGetOnestring("select sampleHub from config");
	if(tmp!=NULL)
		{
        printf("'samplehub':'%s',", tmp);
		free(tmp);
		}

    onetimedeal_juxtapose();
    onetimedeal_geneset();
    onetimedeal_nativehmtk();
    onetimedeal_htest();
    onetimedeal_pairwiseCompare();
    onetimedeal_corr();
    onetimedeal_customTrack();
    onetimedeal_session();


    // cytoband (data may be null)
    sr = mysqlGetResult("select chrom,start,stop,colorIdx,name from cytoband");
    printf("\"cytoband\":[");
    while((row=mysql_fetch_row(sr)) != NULL)
	printf("['%s',%s,%s,%s,'%s'],", row[0], row[1], row[2], row[3], row[4]);
    printf("],");
    mysql_free_result(sr);


    /* simply retrieves what's in gfGrouping and decorInfo table
       send them to JS
       JS will render the page
     */
    sr = mysqlGetResult("select * from gfGrouping");
    printf("\"gfGrouping\":[");
    while((row=mysql_fetch_row(sr)) != NULL)
		printf("[%s,\"%s\"],", row[0], row[1]);
    mysql_free_result(sr);
    printf("],");

    sr = mysqlGetResult("select * from decorInfo");
    printf("'decorInfo':{");
    while((row=mysql_fetch_row(sr)) != NULL)
		{
		// some complex string might have quote so must be in double quote
		printf("\"%s\":{isexpassay:false,label:\"%s\",grp:%s,fileType:%s,hasStruct:%s", row[0], row[1], row[3],row[4],row[5]);
		if(row[2] != NULL)
			printf(",parent:\"%s\"", row[2]);
		if(row[6] != NULL)
			printf(",queryUrl:\"%s\"", row[6]);
		printf("},");
		}
    printf("},");
    mysql_free_result(sr);

    /* experimental assays tracks as decors
       they are in groups and have metadata annotation
     */
    printf("'decorexpassay':{groupgrid:{");
    sr = mysqlGetResult("select * from decorTrackselectiongrid");
    boolean hasexptk = FALSE;
    while((row=mysql_fetch_row(sr)) != NULL)
        {
		printf("'%s':['%s','%s'],", row[0], row[1], row[2]);
		hasexptk = TRUE;
		}
    printf("},");
    mysql_free_result(sr);
    if(hasexptk)
        {
		// track name to filetype, label, mdanno
		printf("tkinfo:{");
		sr = mysqlGetResult("select a.tkname,a.filetype,b.label,c.attridx from decorAssaytrack as a,track2Label as b,track2Annotation as c where a.tkname=b.name and a.tkname=c.name");
		while((row=mysql_fetch_row(sr)) != NULL)
			{
			printf("'%s':{isexpassay:true,fileType:%s,label:\"%s\",mdanno:'%s',grp:-1,hasStruct:0},", row[0], row[1], row[2], row[3]);
			}
		printf("},");
		mysql_free_result(sr);
		}
    printf("},");

    // decor default parameter
    printf("'decorDefaultparam':{");
    sr = mysqlGetResult("select * from decorDefaultparam");
    while((row=mysql_fetch_row(sr)) != NULL)
		printf("'%s':{%s},", row[0], row[1]);
    printf("},");
    mysql_free_result(sr);

    // metadata vocabulary
    printf("\"mdvidx2attr\":{");
    sr = mysqlGetResult("select * from trackAttr2idx");
    while((row=mysql_fetch_row(sr)) != NULL)
        printf("%s:\"%s\",", row[0], row[1]);
    printf("},");
    mysql_free_result(sr);

    printf("\"mdvc2p\":{");
    sr = mysqlGetResult("select * from metadataVocabulary");
    while((row=mysql_fetch_row(sr)) != NULL)
		printf("\"%s\":\"%s\",", row[0], row[1]);
    printf("},");
    mysql_free_result(sr);

    char *tok;
    char delimcomma[] = ",";

    // default metadata terms on show
    if(!cgiVarExists("noDefaultcontent"))
        {
	printf("\"mdcategoryonshow\":[");
	char *string = mysqlGetOnestring("select defaultMdcategory from config");
	tok = strtok(string, delimcomma);
	while(tok != NULL)
	    {
	    printf("\"%s\",", tok);
	    tok = strtok(NULL, delimcomma);
	    }
	printf("],");
	}

    printf("\"defaultGenelist\":\"%s\","
           "\"defaultCustombigwig\":\"%s\","
	   "\"defaultCustombigbed\":\"%s\","
	   "\"defaultCustombam\":\"%s\","
	   "\"keggSpeciesCode\":\"%s\",", 
	   mysqlGetOnestring("select defaultGenelist from config"),
	   mysqlGetOnestring("select defaultCustombigwig from config"),
	   mysqlGetOnestring("select defaultCustombigbed from config"),
	   mysqlGetOnestring("select defaultCustombam from config"),
	   mysqlGetOnestring("select keggSpeciesCode from config")
	  );


    /* datasets
	if 'hmtk4dataset' is present, user has supplied hmtk tracks from urlparam,
	and need to fetch data sets spanned by these tracks
	else, only use first dataset
	*/
	if(cgiVarExists("hmtk4dataset"))
		{
		struct slNode *tksl=NULL, *tk; // list of hmtk
		char delim[]=",";
		char *tok=strtok(cgiString("hmtk4dataset"),delim);
		if(tok!=NULL)
			{
			while(tok!=NULL)
				{
				tk=malloc(sizeof(struct slNode));
				tk->name=tok;
				tk->next=tksl;
				tksl=tk;
				tok=strtok(NULL,delim);
				}
			struct tnode *dsl=NULL, *d; // list of ds
			MYSQL_RES *sr=mysqlGetResult("select tablename from dataset");
			assert(sr!=NULL);
			char **row;
			while((row=mysql_fetch_row(sr))!=NULL)
				{
				d=malloc(sizeof(struct tnode));
				d->t1=strdup(row[0]);
				d->t4=FALSE;
				d->next=dsl;
				dsl=d;
				}
			assert(dsl!=NULL);
			mysql_free_result(sr);
			char *query;
			for(tk=tksl; tk!=NULL; tk=tk->next)
				{
				for(d=dsl; d!=NULL; d=d->next)
					{
					if(!d->t4)
						{
						assert(asprintf(&query, "select tkname from %s where tkname='%s'", d->t1, tk->name)>0);
						if(mysqlResultAffirmative(query))
							{
							d->t4=TRUE;
							}
						free(query);
						}
					}
				}
			for(d=dsl; d!=NULL; d=d->next)
				{
				if(!d->t4) continue;
				tk=malloc(sizeof(struct slNode));
				tk->name=strdup(d->t1);
				tk->next=hm.datasetSl;
				hm.datasetSl=tk;
				}
			slFree(dsl);
			slFree(tksl);
			}
		}
	if(hm.datasetSl==NULL)
		{
		char *dsn=mysqlGetOnestring("select tablename from dataset limit 1");
		assert(dsn!=NULL);
		struct slNode *tt = malloc(sizeof(struct slNode));
		tt->name=dsn;
		tt->next=hm.datasetSl;
		hm.datasetSl = tt;
		}
	{
		printf("'dataset':'");
		struct slNode *t;
		for(t=hm.datasetSl; t!=NULL; t=t->next)
			printf("%s,", t->name);
		printf("',");
	}
	
	// info on hmtks inside all the datasets
	printJson_hmtk4datasets(hm.datasetSl);

    /* turn on default decor tracks
     */
    if(!cgiVarExists("noDefaultcontent"))
        {
	printf("'firstdecors':[");
	char *tmp = mysqlGetOnestring("select defaultDecor0 from config");
	if(tmp != NULL)
	    {
	    trigger_decor0 = TRUE;
	    cgiVarSet("decor0", tmp);
	    // decorname,mode
	    tok = strtok(tmp, delimcomma);
	    while(tok != NULL)
		{
		char *name = tok;
		char *mode = strtok(NULL, delimcomma);
		assert(mode != NULL);
		printf("'%s','%s',", name, mode);
		tok = strtok(NULL, delimcomma);
		}
	    free(tmp);
	    }
	tmp = mysqlGetOnestring("select defaultDecor8 from config");
	if(tmp != NULL)
	    {
	    trigger_decor8 = TRUE;
	    cgiVarSet("decor8", tmp);
	    // decorname,mode
	    tok = strtok(tmp, delimcomma);
	    while(tok != NULL)
		{
		char *name = tok;
		char *mode = strtok(NULL, delimcomma);
		assert(mode != NULL);
		printf("'%s','%s',", name, mode);
		tok = strtok(NULL, delimcomma);
		}
	    free(tmp);
	    }
	printf("],");
	}

    // make session id
    session = malloc(10*sizeof(char));
    srand(time(0));
    do {
        i=0;
        while(1)
            {
			int j = 48 + floor(75*(((float)rand())/RAND_MAX));
			if(j<= 57) session[i++]=j;
			else if(j>=65 && j<=90) session[i++]=j;
			else if(j>=97) session[i++]=j;
			if(i == 10) break;
			}
        session[10] = '\0';
	} while(sessionExists(session));
    printf("\"session\":\"%s\",", session);


    // retrieve and return all scaffold info
    sr = mysqlGetResult("select parent,child,childLength from scaffoldInfo");
	assert(sr!=NULL);
    printf("'scaffoldInfo':[");
    while((row=mysql_fetch_row(sr)) != NULL)
        printf("['%s','%s',%s],",row[0],row[1],row[2]);
    printf("],");
    mysql_free_result(sr);

    // load up default scaffold sequences for display
    tmp = mysqlGetOnestring("select defaultScaffold from config");
    // need to count number of scaffold, and make new string (mix of name and length)
    char *old=NULL, *new;
    i = 0; // # of names
    tok = strtok(tmp, delimcomma);
    while(tok!=NULL)
        {
		i++;
		int len = getScaffoldLength(tok);
		assert(len != -1);
		if(old == NULL)
			{
			if(asprintf(&new, "%s,%d,", tok, len)<0) errabort("bae");
			}
		else
			{
			if(asprintf(&new, "%s%s,%d,", old, tok, len)<0) errabort("bae");
			free(old);
			}
		old = new;
		tok = strtok(NULL, delimcomma);
		}
    if(asprintf(&query, "insert into scaffoldRuntime values('%s',%d,%d,'%s')", session, statusId, i, old)<0) errabort("bae");
    mysqlUpdate(query);
    free(query);
    reviveScaffold();
    free(tmp);

    // chromosome on display by default
    printJson_scaffoldRuntimeInfo();

    // greets user
    char *greetings[] = {"Howdy!", "Alo...ha!", "How are you doing today?", 
        "Lieutenant Kerrigan reporting.", "Let's roll!", "Greetings, honored traveler!",
	"@_@ get some sleep...",
	"<img src=images/facai.png>","<img src=images/ja1.png>",
	"<img src=images/ja2.png>",
	"<img src=images/hindi1.png>", "<img src=images/korean1.png>"};
    printf("\"greeting\":\"%s\",", greetings[(int)floor(12*(float)rand()/RAND_MAX)]);
    printf("\"MaxBigbeditem4geneplot\":%d,", MaxBigbeditem4geneplot);
	if(SQUAWK) fputs("done processing isFirst trigger\n", stderr);
    }



/***************************************
    dsp can be determined in a number of ways, exclusive of each other:
    1. submitting gene set/pathway
    2. juxtaposing on a bigbed file
    3. restore status
    4. jump
    5. normal (boundaries given via CGI)
    
    based on "normal", dsp might be altered by following triggers:
    1. image area select (defunc)
    2. zoom out
    3. move

    Operations that will change zoom level will only be provided with dsp view boundaries,
    no number of summary point will be given, 
    an extension from one hmSpan to 3*hmSpan will be attempted.
    Such includes: 
      - zoom in/out
      - change GF
      - jump
    All the other operations will be provided the entire boundary,
    and total number of summary points.
 ***********************************/

if(trigger_genesetview)
	{
	if(SQUAWK) fputs("gene set view mode...\n", stderr);
	/*********************

			 GSV gene set view (previously known as itemlist....)

	 case 1: newly submitted
	 case 2: update existing, in case of add/remove, change part, sort
	 case 3: revive from db, either session restore, or move/zoom/...

	 chrInfo array has to be made!
	 but genes might appear in new scaffold and they will be added to chrInfo array

	 **********************/

	char *session = cgiString("session");
	int statusId = cgiInt("statusId"); // won't change status id

	/* 3 (custom geneset) and 4 (kegg pathway) are not discerned, treated the same... */
	dsp.juxType = 3;

	trigger_newitemlist = cgiVarExists("new");
	trigger_updateitemlist = cgiVarExists("update");

	if(trigger_newitemlist || trigger_updateitemlist)
		{
		/* new-submit and update shares code in deciding exact coord of each item
		   - store in genesetRuntime as new entry
		   - generate and return new statusId
		   - store "session,statusId,itemlistId" in session (insert or update, depends on if session exists)
		   - return new border
		 */
		struct tnode *itemsl = NULL, *t;
		// some numbers to report in case of new-submit
		int redundantItemNum = 0,
			genenum=0,
			coordnum=0,
			invalidnum=0,
			validnum=0;

		if(trigger_newitemlist)
			{
			/* make a neat coord list from cgi param remove redundancy..
			 */
			char *itemlist = cgiString("itemlist");
			if(SQUAWK) fprintf(stderr, "new itemlist: %s", itemlist);
			char delim[] = ",\n";
			char *tok = strtok(itemlist, delim);
			while(tok != NULL)
				{
				if(slLookup(itemsl, tok, 0)) 
					{
					redundantItemNum++; 
					tok = strtok(NULL, delim);
					continue;
					}
				t = malloc(sizeof(struct tnode));
				t->t1 = tok;
				t->next = itemsl;
				itemsl = t;
				tok = strtok(NULL, delim);
				}
			}
		else
			{
			/* update existing itemlist
			   need to build list of item names from db record
			 */
			char *itemlist = getItemlistfromdb(session, statusId);
			char delim[] = ",";
			char *tok = strtok(itemlist, delim);
			while(tok != NULL)
				{
				t = malloc(sizeof(struct tnode));
				t->t1 = tok;
				t->next = itemsl;
				itemsl = t;
				strtok(NULL,delim);strtok(NULL,delim);strtok(NULL,delim);
				strtok(NULL,delim);strtok(NULL,delim);strtok(NULL,delim);strtok(NULL, delim);
				tok = strtok(NULL, delim);
				}
			}

		if(itemsl == NULL)
			{
			printf("\"abort\":\"no recognizable items\"}");
			return 1;
			}

		if(0)
			{
			for(t=itemsl; t!=NULL; t=t->next)
				fprintf(stderr, "%s, ", t->t1);
			fputs("\n", stderr);
			exit(0);
			}

		slReverse(&itemsl);
		char *genestruct = cgiString("gss_opt");
		char *origintype = cgiString("gss_origin");
		int leftlength = cgiInt("gss_up");
		int rightlength = cgiInt("gss_down");
		printf("\"gssparam\":{\"gss_says\":\"%s\",\"gss_opt\":\"%s\",\"gss_origin\":\"%s\",\"gss_up\":%d,\"gss_down\":%d},", cgiString("gss_says"), genestruct, origintype, leftlength, rightlength);

		// make one region for each valid item, skip invalid items
		for(t=itemsl; t!=NULL; t=t->next)
			{
			char *cc = strdup(t->t1);
			struct nnode *sl = itemQueryRefGene(hm.genetracksl, t->t1, NULL, genestruct, origintype, leftlength, rightlength);

			if(sl != NULL)
				{ // we've got a gene
				struct nnode *t;
				for(t=sl; t!=NULL; t=t->next)
					{
					struct region *r = malloc(sizeof(struct region));
					r->chromIdx = t->chrIdx;
					r->bstart = r->dstart = t->start;
					r->bstop = r->dstop = t->stop;
					r->flank5start = t->flank5start;
					r->flank5stop = t->flank5stop;
					r->flank3start = t->flank3start;
					r->flank3stop = t->flank3stop;
					r->name = cc;
					r->isViewStart = FALSE;
					dspAddRegionTail(hm.dsp, r);
					genenum++;
					}
				slFree(sl);
				validnum++;
				}
			else
				{ // now treat it as coord TODO
				int *arr = dissectCoordString(t->t1);
				if(arr==NULL || arr[0]==-1 || arr[1]==-1 || arr[2]==-1) 
					{
					invalidnum++;
					}
				else
					{
					struct region *r = malloc(sizeof(struct region));
					r->chromIdx = arr[0];
					r->bstart = r->dstart = arr[1];
					r->bstop = r->dstop = arr[2];
					// don't use original coord as name as it might contain space and that breaks bedToBigBed
					if(asprintf(&r->name, "%s:%d-%d", chrInfo[r->chromIdx]->name, r->bstart, r->bstop)<0) errabort("bae");
					// see if to add flanking
					if(strcmp(genestruct, "custom") == 0)
						{
					if(arr[3] == 1)
						{
						r->flank5start = (r->bstart>=leftlength) ? r->bstart-leftlength : 0;
						r->flank5stop = r->bstart;
						r->flank3start = r->bstop;
						r->flank3stop = (r->bstop+rightlength>chrInfo[r->chromIdx]->length) ? chrInfo[r->chromIdx]->length : r->bstop+rightlength;
						r->bstart = r->dstart = r->flank5start;
						r->bstop = r->dstop = r->flank3stop;
						}
					else
						{
						r->flank3start = (r->bstart>=rightlength) ? r->bstart-rightlength : 0;
						r->flank3stop = r->bstart;
						r->flank5start = r->bstop;
						r->flank5stop = (r->bstop+leftlength>chrInfo[r->chromIdx]->length) ? chrInfo[r->chromIdx]->length : r->bstop+leftlength;
						r->bstart = r->dstart = r->flank3start;
						r->bstop = r->dstop = r->flank5stop;
						}
					}
					else
						{
					r->flank5start=r->flank5stop=r->flank3start=r->flank3stop=-1;
					}

					r->isViewStart = FALSE;
							dspAddRegionTail(hm.dsp, r);
							free(arr);
					coordnum++;
					validnum++;
					}
				}
			}
		slFree(itemsl);
		if(validnum == 0)
			{
			printf("\"abort\":\"No recognizable items\"}");
			return 0;
			}

		if(cgiVarExists("generatebigbed"))
			{
			/*************************************
			   execution flow diverges here
			   generating bigBed file request is handled here
			   exit when done
			*************************************/
			int bid = 1;
			srand(time(0));
			int rn=rand();
			char *bedfile, *sortfile;
			if(asprintf(&bedfile, "%s/%s.%d", WWWT, session, rn)<0) errabort("bae");
			if(asprintf(&sortfile, "%s/%s.%d.s", WWWT, session, rn)<0) errabort("bae");
			FILE *fout = fopen(bedfile, "w");
			if(fout == NULL)
				errabort("cannot open temp bed file");
			struct region *r;
			for(r=dsp.head; r!=NULL; r=r->next)
				fprintf(fout, "%s\t%d\t%d\t%s\t%d\t%c\n", chrInfo[r->chromIdx]->name, r->bstart, r->bstop, r->name, bid++, strMayGetgeneStrand(genetracksl, r->name));
			fclose(fout);

			char *command;
			if(asprintf(&command, "sort -k1,1 -k2,2n %s > %s", bedfile, sortfile)<0) errabort("bae");
			if(system(command) == -1)
				errabort("cannot do unix sort");
			unlink(bedfile);
			free(command);

			if(asprintf(&command, "%s/bgzip %s", BINdir, sortfile)<0) errabort("bae");
			if(system(command) == -1)
				errabort("cannot run bgzip");
			free(command);
			if(asprintf(&command, "%s/tabix -p bed %s.gz", BINdir, sortfile)<0) errabort("bae");
			if(system(command) == -1)
				errabort("cannot run tabix");
			free(command);

			printf("'rand':%d,'itemnum':%d}", rn,bid-1);
			done();
			return 1;
			}


		/* itemlist sorting functions goes here 
		TODO revise the sorting code with nsortItem
		but it won't work with coordinate sort
		remove coordinate sort?
		*/
		if(cgiVarExists("sortby"))
			{
			// genenum is number of items
			char *sortby = cgiString("sortby");
			int i;
			struct region *r = dsp.head;
			// array of pointer doesn't work for qsort???
			struct region itemarr[genenum];
			for(i=0; i<genenum; i++)
				{
				assert(r != NULL);
				itemarr[i].chromIdx = r->chromIdx;
				itemarr[i].bstart = r->bstart;
				itemarr[i].bstop = r->bstop;
				itemarr[i].dstart = r->dstart;
				itemarr[i].dstop = r->dstop;
				itemarr[i].name = strdup(r->name);
				itemarr[i].isViewStart = FALSE;
				r = r->next;
				}

			// average score from a numerical track
			if(strcmp(sortby, "tkmeanAsc")==0 || strcmp(sortby, "tkmeanDesc")==0)
				{
				// each item got one summary point, as average signal over that region...
				dsp.usedSummaryNumber = genenum;
				r = dsp.head;
				for(i=0; i<genenum; i++)
					{
					r->summarySize = 1;
					r = r->next;
					}
				// if is custom, will be url, else, need to compose file path
				char *tmp1=cgiString("datatk");
				char *tmp2=cgiString("datatkft");
				int ft=strMayPositiveInt(tmp2);
				if(ft==-1)
					{
					printf("'abort':'wrong filetype for numerical track'}");
					fprintf(stderr, "gene set sort: wrong file type (%s)\n", tmp2);
					return 1;
					}
				if(ft!=FT_hmtk_c && ft!=FT_hmtk_n && ft!=FT_qdecor_n)
					{
					printf("'alert':'data track not of quantitative','gpabort':1}");
					return 1;
					}
				char *urlpath=makefilepath(tmp1, ft);
				double *data = tabixQuery_bedgraph_dsp(hm.dsp, urlpath);
				for(i=0; i<genenum; i++)
					{
					itemarr[i].fvalue = data[i];
					}
				free(data);
				if(strcmp(sortby, "tkmeanAsc") == 0)
					qsort(itemarr, (size_t)genenum, sizeof(struct region), itemlistsort_tkmeanAsc);
				else
					qsort(itemarr, (size_t)genenum, sizeof(struct region), itemlistsort_tkmeanDesc);
				}
			else if(strcmp(sortby, "lenAsc") == 0)
				{
				qsort(itemarr, (size_t)genenum, sizeof(struct region), itemlistsort_lenAsc);
				}
			else if(strcmp(sortby, "lenDesc") == 0)
				{
				qsort(itemarr, (size_t)genenum, sizeof(struct region), itemlistsort_lenDesc);
				}
			else if(strcmp(sortby, "coord") == 0)
				{
				qsort(itemarr, (size_t)genenum, sizeof(struct region), itemlistsort_coord);
				}
			else
				{
				errabort("unrecognized itemlist sortby criteria");
				}
			if(0)
				{
				fputs("check sorted itemlist:\n", stderr);
				for(i=0; i<genenum; i++)
					{
					int start = itemarr[i].bstart;
					int stop = itemarr[i].bstop;
					fprintf(stderr, "%s %s %d %d, len %d\n", itemarr[i].name, chrInfo[itemarr[i].chromIdx]->name, start, stop, stop-start);
					}
				}
			r = dsp.head;
			for(i=0; i<genenum; i++)
				{
				// why so much trouble
				r->chromIdx = itemarr[i].chromIdx;
				r->dstart = itemarr[i].dstart;
				r->dstop = itemarr[i].dstop;
				r->bstart = itemarr[i].bstart;
				r->bstop = itemarr[i].bstop;
				r->name = strdup(itemarr[i].name);
				r->isViewStart = FALSE;
				r = r->next;
				}
			}

		// only do alert for newly submitted itemlist
		if(trigger_newitemlist)
			{
			printf("'alert':'");
			if(coordnum == 0)
				printf("%d genes added", genenum);
			else
				printf("%d genes and %d coordinates added", genenum, coordnum);
			if(invalidnum > 0)
				printf(", %d unrecognized items discarded", invalidnum);
			if(redundantItemNum > 0)
				printf(", %d redundant items skipped", redundantItemNum);
			printf("',");
			}

			/* border */
		printf("\"border\":[\"%s\",%d,\"%s\",%d],", dsp.head->name,dsp.head->bstart,dsp.tail->name,dsp.tail->bstop);
		/* determine view start
		   all the rest regions has been set to FALSE
		 */
		dsp.head->isViewStart = TRUE;
		dsp.head->viewStartCoord = dsp.head->dstart;

			
		// make long string for itemlist to be stored in genesetRuntime table, very inefficient
		char *old = "", *new;
		struct region *r;
		for(r=dsp.head; r!=NULL; r=r->next)
			{
			if(asprintf(&new, "%s%s,%d,%d,%d,%d,%d,%d,%d,", old,r->name,r->chromIdx,r->bstart,r->bstop,r->flank5start,r->flank5stop,r->flank3start,r->flank3stop)<0) errabort("bae");
			if(strcmp(old,"")!=0)
				free(old);
			old = new;
			}
		/* store itemlist into db
		   first remove what ever exists in genesetRuntime by session and status
		   then insert new itemlist string
		 */
		genesetRuntime_insert(session, statusId, old);
		free(old);

		if(SQUAWK) fputs("itemlist stored into db\n", Squawk);

			computeEntireLength_itemlist(hm.dsp);
		computeSummarySize_itemlist(hm.dsp);
		}
	else
		{
		/*************************
		   fetch neat item list string from db using session
		   load all items as a big regionSl by order
		   fix dsp.head/tail on two ends of the SL
		   then try to determine real displayed region by sliding on this SL

		   instead of chromsome name, item names are passed as dsp args,
		   (because item names are not redundant)

		   in case of using displayedRegionParamPrecise, summary size will be given for each item
		   special args:
			- allrss
		 *************************/
		if(!dspRestoreByCleanItemlist(hm.dsp, session, statusId))
			{
				printf("\"abort\":\"sorry, gene set information could not be retrieved from database\"}");
			return 1;
			}

		if(SQUAWK) fputs("itemlist fetched from db, regionSl made...\n", Squawk);

		// so all items have been loaded, find previous displayed boundary from CGI param
		char *startItem = cgiString(StartChrom_cgi);
		int startCoord = cgiInt(StartCoord_cgi);
		char *stopItem = cgiString(StopChrom_cgi);
		int stopCoord = cgiInt(StopCoord_cgi);
		if(SQUAWK) fprintf(Squawk, "itemlist=on coord param: %s %d %s %d\n", startItem, startCoord, stopItem, stopCoord);
		trimRegionSl_itemlist(hm.dsp, startItem, startCoord, stopItem, stopCoord);

		// dsp adjustments
		if(cgiVarExists("allrss"))
			{
			if(SQUAWK) fputs("using precomputed summary size for all regions...\n", Squawk);
			/* forgot to compute dsp.usedSummaryNumber
			   2011/5/12 CSHL
			 */
			dsp.usedSummaryNumber = 0;
			dsp.tail->next = NULL;
			// assign given summary size to each item
			char delim[] = ",";
			char *allrss = cgiString("allrss");
			char *tok;
			tok = strtok(allrss, delim); assert(tok != NULL);
			// first item
			struct region *r = dsp.head;
			assert((r->summarySize=strMayPositiveInt(tok))!=-1);
			dsp.usedSummaryNumber += r->summarySize;
			for(r=r->next; r!=NULL; r=r->next) // rest of items
				{
			tok = strtok(NULL, delim); assert(tok != NULL);
			assert((r->summarySize=strMayPositiveInt(tok))!=-1);
			dsp.usedSummaryNumber += r->summarySize;
			}
			}
		else if(trigger_move)
			{
			// TODO don't need to tell from param if in basepair level??
				char direction = cgiString("move")[0];
				int mDistance = cgiInt("distance");
				int mSummarySize = cgiInt("summarySize");
			if(SQUAWK) fprintf(Squawk, "for moving (direction: %c mDist: %d mSumm: %d)...\n", direction, mDistance, mSummarySize);
			long remainingDist = 0;
			if(direction == 'l')
				{
			// newly exposed on left
			dsp.head->dstop = dsp.head->dstart;
			dsp.tail = dsp.head;
					remainingDist = moveBoundary_list_which(hm.dsp, 'h', 'l', mDistance);
			if(remainingDist != 0)
				{
				mSummarySize = (int)(mSummarySize * (1-(float)remainingDist/mDistance));
				}
			}
			else if(direction == 'r')
				{
				// newly exposed on right
			dsp.tail->dstart = dsp.tail->dstop;
			dsp.head = dsp.tail;
					remainingDist = moveBoundary_list_which(hm.dsp, 't', 'r', mDistance);
			if(remainingDist != 0)
				{
				mSummarySize = (int)(mSummarySize * (1-(float)remainingDist/mDistance));
				}
			}
				else
				{
			errabort("unknown moving direction");
			}
			dsp.head->prev = NULL;
			dsp.tail->next = NULL;
			computeEntireLength(hm.dsp);
			// not calling computeEntireLength_itemlist as need to do for entire list
			computeSummarySize(hm.dsp, mSummarySize);
			}
		else
			{
			computeEntireLength_itemlist(hm.dsp);
			if(trigger_imgAreaSelect)
				{
				// isViewStart is set in makeDspWing_itemlist()...
				makeDspWing_itemlist(hm.dsp);
				}
			else if(trigger_zoom)
				{
				if(SQUAWK) fputs("zoom out:\n", Squawk);
			double f = cgiDouble("zoom");
					moveBoundary_list_which(hm.dsp, 'h', 'l', (long)(dsp.entireLength*f));
					moveBoundary_list_which(hm.dsp, 't', 'r', (long)(dsp.entireLength*f));
				makeDspWing_itemlist(hm.dsp);
				}
			else
				{
				computeSummarySize(hm.dsp, cgiInt("sptotalnum"));
				}
			}
		if(0) 
			{
			fprintf(stderr, "usedSummaryNumber: %d\n", dsp.usedSummaryNumber);
			showRegionSl(hm.dsp);
			}
		}
	}
else if(trigger_restoreStatus)
    {
    /**********************************
             SESS restore status
     **********************************/
	if(SQUAWK) fprintf(stderr, "restoring status (%s %d)...\n", session, statusId);

    struct tnode *voidcustomtrack = NULL; // t1: track name, t2: url

    /* run mode other than genome:
       if juxtaposing geneset/pathway,
         extract itemlist by running additional sql query,
	 flip trigger_newitemlist
     */
    char *query, **row;
	MYSQL_RES *sr;

    /* restore scaffold runtime before doing anything else */
    if(asprintf(&query, "select scaffoldCount,scaffoldNames from session where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
    sr = mysqlGetResult(query);
	assert(sr!=NULL);
    free(query);
    row = mysql_fetch_row(sr);
    assert(row[0] != NULL);
    assert(row[1] != NULL);
    char *tmp1 = strdup(row[0]);
    char *tmp2 = strdup(row[1]);
    mysql_free_result(sr);

    if(asprintf(&query, "delete from scaffoldRuntime where session='%s' and statusId=%d", session, statusId)<0) errabort("bae");
    mysqlUpdate(query);
    free(query);
    if(asprintf(&query, "insert into scaffoldRuntime values('%s',%d,%s,'%s')", session, statusId, tmp1, tmp2)<0) errabort("bae");
    mysqlUpdate(query);
    free(query);
    reviveScaffold();
    free(tmp1); free(tmp2);

    if(asprintf(&query, "select juxType from session where session=\"%s\" and statusId=%d", session, statusId)<0) errabort("bae");
	dsp.juxType=mysqlGetPositiveInteger(query);
    free(query);

    // flip trigger in case of geneset/pathway
    trigger_newitemlist = (dsp.juxType==3 || dsp.juxType==4);

    if(asprintf(&query, "select * from session where session=\"%s\" and statusId=%d", session, statusId)<0) errabort("bae");
    sr = mysqlGetResult(query);
	assert(sr!=NULL);
    free(query);
    if(sr==NULL || (row=mysql_fetch_row(sr))==NULL)
        {
		printf("'abort':'Cannot restore status: session or status not found'}");
		return 0;
		}

    /* array id in sql result, 
       but some are not used, so comment them out...
       problem on this caused an embarrassing server error during live demo on NAG presentation 4/28/2011
     */
    //int sid_session=0, sid_statusId=1, sid_statusNote=2, sid_clientCtrl=3, 
    int sid_serverTrack=4, sid_customTrack=5, sid_customTrackAttr=6, 
	sid_juxWhat=8, sid_juxNote=9,
	sid_dspStat=10, sid_correlation=11, 
	sid_itemlist=12, 
	sid_custmd=13, sid_mdconshow=14, sid_dataset=15, sid_pairwisecomp=16,
	sid_decor0=17,sid_decor1=18,sid_decor8=19, sid_decor5=21,
	sid_decor9=22, sid_decor10=23,
	//sid_decor4=20,
	sid_decorRenderingParams=24, sid_qtc=25, sid_gssparam=26, sid_stickynote=27;

    char *itemliststring = NULL;

    /* native hmtk tracks */
    char delim[] = ",";
    char *tok;
    struct track *tt;
    if(row[sid_serverTrack] != NULL)
        {
        tok=strtok(row[sid_serverTrack], delim); assert(tok!=NULL);
        while(tok != NULL)
            {
            tt = malloc(sizeof(struct track));
            if(asprintf(&tt->name, "%s", tok)<0) errabort("bae");
	    	tt->data = NULL;
            tt->ft=FT_hmtk_n;
            tt->next = hm.trackSl;
            hm.trackSl = tt;
			tok = strtok(NULL, delim);
			}
        }
    /* custom hmtk tracks */
    printf("'customhmtklabel':{");
    if(row[sid_customTrack] != NULL)
        {
        tok=strtok(row[sid_customTrack], delim); assert(tok!=NULL);
        while(tok != NULL)
            {
	    // name, label, url
	    char *tkname = tok;
	    char *label = strtok(NULL, delim);
	    char *url = strtok(NULL, delim);
	    if(label==NULL || url==NULL)
	        {
			struct tnode *tmp = malloc(sizeof(struct tnode));
			tmp->t2 = strdup(tkname);
			tmp->t1 = strdup(tkname);
			tmp->next = voidcustomtrack;
			voidcustomtrack = tmp;
			}
	    else
	        {
			tt = malloc(sizeof(struct track));
			tt->urlpath = strdup(url);
			tt->name = strdup(tkname);
			tt->data = NULL;
			tt->ft=FT_hmtk_c;
			tt->next = hm.trackSl;
			hm.trackSl = tt;
			printf("'%s':'%s',", tkname, label);
			}
	    tok = strtok(NULL, delim);
	    }
	}
    printf("},");
    /* custom track attribute 
       will be printed out later, after track data has been made & sent to client
     */
    if(row[sid_customTrackAttr] != NULL)
        {
        printf("\"customTrackAttr\":{%s},", row[sid_customTrackAttr]);
		}
    /* juxtaposition type */
    printf("\"juxtaposition\":{\"type\":%d,\"what\":\"%s\",\"note\":\"%s\"},", 
    		dsp.juxType, 
		row[sid_juxWhat], 
		row[sid_juxNote]);
    // dsp.gf will carry bigbed file path/url for juxtaposition
	if(dsp.juxType!=0)
		{
		if(dsp.juxType == 1)
			{
			dsp.gf=makefilepath(row[sid_juxWhat], FT_bigbed_n);
			assert((dsp.tabix=tabixOpen(dsp.gf))!=NULL);
			}
		else
			{
			dsp.gf = strdup(row[sid_juxWhat]);
			}
		}

    /* make DSP
     */
    tok = strtok(row[sid_dspStat], delim); assert(tok!=NULL);
    char *startChrstr = strdup(tok); 
    tok = strtok(NULL, delim); assert(tok!=NULL);
    int startCoord = strMayPositiveInt(tok);
	assert(startCoord!=-1);
    tok = strtok(NULL, delim); assert(tok!=NULL);
    char *stopChrstr = strdup(tok);
    tok = strtok(NULL, delim); assert(tok!=NULL);
    int stopCoord = strMayPositiveInt(tok);
	assert(stopCoord!=-1);

    /* decors */
    if(row[sid_decor0] != NULL)
		hm.decor0 = parseParamDecor0(row[sid_decor0]);
    if(row[sid_decor8] != NULL)
		hm.decor8 = parseParamDecor8(row[sid_decor8]);
    if(row[sid_decor1] != NULL)
		hm.decor1 = parseParamDecor1(row[sid_decor1]);
    if(row[sid_decor5] != NULL)
		hm.decor5 = parseParamDecor5(row[sid_decor5]);
    if(row[sid_decor9] != NULL)
		hm.decor9 = parseParamDecor9(row[sid_decor9]);
    if(row[sid_decor10] != NULL)
		hm.decor10 = parseParamDecor10(row[sid_decor10]);

    /* corr */
    if(row[sid_correlation] != NULL)
		{
		//trigger_correlation = TRUE;
		tok = strtok(row[sid_correlation], delim); assert(tok!=NULL); // file type
		printf("\"correlation\":[%s,", tok);
		tok = strtok(NULL, delim); assert(tok!=NULL); // where
		printf("%s,", tok);
		tok = strtok(NULL, delim); assert(tok!=NULL); // name
		printf("\"%s\"],", tok);
		}

    /* custom metadata */
    if(row[sid_custmd] != NULL)
	printf("\"custmd\":{%s},", row[sid_custmd]);
    /* metadata category onshow */
    if(row[sid_mdconshow] != NULL)
	printf("\"mdconshow\":[%s],", row[sid_mdconshow]);
    /* pairwise comparison */
    if(row[sid_pairwisecomp] != NULL)
        printf("\"pairwisecomp\":%s,", row[sid_pairwisecomp]);
    /* decor rendering param */
    if(row[sid_decorRenderingParams] != NULL)
        printf("\"decorRenderingParams\":%s,", row[sid_decorRenderingParams]);
    /* qtc, insanely long json string */
    if(row[sid_qtc] != NULL)
        printf("\"qtc\":%s,", row[sid_qtc]);
    /* gssparam, short json string */
    if(row[sid_gssparam] != NULL)
        printf("\"gssparam\":%s,", row[sid_gssparam]);
    /* sticky note */
    if(row[sid_stickynote] != NULL)
        {
		printf("\"stickynote\":[");
		char delim2[] = "|";
		tok = strtok(row[sid_stickynote], delim2);
		while(tok != NULL)
			{
			printf("[%s,", tok);
			tok = strtok(NULL, delim2); assert(tok!=NULL);
			printf("%s,", tok);
			tok = strtok(NULL, delim2); assert(tok!=NULL);
			printf("\"%s\"],", tok);
			tok = strtok(NULL, delim2);
			}
		printf("],");
		}
        
    /* if running gene set view */
    if(trigger_newitemlist)
	itemliststring = strdup(row[sid_itemlist]); // to be inserted to genesetRuntime table

    mysql_free_result(sr);

    /* dataset */
    printf("'dataset':[");
    tok = strtok(row[sid_dataset], delim);
    struct slNode *ttt;
    while(tok != NULL)
        {
		ttt = malloc(sizeof(struct slNode));
		ttt->name=strdup(tok);
		ttt->next = hm.datasetSl;
		hm.datasetSl = ttt;
		printf("'%s',", tok);
		tok = strtok(NULL, delim);
		}
    printf("],");

	printJson_hmtk4datasets(hm.datasetSl);

    if(trigger_newitemlist)
        {
		trigger_genesetview = TRUE;
		genesetRuntime_insert(session, statusId, itemliststring);

		if(!dspRestoreByCleanItemlist(hm.dsp, session, statusId))
			{
			printf("\"abort\":\"Error parsing itemlist string, please send the session ID to developer, sorry!!\"}");
			return 0;
			}
		/* before trimming dsp
		   - print out border
		   - print out entire list for entire.itemlist (drawing minichrcanvas)
		 */
		printf("\"border\":[\"%s\",%d,\"%s\",%d],", dsp.head->name,dsp.head->bstart,dsp.tail->name,dsp.tail->bstop);
		struct region *r;
		printf("\"entireItemlist\":[");
		for(r=dsp.head; r!=NULL; r=r->next)
			printf("[\"%s\",\"%s\",%d,%d],", r->name, chrInfo[r->chromIdx]->name,r->bstart, r->bstop);
		printf("],");
		// trim region list, startChrstr/stopChrstr are item names
		trimRegionSl_itemlist(hm.dsp, startChrstr, startCoord, stopChrstr, stopCoord);
		makeDspWing_itemlist(hm.dsp);
		}
    else
        {
		/* not in itemlist mode */
        int startChr = strMayChrID(startChrstr);
		assert(startChr!=-1);
        int stopChr = strMayChrID(stopChrstr);
		assert(stopChr!=-1);
        makeBorder(hm.dsp);
        printf("\"border\":[\"%s\",%d,\"%s\",%d],", chrInfo[leftBorder.chromIdx]->name, leftBorder.coord, chrInfo[rightBorder.chromIdx]->name, rightBorder.coord);
        setDspBoundary(hm.dsp, startChr, startCoord, stopChr, stopCoord);
		computeEntireLength(hm.dsp);
		if(dsp.juxType == 0)
				finalizeDsp_genome(hm.dsp);
		else 
				finalizeDsp_gf(hm.dsp);
		}

    if(voidcustomtrack != NULL)
        {
		struct tnode *tmp;
		printf("\"voidcustomtrack\":[");
		for(tmp=voidcustomtrack; tmp!=NULL; tmp=tmp->next)
			printf("[\"%s\",\"%s\"],", tmp->t1, tmp->t2);
		printf("],");
		}

    // chromosome on display by default
    printJson_scaffoldRuntimeInfo();

    if(SQUAWK) fputs("semi-restored from past status\n", Squawk);
    }
else
    {
    /*****************************************

                "NORmal"
 	   dsp determination operations

     *****************************************/
    if(SQUAWK) fputs("normal dsp...\n", stderr);
    if(cgiVarExists(GFType_cgi))
		{
		char *gf = cgiString(GFType_cgi);
		if(cgiVarExists("gfiscustom")) 
			{
			// custom bigbed, dsp.gf will be url
            dsp.gf = gf;
	    	dsp.juxType = 2;
			dsp.juxFt=FT_bigbed_c; // update here if other file types are used
			dsp.tabix = tabixOpen(gf);
			if(dsp.tabix==NULL)
				{
				// fall back
				fprintf(stderr, "!!! juxtapose on custom tabix but failed to open: %s\n", gf);
				dsp.gf=GENOME; 
				dsp.juxType=0;
				}
	    	}
		else
	    	{
			if(strcmp(gf, GENOME) == 0)
				{
				dsp.gf = GENOME;
				dsp.juxType = 0;
				dsp.juxFt=0;
				}
			else
				{
				dsp.juxType = 1;
				dsp.juxFt=FT_bigbed_n;
				dsp.gf=makefilepath(gf, FT_bigbed_n);
				dsp.tabix=tabixOpen(dsp.gf);
				if(dsp.tabix==NULL)
					{
					fprintf(stderr, "!!! juxtapose on native tabix but failed to open: %s\n", gf);
					dsp.gf=GENOME;
					dsp.juxType=0;
					dsp.juxFt=0;
					}
				}
			}
		}
    else
        {
		/* this case is only supposed to be on page load up */
		dsp.gf = GENOME;
		dsp.juxType = 0;
		}
	if(SQUAWK) fprintf(stderr, "juxType: %d gf: %s\n", dsp.juxType, dsp.gf);

	assert(lastChrIdx!=-1);
	makeBorder(hm.dsp);
	/* in case of juxtaposition,
	itemsl data for entire chromosomes are fetched and cached in dsp.chritemsl for the border chrs
	*/

    /* ordinary procedure to determine DSP
       first check whether to jump
       if not, get parameter from CGI
       if not, set boundary to default location
     */

    boolean notJumped = TRUE;
    int startChr=-1, stopChr=-1, startCoord=0, stopCoord=0;
    if(trigger_jump)
		{
		// JUMP
		if(cgiVarExists("jumpchr"))
			{
			// view an entire chr by <select>
			if(SQUAWK) fputs("view entire chr\n", stderr);
			if((startChr=strMayChrID(cgiString("jumpchr"))) == -1)
				{
				printf("\"abort\":\"invalid chromosome name\"}");
				return 0;
				}
			startCoord = 0;
			stopCoord = chrInfo[startChr]->length;
			}
		else if(cgiVarExists("jumppos"))
			{
			// input is in form of "chr:start-stop [strand]", and to be handled by a common routine
			//fprintf(stderr, "%s\n", cgiString("jumppos"));
			if(SQUAWK) fprintf(stderr, "relocate to %s\n", cgiString("jumppos"));
			int *arr = dissectCoordString(cgiString("jumppos"));
			if(arr == NULL)
				{
				printf("\"abort\":\"invalid genomic coordinate\"}");
				return 0;
				}
			if(arr[0] == -1)
				{
				printf("\"abort\":\"wrong chromosome name\"}");
				return 0;
				}
			if(arr[1] == -1)
				{
				printf("\"abort\":\"invalid start coordinate\"}");
				return 0;
				}
			if(arr[2] == -1)
				{
				printf("\"abort\":\"invalid stop coordinate\"}");
				return 0;
				}
			if(arr[1] >= arr[2])
				{
				printf("\"abort\":\"start coordinate must precede stop coordinate\"}");
				return 0;
				}
			startChr = arr[0];
			startCoord = arr[1];
			stopCoord = arr[2];
			/* FIXME: hard-coded stuff
			   at finest zoomin level, each basepair spans 10bp, so hmSpan will take hmSpan/10 basepairs
			 */
			int L = stopCoord-startCoord;
			if(L < hmSpan/10)
				{
				if(startCoord+hmSpan/10 < chrInfo[arr[0]]->length)
					{
					stopCoord = startCoord+79;
					}
				else
					{
					stopCoord = chrInfo[arr[0]]->length-1;
					startCoord = stopCoord-79;
					}
				}
			free(arr);
			}
		else if(cgiVarExists("jumppos2"))
			{
			if(SQUAWK) fprintf(stderr, "relocate to %s\n", cgiString("jumppos2"));
			// now it is in form of chr1,start1,chr2,start2
			char delim[] = ",";
			char *tok;
			assert((tok=strtok(cgiString("jumppos2"), delim)) != NULL);
			assert(tok != NULL);
			startChr = strMayChrID(tok);
			if(startChr == -1)
				{
				/* new scaffold sequence, insert into chrInfo */
				scaffoldAddnew(tok);
				startChr = lastChrIdx;
				}
			assert((tok=strtok(NULL, delim)) != NULL);
			assert((startCoord=strMayPositiveInt(tok))!=-1);
			assert((tok=strtok(NULL, delim)) != NULL);
			stopChr = strMayChrID(tok);
			if(stopChr == -1)
				{
				scaffoldAddnew(tok);
				stopChr = lastChrIdx;
				}
			assert((tok=strtok(NULL, delim)) != NULL);
			assert((stopCoord=strMayPositiveInt(tok))!=-1);
			}
		else if (cgiVarExists("jumpgene"))
			{
			/* query for only one gene struct
			   must handle case of novel scaffold sequence here
			   itemQueryRefGene will append new scaffold at the end of chrInfo
			   so lastChrIdx will update
			   this change shall be reported to JS
			 */
			if(SQUAWK) fputs("relocate to a gene\n", stderr);
			int lastChrIdx_old = lastChrIdx;
			struct nnode *re = itemQueryRefGene(hm.genetracksl, cgiString("jumpgene"), NULL, "genebody", "", 0,0);
			if(re != NULL)
				{
				if(SQUAWK)
					fprintf(stderr, "jumpgene: %s %d %d\n", cgiString("jumpgene"), re->start, re->stop);
				startChr = re->chrIdx;
				startCoord = re->start;
				stopCoord = re->stop;
				slFree(re);
				}
			else
				{
				printf("\"abort\":\"unrecognizable gene name\"}");
				return 0;
				}
			if(lastChrIdx_old != lastChrIdx)
				{
				assert(lastChrIdx == lastChrIdx_old+1);
				printf("'newscaffold':['%s',%u],", chrInfo[lastChrIdx]->name, chrInfo[lastChrIdx]->length);
				}
			}
		notJumped = FALSE;
		setDspBoundary(hm.dsp, startChr, startCoord, stopChr==-1 ? startChr : stopChr, stopCoord);
		if(dsp.juxType == 0)
			finalizeDsp_genome(hm.dsp);
		else
			finalizeDsp_gf(hm.dsp);
		}
	if(notJumped)
		{
		if(SQUAWK) fputs("not jumping...\n", Squawk);

		if(trigger_move)
			{
			if(SQUAWK) fputs("Moving...\n", Squawk);

			makeDspBoundaryFromCgi(hm.dsp);

			/******************************
			   MOVE
			   only fetch data for newly exposed region
			   make a region to start with
			   the region will covers the point where new region will be made on one of its side

			   |<<<<<<left new<<<<<<|======old======|>>>>>>right new>>>>>>|

			   if atbplevel, only use mDistance, mSummarySize is of no use then
			 ******************************/
			dsp.atbplevel = cgiVarExists("atbplevel");
			char direction = cgiString("move")[0];
			int mDistance = cgiInt("distance");
			int mSummarySize = cgiInt("summarySize");
			if(SQUAWK) fprintf(Squawk, "need to move %d (%d)\n", mDistance, mSummarySize);
			struct region *r = malloc(sizeof(struct region)); // dsp.head and dsp.tail will be set to this region
			if(dsp.juxType == 0)
				{
				if(direction == 'l')
					{
					r->chromIdx = dsp.start->chromIdx;
					r->dstart = r->dstop = dsp.start->coord;
					}
				else
					{
					r->chromIdx = dsp.stop->chromIdx;
					r->dstart = r->dstop = dsp.stop->coord;
					}
				r->bstart = 0;
				r->bstop = chrInfo[r->chromIdx]->length;
				}
			else
				{
				/* juxtaposition
				form a region from left/right of initial point
			    chromosome might not contain genomic feature of this kind, so use loop

				the operations dealing with left/right moving is really symmetrical
				but it seems impossible to be integrated
				 */
				struct beditem *itemsl=NULL;
				struct chritemsl *ci;
				if(direction == 'l')
					{
					/* look to left, for each chr, fetch bed items from an interval,
					   interval start is always 0, stop is variable
					 */
					int lookChrIdx = dsp.start->chromIdx;
					while(itemsl == NULL)
						{
						if((ci=chritemsl_searchidx(hm.dsp, lookChrIdx))==NULL)
							{
							struct beditem *sl2=tabixQuery_regioncoord(dsp.tabix, dsp.juxFt, chrInfo[lookChrIdx]->name, 0, chrInfo[lookChrIdx]->length);
							if(sl2!=NULL)
								{
								itemsl=(struct beditem *)beditemsort_stopDsc((struct genericItem *)sl2);
								chritemslAppend(hm.dsp, lookChrIdx, itemsl);
								}
							}
						else
							{
							assert(ci->itemsl!=NULL);
							itemsl=(struct beditem *)beditemsort_stopDsc((struct genericItem *)ci->itemsl);
							ci->itemsl=itemsl;
							}
						if(itemsl == NULL)
							{
							if(lookChrIdx==0) break;
							lookChrIdx--;
							}
						else
							{
							/* in case the itemsl is from same chr as dsp.start,
							need to check if there's any item exists on the upstream of dsp.start
							those will be used to create the region
							*/
							if(lookChrIdx==dsp.start->chromIdx)
								{
								for(; itemsl!=NULL; itemsl=itemsl->next)
									{
									if(itemsl->start < dsp.start->coord)
										break;
									}
								if(itemsl==NULL)
									{
									if(lookChrIdx==0) break;
									lookChrIdx--;
									}
								}
							}
						}
					if(itemsl==NULL)
						{
						/* cannot find anything on the upstream of dsp.start
						including all chrs on dsp.start chr's "upstream"
						must reset dsp.start at right-most item from left border chr
						and generate a region
						*/
						if(SQUAWK)
							fprintf(stderr, "! juxtaposition trying to set first region for moving to left, no items could be found from chrs before %s (dsp.start), resetting dsp.start to left border...\n", chrInfo[dsp.start->chromIdx]->name);
						ci=chritemsl_searchidx(hm.dsp, leftBorder.chromIdx);
						assert(ci!=NULL);
						assert(ci->itemsl!=NULL);
						itemsl=(struct beditem *)beditemsort_stopDsc((struct genericItem *)ci->itemsl);
						ci->itemsl=itemsl;
						dsp.start->chromIdx=dsp.stop->chromIdx=leftBorder.chromIdx;
						dsp.start->coord=dsp.stop->coord=itemsl->stop;
						lookChrIdx=leftBorder.chromIdx;
						}
					// use the first item in itemsl to form the region
					r->chromIdx = lookChrIdx;
					r->bstart = itemsl->start;
					r->bstop = itemsl->stop;
					r->dstart = r->dstop = (itemsl->stop < dsp.start->coord) ? itemsl->stop : dsp.start->coord;
					// extend this region using overlapping bed items in itemsl
					for(itemsl=itemsl->next; itemsl!=NULL; itemsl=itemsl->next)
						{
						if(itemsl->stop >= r->bstart && itemsl->start < r->bstart)
							r->bstart = itemsl->start;
						else
							break;
						}
					}
				else
					{
					/* look to right, for each chr, fetch bed items from an interval,
					   interval stop is always chromosome end, start is variable
					 */
					int lookChrIdx = dsp.stop->chromIdx;
					while(itemsl == NULL)
						{
						if((ci=chritemsl_searchidx(hm.dsp, lookChrIdx))==NULL)
							{
							struct beditem *sl2=tabixQuery_regioncoord(dsp.tabix, dsp.juxFt, chrInfo[lookChrIdx]->name, 0, chrInfo[lookChrIdx]->length);
							if(sl2!=NULL)
								{
								itemsl=(struct beditem *)beditemsort_startAsc((struct genericItem *)sl2);
								chritemslAppend(hm.dsp, lookChrIdx, itemsl);
								}
							}
						else
							{
							assert(ci->itemsl!=NULL);
							itemsl=(struct beditem *)beditemsort_startAsc((struct genericItem *)ci->itemsl);
							ci->itemsl=itemsl;
							}
						if(itemsl==NULL)
							{
							if(lookChrIdx == lastChrIdx) 
								break;
							lookChrIdx++;
							}
						else
							{
							/* in case the itemsl is from same chr as dsp.stop,
							need to check if there's any item exists on the downstream of dsp.stop
							those will be used to create the region
							*/
							if(lookChrIdx==dsp.stop->chromIdx)
								{
								for(; itemsl!=NULL; itemsl=itemsl->next)
									{
									if(itemsl->stop > dsp.stop->coord)
										break;
									}
								if(itemsl==NULL)
									{
									if(lookChrIdx==lastChrIdx)
										break;
									lookChrIdx++;
									}
								}
							}
						}
					if(itemsl == NULL)
						{
						/* cannot find anything on the downstream of dsp.stop
						including all chrs on dsp.stop chr's "downstream"
						must reset dsp.stop at left-most item from right border chr
						and generate a region
						*/
						if(SQUAWK)
							fprintf(stderr, "! juxtaposition trying to set first region for moving to right, no items could be found from chrs after %s (dsp.stop), resetting dsp.stop to right border...\n", chrInfo[dsp.stop->chromIdx]->name);
						ci=chritemsl_searchidx(hm.dsp, rightBorder.chromIdx);
						assert(ci!=NULL);
						assert(ci->itemsl!=NULL);
						itemsl=(struct beditem *)beditemsort_startAsc((struct genericItem *)ci->itemsl);
						ci->itemsl=itemsl;
						dsp.start->chromIdx=dsp.stop->chromIdx=rightBorder.chromIdx;
						dsp.start->coord=dsp.stop->coord=itemsl->start;
						lookChrIdx=rightBorder.chromIdx;
						}
					r->chromIdx = lookChrIdx;
					r->bstart = itemsl->start;
					r->bstop = itemsl->stop;
					r->dstart = r->dstop = (itemsl->start > dsp.stop->coord) ? itemsl->start : dsp.stop->coord;
					for(itemsl=itemsl->next; itemsl!=NULL; itemsl=itemsl->next)
						{
						if(itemsl->start <= r->bstop && itemsl->stop > r->bstop)
							r->bstop = itemsl->stop;
						else 
							break;
						}
					}
				}
			if(SQUAWK) fprintf(Squawk, "start region determined for move: %s bstart %d bstop %d\n", chrInfo[r->chromIdx]->name, r->bstart, r->bstop);
			r->summarySize = 0;
			dspAddRegionHead(hm.dsp, r);
			double sf = (double)mDistance / mSummarySize;
			if(dsp.juxType == 0)
				{
				moveBoundary_genome(hm.dsp, direction, mDistance, &mSummarySize, sf);
				}
			else
				{
				if(direction == 'l')
					moveBoundary_gf_left(hm.dsp, mDistance, mSummarySize);
				else
					moveBoundary_gf_right(hm.dsp, mDistance, mSummarySize);
				}
			if(SQUAWK) fprintf(Squawk, "dsp.head: %s:%d-%d   dsp.tail: %s:%d-%d\n\n", 
				chrInfo[dsp.head->chromIdx]->name, dsp.head->dstart, dsp.head->dstop, 
				chrInfo[dsp.tail->chromIdx]->name, dsp.tail->dstart, dsp.tail->dstop);
			computeEntireLength(hm.dsp);
			if(dsp.atbplevel)
				{
				computeSummarySize_bplevel(hm.dsp);
				}
			computeUsedSummaryNumber(hm.dsp);
			}
		else 
			{
			if(SQUAWK) fputs("not moving...\n", Squawk);
			/****************************
				not moving, possibilities:
				* image area select
				* zoom
				* change mode (genome <=> juxtaposition)
				* not changing dsp at all, just rebuild from CGI parameters
				* update scaffold
			 ****************************/
			if(trigger_scaffoldUpdate)
				{
				char *query;
				if(asprintf(&query, "update scaffoldRuntime set count=%s, names='%s' where session='%s' and statusId=%d", cgiString("scaffoldCount"), cgiString("scaffoldNames"), session, statusId)<0) errabort("bae");
				mysqlUpdate(query);
				free(query);
				reviveScaffold();
				trigger_imgAreaSelect = TRUE; // patch?
				}
			if(trigger_zoom || trigger_imgAreaSelect || trigger_changeGF)
				{
				makeDspBoundaryFromCgi(hm.dsp);
				if(dsp.juxType == 0)
					makeRegionSl_genome(hm.dsp);
				else
					makeRegionSl_gf(hm.dsp);
				computeEntireLength(hm.dsp);
				if(trigger_zoom) 
					{
					double zoomoutPerc = cgiDouble("zoom"); // >0
					if(SQUAWK)
					fprintf(Squawk, "zoom out by %.2f...\n", zoomoutPerc);
					// distance to expand to each side
					long dist = (long)((dsp.entireLength * zoomoutPerc /2));
					// region after zoom out should take hmSpan summary points
					double sf = dsp.entireLength * (1+zoomoutPerc) / hmSpan;
					computeSummarySize(hm.dsp, ceil(hmSpan / (1+zoomoutPerc)));
					int spnum = hmSpan*zoomoutPerc / (1+zoomoutPerc);
					if(dsp.juxType == 0)
						{
						moveBoundary_genome(hm.dsp, 'l', dist, &spnum, sf);
						spnum = hmSpan*zoomoutPerc / (1+zoomoutPerc);
						moveBoundary_genome(hm.dsp, 'r', dist, &spnum, sf);
						}
					else
						{
						moveBoundary_gf_left(hm.dsp, dist, spnum);
						moveBoundary_gf_right(hm.dsp, dist, spnum);
						}
					}
				if(dsp.juxType == 0)
					finalizeDsp_genome(hm.dsp);
				else
					finalizeDsp_gf(hm.dsp);
				}
			else
				{
				/* recover dsp using params:
				   - regionLst: chr,bstart,bstop,summarysize all joined by comma
				   - startCoord: dstart of head
				   - stopCoord: dstop of tail

				   NEVER forget to compute entire length and usedSummaryNumber
				 */
				dsp.usedSummaryNumber = 0;
				char *param = cgiString("regionLst");
				assert(param!=NULL);
				struct region *r = NULL;
				char delim[] = ",";
				char *tok = strtok(param, delim);
				assert(tok!=NULL);
				while(tok != NULL)
					{
					r = malloc(sizeof(struct region));
					r->chromIdx = strMayChrID(tok);
					if(r->chromIdx == -1)
						{
						scaffoldAddnew(tok);
						r->chromIdx = lastChrIdx;
						printf("'newscaffold':['%s',%u],", tok, chrInfo[lastChrIdx]->length);
						}
					assert((tok=strtok(NULL, delim))!=NULL);
					assert((r->bstart=r->dstart=strMayPositiveInt(tok))!=-1);
					assert((tok=strtok(NULL, delim))!=NULL);
					assert((r->bstop=r->dstop=strMayPositiveInt(tok))!=-1);
					assert((tok=strtok(NULL, delim))!=NULL);
					assert((r->summarySize=strMayPositiveInt(tok))!=-1);
					dsp.usedSummaryNumber += r->summarySize;
					r->isViewStart = FALSE;
					dspAddRegionTail(hm.dsp, r);
					tok = strtok(NULL, delim);
					}
				dsp.head->dstart = cgiInt("startCoord");
				dsp.tail->dstop = cgiInt("stopCoord");

				computeEntireLength(hm.dsp);
				if(dsp.usedSummaryNumber == dsp.entireLength)
					dsp.atbplevel = TRUE;
				}
			if(trigger_scaffoldUpdate)
				makeBorder(hm.dsp);
			}
		}
    }



if(trigger_chiapet)
    {
    // make chiapet dsp
    char *tmp = cgiString("chiapetregion");
    char delim[] = ",";
    char *tok = strtok(tmp, delim);
    assert(tok!=NULL);
    while(tok != NULL)
	{
	struct region *r = malloc(sizeof(struct region));
	assert((r->chromIdx=strMayChrID(tok))!=-1);
	tok = strtok(NULL, delim); assert(tok!=NULL);
	assert((r->bstart=r->dstart=strMayPositiveInt(tok))!=-1);
	tok = strtok(NULL, delim); assert(tok!=NULL);
	assert((r->bstop=r->dstop=strMayPositiveInt(tok))!=-1);
	tok = strtok(NULL, delim); assert(tok!=NULL);
	assert((r->summarySize=strMayPositiveInt(tok))!=-1);
	dsp_chiapet.usedSummaryNumber += r->summarySize;
	dspAddRegionTail(hm.dsp_chiapet, r);
	tok = strtok(NULL, delim);
	}
    }


if(trigger_genesetview)
    {
    /* running gene set view mode, 
       need to print out flanking info
     */
    printf("'gsvflanking':[");
    struct region *r;
    for(r=dsp.head; r!=NULL; r=r->next)
	printf("[%d,%d,%d,%d],", r->flank5start, r->flank5stop, r->flank3start, r->flank3stop);
    printf("],");
    }

/* CGI tells JS that they are at basepair level */
if(dsp.atbplevel)
    printf("\"atbplevel\":1,");

/****************
   border
   border info is also printed elsewhere...
   * first submission of itemlist
   * restoring saved status
 ****************/
if(isFirst || trigger_changeGF || trigger_scaffoldUpdate)
    printf("\"border\":[\"%s\",%d,\"%s\",%d],", chrInfo[leftBorder.chromIdx]->name, leftBorder.coord, chrInfo[rightBorder.chromIdx]->name, rightBorder.coord);


/******************
 ?? ensure usedSummaryNumber reaches hmSpan ??
if(dsp.usedSummaryNumber < hmSpan)
    {
    if(SQUAWK) fprintf(Squawk, "Low total summary number: %u...<br>\n", dsp.usedSummaryNumber);
    while(dsp.usedSummaryNumber < hmSpan)
        zoom(hm.dsp, '+', .1);
    }
else if(dsp.usedSummaryNumber > hmSpan)
    errabort("total summary number %d > %d (this should not happen!)", dsp.usedSummaryNumber, hmSpan);
*/


if(SQUAWK) showRegionSl(hm.dsp);

/* where does the view start?
   this piece of info is only needed when dsp got changed ON SERVER SIDE
   such as zoom, image area select, jump, ...
   in those cases, view start region should have been flagged out

   operations that change dsp on client side (e.g. move) will keep an updated dsp view start
 */
struct region *r;
int i = 0;
for(r=dsp.head; r!=NULL; r=r->next)
    {
    if(r->isViewStart)
        {
	printf("\"viewStart\":[%d,%d],", i, r->viewStartCoord);
	if(SQUAWK) fprintf(stderr, "viewStart: %s %d\n", chrInfo[r->chromIdx]->name, r->viewStartCoord);
	break;
	}
    i++;
    }

/* which datasets are being used?
   if isFirst, a dataset has been added to hm.datasetSl
   else, figure out from param
 */
if(!isFirst && cgiVarExists("dataset"))
	{
	char *string = cgiString("dataset");
	// comma separated table names
	char delim[] = ",";
	char *tok = strtok(string, delim);
	while(tok != NULL)
		{
		struct slNode *tt = malloc(sizeof(struct slNode));
		tt->name=strdup(tok);
		tt->next = hm.datasetSl;
		hm.datasetSl = tt;
		}
	}

if(trigger_changeGF || trigger_zoom || trigger_move || trigger_imgAreaSelect || trigger_jump || isFirst || trigger_restoreStatus || trigger_newitemlist || trigger_updateitemlist)
    {
    printf("\"regionLst\":[");
    struct region *r;
    for(r=dsp.head; r!=NULL; r=r->next)
        {
	// skip region with 0 summarySize
	if(r->summarySize == 0)
	    continue;
	printf("[\"%s\",%d,%d,%d,%d,%d,\"%s\",],", 
		(dsp.juxType==5) ? r->name : chrInfo[r->chromIdx]->name, 
		r->bstart, r->bstop, 
		r->dstart, r->dstop, 
		r->summarySize, 
		(cgiVarExists("itemlist")||trigger_newitemlist)?r->name:"");
	}
    printf("],");
    /* beware
       if atbplevel, the r->summarySize should not be used in JS,
       as regionLst[x][5] is supposed to be plot width (# of pixels) atbplevel
     */
    }

/***************************************
   displayed region is now determined
 ***************************************/



/*******************************
   chromosome ideogram
   only generate when dsp got changed
   only do for genome or bigbed juxtaposition modes
   won't do when at basepair level

   TODO remove this section as cytoband data is entirely held at js
 */
if((dsp.juxType==0 || dsp.juxType==1 || dsp.juxType==2) && !dsp.atbplevel && (trigger_changeGF || trigger_zoom || trigger_move || trigger_imgAreaSelect || trigger_jump || isFirst || trigger_restoreStatus || trigger_newchiapet))
    {
    char *query, **row;
    MYSQL_RES *sr;
    struct region *r;
    printf("\"ideogram\":[");
    for(r=dsp.head; r!=NULL; r=r->next)
        {
		if(r->dstart > r->dstop)
			{
			if(SQUAWK) fputs("illegal region omitted in querying cytoband table\n", Squawk);
			continue;
			}
		if(r->dstart == r->dstop)
			{
			if(SQUAWK) fputs("requesting ideogram band data: dstart=dstop\n", stderr);
			continue;
			}
		float sf = (float)r->summarySize / (r->dstop-r->dstart);
		if(asprintf(&query, "select * from cytoband where chrom=\"%s\" and greatest(start,%d)<least(stop,%d)", 
			chrInfo[r->chromIdx]->name,
			r->dstart,
			r->dstop)<0) errabort("bae");
		// id, chrom, start, stop, name, colorIdx
		sr = mysqlGetResult(query);
		free(query);
		if(sr==NULL)
			continue;
		printf("[");
		while((row=mysql_fetch_row(sr))!= NULL)
			{
			int startCoord = strMayPositiveInt(row[2]);
			assert(startCoord!=-1);
			int stopCoord = strMayPositiveInt(row[3]);
			assert(stopCoord!=-1);
			if(startCoord < r->dstart) startCoord = r->dstart;
			if(stopCoord > r->dstop) stopCoord = r->dstop;
			printf("[\"%s\",%f,%s,%s],", row[4], (stopCoord-startCoord)*sf, row[5],row[0]);
			}
		mysql_free_result(sr);
		printf("],");
		}
    printf("],");
    }



/****  
    adding single custom track  
    bigwig, bigbed
 ****/
if(cgiVarExists("addcustombigwig"))
    {
    /* a custom quantitative hmtk file is newly submitted, only retrieve data for it over DSP
     */
    char *url = cgiString("url");
	/*
    if(binaryFileIsInvalid(url, TRUE))
        {
		printf("\"abort\":\"file not found with given URL\",");
		}
    else
	*/
	printf("'newcustomdata':");
	printJson_bigwig(hm.dsp, url);
	if(trigger_chiapet)
	    {
	    printf("'hmtkchiapet':{'%s':", cgiString("name"));
	    printJson_bigwig(hm.dsp_chiapet, url);
	    printf("},");
	    }
    }
if(cgiVarExists("addserverbam"))
    {
    /* add multiple server bam files
       parameter is bam file name,mode
       for each bam file return [name, label, mode, [data]]
	   TODO lots of unfixed
     */
    printf("'serverbamdata':[");
    char delim[] = ",";
    char *tok = strtok(cgiString("addserverbam"), delim);
    while(tok != NULL)
        {
	printf("['%s',", tok);
	char *query;
	if(asprintf(&query, "select bamfilelabel from track2BamInfo where bamfile='%s'", tok)<0) errabort("bae");
	char *label = mysqlGetOnestring(query);
	free(query);
	printf("'%s',", label);
	char *fpath;
	if(asprintf(&fpath, "%sbam/%s.bam", bbiDir, tok)<0) errabort("bae");
	assert((tok=strtok(NULL, delim)) != NULL); // mode
	printf("'%s',", tok);
	if(strcasecmp(tok, "density") == 0)
	    {
	    printJson_itemDensity(hm.dsp, fpath, FT_bam_n);
	    }
	else
	    {
	    //printJson_BAMstack(hm.dsp, fpath);
	    }
	printf("],");
	tok = strtok(NULL, delim);
	}
    printf("],");
    }
/** add multiple custom bigwig
    an awkward branching out
 **/
if(cgiVarExists("addmulticustombigwig"))
    {
    // param: name/label/url, joined by comma
    char delim[] = ",";
    char *tok = strtok(cgiString("tklst"), delim);
    printf("'bwdata':{");
    while(tok != NULL)
        {
        printf("'%s':[", tok); // name
	assert((tok=strtok(NULL, delim)) != NULL); // label
	printf("'%s',", tok);
	assert((tok=strtok(NULL, delim)) != NULL); // url
	printJson_bigwig(hm.dsp, tok);
	printf("],");
	tok = strtok(NULL, delim);
	}
    printf("},");
    }



/****
     DECORs
     note that if decor0 exists in CGI param, implies that this is not restoring session
     so hm.decorX should not be overwritten
 ****/
if(trigger_decor0) hm.decor0 = parseParamDecor0(cgiString("decor0"));
if(trigger_decor1) hm.decor1 = parseParamDecor1(cgiString("decor1"));
if(trigger_decor8) hm.decor8 = parseParamDecor8(cgiString("decor8"));
if(trigger_decor4) hm.decor4 = parseParamDecor4(cgiString("decor4"));
if(trigger_decor5) hm.decor5 = parseParamDecor5(cgiString("decor5"));
if(trigger_decor9) hm.decor9 = parseParamDecor9(cgiString("decor9"));
if(trigger_decor10) hm.decor10 = parseParamDecor10(cgiString("decor10"));
if(hm.decor0!=NULL || hm.decor1!=NULL || hm.decor9!=NULL || hm.decor10!=NULL || hm.decor8!=NULL || hm.decor4!=NULL || hm.decor5!=NULL)
    {
    /* return a json array: [tkname, filetype, label, url, mode, plotting data]
       to be parsed by jsonDecor
     */
    printf("'decorData':[");
    struct tnode *tt;
    for(tt=hm.decor0; tt!=NULL; tt=tt->next) // native bigbed
        {
		printf("['%s', %d, , , %d,", tt->t1, FT_bigbed_n, tt->t4);
		printJsonDecor(hm.dsp, tt, FT_bigbed_n, FALSE);
		printf("],");
		}
    for(tt=hm.decor1; tt!=NULL; tt=tt->next) // custom bigbed
        {
		printf("['%s', %d, '%s', '%s', %d,", tt->t1, FT_bigbed_c, tt->t2, tt->t3, tt->t4);
		printJsonDecor(hm.dsp, tt, FT_bigbed_c, FALSE);
		printf("],");
		}
    for(tt=hm.decor9; tt!=NULL; tt=tt->next) // native long-range
        {
		printf("['%s', %d, , , %d,", tt->t1, FT_chiapet_n, tt->t4);
		printJsonDecor(hm.dsp, tt, FT_chiapet_n, trigger_newchiapet);
		printf("],");
		}
    for(tt=hm.decor10; tt!=NULL; tt=tt->next) // custom long-range
        {
		printf("['%s', %d, '%s', '%s', %d,", tt->t1, FT_chiapet_c, tt->t2, tt->t3, tt->t4);
		printJsonDecor(hm.dsp, tt, FT_chiapet_c, trigger_newchiapet);
		printf("],");
		}
    for(tt=hm.decor8; tt!=NULL; tt=tt->next) // native qdecor
        {
		printf("['%s', %d, , , %d,", tt->t1, FT_qdecor_n, tt->t4);
		printJsonDecor(hm.dsp, tt, FT_qdecor_n, FALSE);
		printf("],");
		}
    for(tt=hm.decor4; tt!=NULL; tt=tt->next) // native bam
        {
		printf("['%s', %d, , , %d,", tt->t1, FT_bam_n, tt->t4);
		printJsonDecor(hm.dsp, tt, FT_bam_n, FALSE);
		printf("],");
		}
    for(tt=hm.decor5; tt!=NULL; tt=tt->next) // custom bam
        {
		printf("['%s', %d, '%s', '%s', %d,", tt->t1, FT_bam_c, tt->t2, tt->t3, tt->t4);
		printJsonDecor(hm.dsp, tt, FT_bam_c, FALSE);
		printf("],");
		}
    printf("],");
    if(trigger_chiapet)
        {
		printf("\"chiapetdecorData\":[");
		struct tnode *tt;
		for(tt=hm.decor0; tt!=NULL; tt=tt->next)
			{
			printf("['%s', %d, , , %d,", tt->t1, FT_bigbed_n, tt->t4);
			printJsonDecor(hm.dsp_chiapet, tt, FT_bigbed_n, TRUE);
			printf("],");
			}
		for(tt=hm.decor1; tt!=NULL; tt=tt->next)
			{
			printf("['%s', %d, '%s', '%s', %d,", tt->t1, FT_bigbed_c, tt->t2, tt->t3, tt->t4);
			printJsonDecor(hm.dsp_chiapet, tt, FT_bigbed_c, TRUE);
			printf("],");
			}
		for(tt=hm.decor9; tt!=NULL; tt=tt->next)
			{
			printf("['%s', %d, , , %d,", tt->t1, FT_chiapet_n, tt->t4);
			printJsonDecor(hm.dsp_chiapet, tt, FT_chiapet_n, TRUE);
			printf("],");
			}
		for(tt=hm.decor10; tt!=NULL; tt=tt->next)
			{
			printf("['%s', %d, '%s', '%s', %d,", tt->t1, FT_chiapet_c, tt->t2, tt->t3, tt->t4);
			printJsonDecor(hm.dsp_chiapet, tt, FT_chiapet_c, TRUE);
			printf("],");
			}
		for(tt=hm.decor8; tt!=NULL; tt=tt->next)
			{
			printf("['%s', %d, , , %d,", tt->t1, FT_qdecor_n, tt->t4);
			printJsonDecor(hm.dsp_chiapet, tt, FT_qdecor_n, TRUE);
			printf("],");
			}
		for(tt=hm.decor4; tt!=NULL; tt=tt->next)
			{
			// t3 is bamfilepath, t4 is mode
			printf("['%s', %d, , , %d,", tt->t1, FT_bam_n, tt->t4);
			printJsonDecor(hm.dsp_chiapet, tt, FT_bam_n, TRUE);
			printf("],");
			}
		for(tt=hm.decor5; tt!=NULL; tt=tt->next)
			{
			printf("['%s', %d, '%s', '%s', %d,", tt->t1, FT_bam_c, tt->t2, tt->t3, tt->t4);
			printJsonDecor(hm.dsp_chiapet, tt, FT_bam_c, TRUE);
			printf("],");
			}
		printf("],");
		}
    }


if(cgiVarExists("loaddatahub"))
	{
	/* wget hub descriptor file
	   load bigwig/bigbed/bam tracks as custom tracks
	   load custom metadata
	   deals with chiapet

	   output json format (one array for each track, incompatible with usual way):
	   [ filetype, name, label, url, mode, [main data], metadata, [chiapet data] ]

	   exit when done!!
	 */
	if(SQUAWK) fputs("loading hub...\n", stderr);
	srand(time(0));
	int r = rand();
	char *descriptorfile;
	if(asprintf(&descriptorfile, "%s/%s.%d.hub", trashDir, session, r)<0) errabort("bae");
	char *command;
	if(asprintf(&command, "wget %s -O %s -q", cgiString("url"), descriptorfile)<0) errabort("bae");
	if(system(command) == -1)
		{
		printf("'abort':'failed to issue wget'}");
		return 1;
		}
	// tell if the file is empty
	FILE *fin = fopen(descriptorfile, "rb");
	if(fin == NULL)
		{
		printf("'abort':'internal server error'}");
		return 1;
		}
	fseek(fin, 0, SEEK_END);
	if(ftell(fin) == 0)
		{
		printf("'abort':'cannot read descriptor file or zero file content'}");
		return 1;
		}
	rewind(fin);

	/* start to read descriptor file
	   output one array for each track
	   [filetype, tkname, label, url, mode, plotting data]
	 */
	char delim[] = "\t\n";
	char *tok; char *line=malloc(1); size_t s=1;
	printf("'hubdata':[");
	int i = 1;
	while(getline(&line, &s, fin) != -1)
		{
		tok = strtok(line, delim);
		if(tok == NULL) 
			continue;
		if(strcasecmp(tok, "bedgraph") == 0)
			{
			char *url = strtok(NULL, delim);
			if(url == NULL)
				continue;
			//if(binaryFileIsInvalid(url, TRUE)) continue;
			char *label = strtok(NULL, delim);
			if(label == NULL)
				continue;
			char *anno = strtok(NULL, delim);
			char *tkname;
			if(asprintf(&tkname, "%s.%d.%d", session, r, i)<0) errabort("bae");
			printf("[%d, '%s', '%s', '%s', , ", FT_hmtk_c, tkname, label, url);
			printJson_bigwig(hm.dsp, url);
			// metadata anno
			if(anno != NULL)
				printf("'%s'", anno);
			printf(",");
			if(trigger_chiapet)
				printJson_bigwig(hm.dsp_chiapet, url);
			printf("],");
			i++;
			}
		else if(strcasecmp(tok, "bed") == 0)
			{
			char *url = strtok(NULL, delim);
			if(url == NULL)
				continue;
			//if(binaryFileIsInvalid(url, TRUE)) continue;
			char *label = strtok(NULL, delim);
			if(label == NULL)
				continue;
			char *mode = strtok(NULL, delim);
			if(mode == NULL)
				continue;
			int mode_i;
			if((mode_i=decorMode2num(mode))==M_error)
				continue;
			char *anno = strtok(NULL, delim);
			char *tkname;
			if(asprintf(&tkname, "%s.%d.%d", session, r, i)<0) errabort("bae");
			printf("[%d, '%s', '%s', '%s', %d, [", FT_bigbed_c, tkname, label, url, mode_i);
			if(mode!=M_hide)
				{
				if(mode_i==M_den)
					printJson_itemDensity(hm.dsp, url, FT_bigbed_c);
				else
					printJson_bedstack(hm.dsp, url, FT_bigbed_c, NULL, NULL,NULL);
				}
			printf("],");
			// metadata anno
			if(anno != NULL)
				printf("'%s'", anno);
			printf(",");
			if(trigger_chiapet && mode_i!=M_hide)
				{
				if(mode_i==M_den)
					{
					printJson_itemDensity(hm.dsp_chiapet, url, FT_bigbed_c);
					}
				else
					{
					printJson_bedstack(hm.dsp_chiapet, url, FT_bigbed_c, NULL, NULL,NULL);
					}
				}
			printf("],");
			i++;
			}
		else if(strcasecmp(tok, "longrange") == 0)
			{
			// similar as bigbed but with extra field of scorecutoff
			char *url = strtok(NULL, delim);
			if(url == NULL)
				continue;
			//if(binaryFileIsInvalid(url, TRUE)) continue;
			char *label = strtok(NULL, delim);
			if(label == NULL)
				continue;
			char *mode = strtok(NULL, delim);
			if(mode == NULL)
				continue;
			int mode_i;
			if((mode_i=decorMode2num(mode))==M_error) continue;
			char *anno = strtok(NULL, delim);
			char *cutoff = strtok(NULL, delim);
			float cutoff2, cutoff3;
			cutoff2 = cutoff==NULL ? 2 : strtod(cutoff, NULL);
			cutoff3 = 0-cutoff2;
			char *tkname;
			if(asprintf(&tkname, "%s.%d.%d", session, r, i)<0) errabort("bae");
			printf("[%d, '%s', '%s', '%s', %d, [", FT_chiapet_c, tkname, label, url, mode_i);
			if(mode_i!=M_hide)
				{
				if(mode_i==M_den)
					{
					printJson_itemDensity(hm.dsp, url, FT_chiapet_c);
					}
				else
					{
					printJson_bed_scorefilter(hm.dsp, url, FT_chiapet_c, cutoff2,cutoff3, FALSE);
					}
				}
			printf("],");
			// metadata anno
			if(anno != NULL)
				printf("'%s'", anno);
			printf(",");
			if(trigger_chiapet && mode_i!=M_hide)
				{
				if(mode_i==M_den)
					{
					printJson_itemDensity(hm.dsp_chiapet, url, FT_chiapet_c);
					}
				else
					{
					printJson_bed_scorefilter(hm.dsp_chiapet, url, FT_chiapet_c, cutoff2,cutoff3, mode_i==M_arc||mode_i==M_trihm);
					}
				}
			printf("],");
			i++;
			}
		else if(strcasecmp(tok, "sam") == 0)
			{
			char *url = strtok(NULL, delim);
			if(url == NULL)
				continue;
			//if(binaryFileIsInvalid(url, TRUE)) continue;
			char *label = strtok(NULL, delim);
			if(label == NULL)
				continue;
			char *mode = strtok(NULL, delim);
			if(mode == NULL)
				continue;
			int mode_i;
			if((mode_i=decorMode2num(mode))==M_error) continue;
			char *anno = strtok(NULL, delim);
			char *tkname;
			if(asprintf(&tkname, "%s.%d.%d", session, r, i)<0) errabort("bae");
			printf("[%d, '%s', '%s', '%s', %d, ", FT_bam_c, tkname, label, url, mode_i);
			if(mode_i==M_hide)
				{
				printf(",");
				}
			else
				{
				if(mode_i==M_den)
					{
					printJson_itemDensity(hm.dsp, url, FT_bam_c);
					}
				else
					{
					//printJson_BAMstack(hm.dsp, url);
					}
				}
			// metadata anno
			if(anno != NULL)
				printf("'%s'", anno);
			printf(",");
			if(trigger_chiapet && mode_i!=M_hide)
				{
				if(mode_i==M_den)
					{
					printJson_itemDensity(hm.dsp_chiapet, url, FT_bam_c);
					}
				else
					{
					//printJson_BAMstack(hm.dsp_chiapet, url);
					}
				}
			printf("],");
			i++;
			}
		else if(strcasecmp(tok, "metadata") == 0)
			{
			// custom metadata term
			char *name = strtok(NULL, delim);
			if(name == NULL)
				continue;
			char *values = strtok(NULL, delim);
			if(values == NULL)
				continue;
			printf("[-1, '%s', '%s'],", name, values);
			}
		else
			{
			// ignore unmatching cases
			fprintf(stderr, "%s: unknown linetype indicator (%s)\n", __FUNCTION__, tok);
			}
		}
	fclose(fin);
	printf("]}");
	done();
	return 1;
    }




/*** make list of hmtk ***/
if(trigger_restoreStatus)
    {
    /* trackSl has already been made from saved status
       only need to make file path for server tracks
     */
    struct track *tk;
    for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
        {
		if(tk->ft==FT_hmtk_c||tk->ft==FT_cat_c)
			continue;
		tk->urlpath=makefilepath(tk->name,tk->ft);
		}
    if(SQUAWK) 
		fputs("track sl made\n", Squawk);
    }
else if(trigger_changeGF || trigger_zoom || trigger_move || trigger_imgAreaSelect || trigger_jump || isFirst || trigger_htest || trigger_addserverhmtk || trigger_getdata || trigger_newitemlist || trigger_updateitemlist || trigger_newchiapet)
    {
    /* trackSl will be made for all cases except following two:
       - restore status
       - draw decor
     */
    struct track *trackSl = NULL, *tk;
    if(isFirst && !cgiVarExists("noDefaultcontent"))
        {
    	/* this is first invocation of CGI program, 
	    use tracks in config.defaultTracks
         */
		char *string = mysqlGetOnestring("select defaultTracks from config");
		assert(string != NULL);
		char delim[] = ",";
		char *tok = strtok(string, delim);
		while(tok != NULL)
			{
			tk = malloc(sizeof(struct track));
			tk->name=tok;
			tk->urlpath=makefilepath(tok, FT_hmtk_n);
			tk->data = NULL; // safety
			tk->next = trackSl;
			trackSl = tk;
			tok = strtok(NULL, delim);
			}
		// get track filetype
		char *query;
		for(tk=trackSl; tk!=NULL; tk=tk->next)
			{
			assert(asprintf(&query, "select ft from track2Ft where name='%s'", tk->name)>0);
			assert((tk->ft=mysqlGetPositiveInteger(query))!=-1);
			free(query);
			}
		// there won't be custom tracks
		}
    else
        {
		char *tok;
		char delim[] = ",";
		if(cgiVarExists("hmtk2"))
			{
			char *tmp=cgiString("hmtk2");
			assert(tmp!=NULL);
			tok = strtok(tmp, delim);
			while(tok != NULL)
				{
				tk = malloc(sizeof(struct track));
				tk->name=tok;
				tk->urlpath=makefilepath(tok, FT_hmtk_n);
				tk->data = NULL;
				tk->ft=FT_hmtk_n;
				tk->next = trackSl;
				trackSl = tk;
				tok = strtok(NULL, delim);
				}
			}
		if(cgiVarExists("hmtk3"))
			{
			char *tmp=cgiString("hmtk3");
			tok = strtok(tmp, delim);
			while(tok != NULL)
				{
				tk = malloc(sizeof(struct track));
				tk->urlpath=strdup(tok);
				tok = strtok(NULL, delim); assert(tok != NULL);
				tk->name=strdup(tok);
				tk->data = NULL;
				tk->ft=FT_hmtk_c;
				tk->next = trackSl;
				trackSl = tk;
				tok = strtok(NULL, delim);
				}
			}
		if(cgiVarExists("hmtk12"))
			{
			char *tmp=cgiString("hmtk12");
			tok=strtok(tmp, delim);
			while(tok != NULL)
				{
				tk = malloc(sizeof(struct track));
				tk->name=tok;
				tk->urlpath=makefilepath(tok, FT_cat_n);
				tk->data = NULL;
				tk->ft=FT_cat_n;
				tk->next = trackSl;
				trackSl = tk;
				tok = strtok(NULL, delim);
				}
			}
		if(cgiVarExists("hmtk13"))
			{
			char *tmp=cgiString("hmtk13");
			tok = strtok(tmp, delim);
			while(tok != NULL)
				{
				tk = malloc(sizeof(struct track));
				tk->urlpath=strdup(tok);
				tok = strtok(NULL, delim); assert(tok != NULL);
				tk->name=strdup(tok);
				tk->data = NULL;
				tk->ft=FT_cat_c;
				tk->next = trackSl;
				trackSl = tk;
				tok = strtok(NULL, delim);
				}
			}
		}
    hm.trackSl = trackSl;

    for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
        tk->gid = 0;

    if(0) showTrackSl(hm.trackSl);
    if(SQUAWK) fputs("track sl made\n", Squawk);
    }



/* during change server track, if htest is on, custom track will have gid
   but as track attribute id will only be calculated on client side,
   this round won't carry out htest, so switch it off after parsing param.
   after json is passed back to client, it will issue htest()
 */
if(trigger_addserverhmtk) trigger_htest = FALSE;



if(CHECKCPUTIME)
    {
    clock_t this = clock();
    fprintf(Squawk, "Elapsed time before fetching track data: %f\n", ((double)(this-cpuTimeStart))/CLOCKS_PER_SEC);
    cpuTimeTemp = clock();
    }




/*** fetch hmtk data ***/
if(trigger_changeGF || trigger_zoom || trigger_move || trigger_imgAreaSelect || trigger_jump || isFirst || trigger_htest || trigger_addserverhmtk || trigger_getdata || trigger_restoreStatus || trigger_newitemlist || trigger_updateitemlist || trigger_newchiapet)
	{
	/* parallelization
	   for each track, fork to fetch data and write into a file at trash dir,
	   file name: session+track name, one value at each line,
	   the parent process will wait till all children processes finish,
	   and read in that folder data of each track,
	   then remove that folder
	   tk->pid as state flag, see "data structure.dia"
	 */
	char *line = malloc(1);
	size_t s = 1;
	/* preparation */
	struct track *tk;
	for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
		{
		/* check if bigwig file exists, if not, abort binaryFileIsInvalid */
		tk->pid = -1;
		if(asprintf(&tk->tmpfile, "%s/%s%s", trashDir, session, tk->name)<0) errabort("bae");
		}

	/* fetch data */
	int i;
	boolean notfinished = TRUE;
	int processRunningNum = 0;
	boolean printdata = trigger_changeGF || trigger_zoom || trigger_move || trigger_imgAreaSelect || trigger_jump || isFirst || trigger_addserverhmtk || trigger_restoreStatus || trigger_newitemlist || trigger_updateitemlist || trigger_newchiapet;
	if(printdata) printf("\"tkData\":[");
	while(notfinished)
		{
		notfinished = FALSE;
		for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
			{
			if(tk->pid == -1)
				{
				/* this track not processed */
				if(processRunningNum == MaxProcessNum)
					{
					notfinished = TRUE;
					if(0) fputs("reaches max, wait for empty slots...\n", Squawk);
					continue;
					}
				/* fork for this track */
				pid_t p = fork();
				if(p == 0)
					{
					/*** now in a child process ***/
					if(tk->ft==FT_hmtk_c || tk->ft==FT_hmtk_n)
						{
						double *data= tabixQuery_bedgraph_dsp(hm.dsp, tk->urlpath);
						FILE *fout = fopen(tk->tmpfile, "w");
						if(fout == NULL) errabort("cannot open file to write");
						for(i=0; i<dsp.usedSummaryNumber; i++)
							fprintf(fout, "%f\n", data[i]);
						fclose(fout);
						}
					else if(tk->ft==FT_cat_c || tk->ft==FT_cat_n)
						{
						int *data=tabixQuery_categorical_dsp(hm.dsp, tk->urlpath);
						FILE *fout = fopen(tk->tmpfile, "w");
						if(fout == NULL) errabort("cannot open file to write");
						for(i=0; i<dsp.usedSummaryNumber; i++)
							fprintf(fout, "%d\n", data[i]);
						fclose(fout);
						}
					else 
						errabort("fetching hmtk data: unknown filetype");
					_exit(0); // exit without flushing buffer
					}
				else if(p < 0)
					{
					errabort("error spawning child process at track");
					}
				else
					{
					tk->pid = p;
					processRunningNum++;
					}
				notfinished = TRUE;
				}
			else if(tk->pid > 0)
				{
				/* child has been forked */
				int status;
				waitpid(tk->pid, &status, 0);
				if(status == 0)
					{
					/* child process has finished successfully */
					tk->pid = 0;
					/* cubersome ft-specific treatment */
					double *data = malloc(sizeof(double)*dsp.usedSummaryNumber);
					FILE *fin = fopen(tk->tmpfile, "r");
					fprintf(stderr, "TMP %s\n", tk->tmpfile);
					if(fin == NULL) errabort("error opening file for reading");
					if(tk->ft==FT_hmtk_c||tk->ft==FT_hmtk_n)
						{
						for(i=0; i<dsp.usedSummaryNumber; i++)
							{
							if(getline(&line, &s, fin) == -1) errabort(tk->tmpfile);
							data[i] = strtod(line, NULL);
							}
						if(printdata)
							{
							// print out json for tkLst array element
							printf("{'name':'%s','ft':%d,",tk->name, tk->ft);
							if(tk->ft==FT_hmtk_c)
								printf("'url':'%s',", tk->urlpath);
							printf("'data':[");
							// track data of different regions are in separate arrays
							int i=0;
							struct region *r;
							for(r=dsp.head; r!=NULL; r=r->next)
								{
								int j;
								printf("[");
								for(j=0; j<r->summarySize; j++)
									printf("%.2f,", data[i+j]);
								printf("],");
								i += j;
								}
							printf("]},");
							}
						}
					else if(tk->ft==FT_cat_n||tk->ft==FT_cat_c)
						{
						for(i=0; i<dsp.usedSummaryNumber; i++)
							{
							assert(getline(&line, &s, fin)!=-1);
							data[i] = strtol(line, NULL, 0);
							}
						if(printdata)
							{
							// print out json for tkLst array element
							printf("{'name':'%s','ft':%d,",tk->name, tk->ft);
							if(tk->ft==FT_cat_c)
								printf("'url':'%s',", tk->urlpath);
							printf("'data':[");
							// track data of different regions are in separate arrays
							int i=0;
							struct region *r;
							for(r=dsp.head; r!=NULL; r=r->next)
								{
								int j;
								printf("[");
								for(j=0; j<r->summarySize; j++)
									printf("%d,", (int)data[i+j]);
								printf("],");
								i += j;
								}
							printf("]},");
							}
						}
					else errabort("collecting hmtk data: unknown ft");
					tk->data = data;
					//unlink(tk->tmpfile);
					//free(tk->tmpfile);
					}
				else
					errabort("unknown status for child process");
				processRunningNum--;
				}
			}
		}
	if(printdata) printf("],");
	if(SQUAWK) fputs("track data fetched, trackSl made\n", Squawk);
	mysql_close(conn);
	mysqlConnect(dbName);

	if(trigger_chiapet)
		{
	/* this should work for:
	   - generic adding server hmtk
		 (adding to show in genome heatmap, not specifically for chiapet)
	   - htest
	   so pretty much one time deal, and no forking should be fine
	   TODO this data need to be attached and send to htest
	 */
	printf("'hmtkchiapet':{");
	for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
		{
		double *data = tabixQuery_bedgraph_dsp(hm.dsp_chiapet, tk->urlpath);
		printf("'%s':[", tk->name);
		// track data of different regions are in separate arrays
		int i=0;
		struct region *r;
		for(r=dsp_chiapet.head; r!=NULL; r=r->next)
		{
		int j;
		printf("[");
		for(j=0; j<r->summarySize; j++)
			printf("%.2f,", data[i+j]);
		printf("],");
		i += j;
		}
		printf("],");
		}
	printf("},");
	}
	}

if(CHECKCPUTIME)
    {
    clock_t this = clock();
    fprintf(Squawk, "Elapsed time spent on fetching track data: %f\n", ((double)(this-cpuTimeTemp))/CLOCKS_PER_SEC);
    cpuTimeTemp = clock();
    }



/* user wants to get data? */
if(trigger_getdata)
    {
    // regions on each row, tracks on each column
    // TODO: in case of gf mode, output feature name at each summary point
    // output file header
    char *outfile;
    if(asprintf(&outfile, "%s/%s.txt", WWWT, session)<0) errabort("bae");
    FILE *fout = fopen(outfile, "w");
    if(fout == NULL)
        {
	fprintf(stderr, "cannot open file to write: %s\n", outfile);
	exit(0);
	}
    fputs("chr\tstart\tstop", fout);
    struct track *tk;
    for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
        fprintf(fout, "\t%s", tk->name);
    fputs("\n", fout);

    struct region *r;
    int summaryIdx = 0;
    int i;
    for(r=dsp.head; r!=NULL; r=r->next)
        {
	float step = (float)(r->dstop-r->dstart) / r->summarySize;
	for(i=0; i<r->summarySize; i++)
	    {
	    fprintf(fout, "%s\t%d\t%d", (dsp.juxType==5)?r->name:chrInfo[r->chromIdx]->name, (int)(r->dstart + step*i), (int)(r->dstart + step*(i+1)));
  	    for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
		fprintf(fout, "\t%f", (tk->data)[summaryIdx+i]);
	    fputs("\n", fout);
	    }
	summaryIdx += r->summarySize;
	}
    //printf("\"getDataLink\":\"<a href='%s' target=_blank>Right click on this link and save file</a>\",", outfile.forCgi);
    //printf("\"");
    fclose(fout);

    free(outfile);
    // but who's gonna use wiggle?
    if(asprintf(&outfile, "%s/%s.wig", WWWT, session)<0) errabort("bae");
    fout = fopen(outfile, "w");
    for(tk=hm.trackSl; tk!=NULL; tk=tk->next)
        {
	fprintf(fout, "TRACK %s\n\n", tk->name);
	summaryIdx = 0;
	for(r=dsp.head; r!=NULL; r=r->next)
	    {
	    fprintf(fout, "fixedStep chrom=%s start=%d step=%d\n", (dsp.juxType==5)?r->name:chrInfo[r->chromIdx]->name, r->dstart, dsp.atbplevel?1:(int)((r->dstop-r->dstart)/r->summarySize));
	    for(i=0; i<r->summarySize; i++)
	        fprintf(fout, "%f\n", (tk->data)[summaryIdx+i]);
	    fputs("\n\n\n",fout);
	    summaryIdx += r->summarySize;
	    }
	}
    fclose(fout);
    free(outfile);
    }



/***   hypothesis test   
 ***/
if(trigger_htest)
    {
    /* assign track->gid
       if restoring status, all info should be stuffed into param environment
     */
    parseParamHtest(hm.trackSl);

    if(SQUAWK) fputs("Running htest...\n", Squawk);
    char *rsourcefile;
    if(asprintf(&rsourcefile, "%s/%s.R", trashDir, session)<0) errabort("bae");
    FILE *fout = fopen(rsourcefile, "w");
    if(fout == NULL) errabort(rsourcefile);
    char *routfile;
    if(asprintf(&routfile, "%s/%s.Rout", trashDir, session)<0) errabort("bae");
    char *pvfile;
    if(asprintf(&pvfile, "%s/%s.pvalues", trashDir, session)<0) errabort("bae");
    fputs("options(echo=FALSE)\n", fout);

    // print grouping vector for tracks
    fputs("grp=c(", fout);
    struct track *track;
    for(track=hm.trackSl; track!=NULL; track=track->next)
        {
	if(track->gid != 0)
	    fprintf(fout, "%d,", track->gid);
	}
    fseek(fout, -1, SEEK_CUR);
    fputs(")\npv=numeric()\n", fout);
    // write track data, one vector for each summary point over participating tracks
    struct region *r;
    int i;
    int j=0; // cumulative over all regions, index of track->data
    for(r=dsp.head; r!=NULL; r=r->next)
        {
	for(i=0; i<r->summarySize; i++)
	    {
	    fputs("data = c(", fout);
            for(track=hm.trackSl; track!=NULL; track=track->next)
                {
	        if(track->gid != 0)
	            fprintf(fout, "%f,", (float)(track->data)[j]);
	        }
	    fseek(fout, -1, SEEK_CUR);
	    fprintf(fout, ")\npv[%d]=kruskal.test(data, grp)$p.value\n", j+1);
	    j++;
	    }
	}
    if(cgiVarExists("htestc"))
        fprintf(fout, "pv=p.adjust(pv, method=\"%s\")\n", cgiString("htestc"));
    fprintf(fout, "write(pv, \"%s\", sep=\"\\n\")\n", pvfile);
    fclose(fout);
    // run test
    char *command;
    if(asprintf(&command, "R CMD BATCH --no-save %s %s", rsourcefile, routfile)<0) errabort("BAE");
    if(system(command) == -1)
        errabort(command);
    free(command);
    // parse pvalue file, return pvalues
    printf("\"htestData\":[");
    FILE *fin = fopen(pvfile,"r");
    char *line = malloc(1);
    size_t s = 1;
    for(r=dsp.head; r!=NULL; r=r->next)
        {
	printf("[");
	for(i=0; i<r->summarySize; i++)
	    {
            if(getline(&line, &s, fin) == -1)
	        errabort("expecting more pvalues but reaches EOF...");
	    if(line[0] == 'N') // NaN
	        printf("1,");
	    else if(line[0] == '1')
	        printf("1,");
            else
	        printf("%.4f,", strtod(line, NULL));
	    }
	printf("],");
        }
    fclose(fin);
    printf("],");
    }


/*** get numerical data for correlation 
 ***/
if(trigger_correlation)
    {
    char *corrtn = cgiString("correlation");
    int corrft = cgiInt("corrft");
    char *urlpath = makefilepath(corrtn, corrft);

    printf("\"corrData\":");
    switch(corrft)
		{
		case FT_bigbed_n:
		case FT_bigbed_c:
		case FT_bam_n: // stake
		case FT_bam_c:
		case FT_chiapet_n:
		case FT_chiapet_c:
			printJson_itemDensity(hm.dsp, urlpath, corrft);
			break;
		case FT_hmtk_n:
		case FT_hmtk_c:
		case FT_qdecor_n:
			printJson_bigwig(hm.dsp, urlpath);
			break;
		default:
			errabort("corrft of unsupported value");
		}
    }
if(trigger_restoreStatus)
    printf("\"alert\":\"saved browsing status restored.\"");

puts("}"); // json outmost brace

if(CHECKCPUTIME)
    {
    clock_t this = clock();
    fprintf(Squawk, "Elapsed time after fetching track data: %f\n", ((double)(this-cpuTimeTemp))/CLOCKS_PER_SEC);
    fprintf(Squawk, "(Parallel) Entire CPU time: %f\n", ((double)(this-cpuTimeStart))/CLOCKS_PER_SEC);
    }

done();
return 1;
}
